<?php

$LANG = array(
    'organization' => 'Organisation',
    'name' => 'Name',
    'website' => 'Webseite',
    'work_phone' => 'Telefon',
    'address' => 'Adresse',
    'address1' => 'Straße',
    'address2' => 'Adresszusatz',
    'city' => 'Stadt',
    'state' => 'Bundesland',
    'postal_code' => 'Postleitzahl',
    'country_id' => 'Land',
    'contacts' => 'Kontakte',
    'first_name' => 'Vorname',
    'last_name' => 'Nachname',
    'phone' => 'Telefon',
    'email' => 'E-Mail',
    'additional_info' => 'Zusätzliche Informationen',
    'payment_terms' => 'Zahlungsbedingungen',
    'currency_id' => 'Währung',
    'size_id' => 'Firmengröße',
    'industry_id' => 'Branche',
    'private_notes' => 'Private Notizen',
    'invoice' => 'Rechnung',
    'client' => 'Kunde',
    'invoice_date' => 'Rechnungsdatum',
    'due_date' => 'Fälligkeitsdatum',
    'invoice_number' => 'Rechnungsnummer',
    'invoice_number_short' => 'Re-Nr.',
    'po_number' => 'Bestellnummer',
    'po_number_short' => 'Best.-Nr.',
    'frequency_id' => 'Wie oft',
    'discount' => 'Rabatt',
    'taxes' => 'Steuern',
    'tax' => 'Steuer',
    'item' => 'Artikel',
    'description' => 'Beschreibung',
    'unit_cost' => 'Einzelpreis',
    'quantity' => 'Menge',
    'line_total' => 'Summe',
    'subtotal' => 'Zwischensumme',
    'paid_to_date' => 'Bereits gezahlt',
    'balance_due' => 'Offener Betrag',
    'invoice_design_id' => 'Design',
    'terms' => 'Bedingungen',
    'your_invoice' => 'Ihre Rechnung',
    'remove_contact' => 'Kontakt löschen',
    'add_contact' => 'Kontakt hinzufügen',
    'create_new_client' => 'Einen neuen Kunden erstellen',
    'edit_client_details' => 'Kundendetails bearbeiten',
    'enable' => 'Aktivieren',
    'learn_more' => 'Mehr erfahren',
    'manage_rates' => 'Steuersätze verwalten',
    'note_to_client' => 'Notiz an den Kunden',
    'invoice_terms' => 'Rechnungsbedingungen',
    'save_as_default_terms' => 'Als Standardbedingungen speichern',
    'download_pdf' => 'PDF herunterladen',
    'pay_now' => 'Jetzt bezahlen',
    'save_invoice' => 'Rechnung speichern',
    'clone_invoice' => 'Als Rechnung kopieren',
    'archive_invoice' => 'Rechnung archivieren',
    'delete_invoice' => 'Rechnung löschen',
    'email_invoice' => 'Rechnung versenden',
    'enter_payment' => 'Zahlung eingeben',
    'tax_rates' => 'Steuersätze',
    'rate' => 'Satz',
    'settings' => 'Einstellungen',
    'enable_invoice_tax' => 'Ermögliche das Bestimmen einer <strong>Rechnungssteuer</strong>',
    'enable_line_item_tax' => 'Ermögliche das Bestimmen von <strong>Steuern für Belegpositionen</strong>',
    'dashboard' => 'Dashboard',
    'dashboard_totals_in_all_currencies_help' => 'Hinweis: Fügen Sie einen :link namens ":name" hinzu, um die Summen in einer einzigen Basiswährung anzuzeigen.',
    'clients' => 'Kunden',
    'invoices' => 'Rechnungen',
    'payments' => 'Zahlungen',
    'credits' => 'Guthaben',
    'history' => 'Verlauf',
    'search' => 'Suche',
    'sign_up' => 'Anmeldung',
    'guest' => 'Gast',
    'company_details' => 'Firmendaten',
    'online_payments' => 'Online-Zahlungen',
    'notifications' => 'Benachrichtigungen',
    'import_export' => 'Import/Export',
    'done' => 'Erledigt',
    'save' => 'Speichern',
    'create' => 'Erstellen',
    'upload' => 'Hochladen',
    'import' => 'Importieren',
    'download' => 'Downloaden',
    'cancel' => 'Abbrechen',
    'close' => 'Schließen',
    'provide_email' => 'Bitte geben Sie eine gültige E-Mail-Adresse an',
    'powered_by' => 'Unterstützt durch',
    'no_items' => 'Keine Objekte',
    'recurring_invoices' => 'Wiederkehrende Rechnungen',
    'recurring_help' => '<p>Senden Sie Ihren Kunden automatisch die gleichen Rechnungen wöchentlich, zweimonatlich, monatlich, vierteljährlich oder jährlich zu.</p> 
 <p>Verwenden Sie :MONTH, :QUARTER oder :YEAR für dynamische Daten. Grundlegende Mathematik funktioniert auch, zum Beispiel :MONTH-1.</p>
 <p>Beispiele für dynamische Rechnungsvariablen:</p>
 <ul>
 <li>"Mitgliedschaft im Fitnessstudio für den Monat :MONTH". >> "Mitgliedschaft im Fitnessstudio für den Monat Juli".</li>
 <li>":YEAR+1 Jahresabonnement" >> "2015 Jahresabonnement".</li>
<li> "Einbehaltungszahlung für :QUARTER+1" >> "Einbehaltungszahlung für Q2".</li>
 </ul>
',
    'recurring_quotes' => 'Wiederkehrende Angebote',
    'in_total_revenue' => 'Gesamtumsatz',
    'billed_client' => 'abgerechneter Kunde',
    'billed_clients' => 'abgerechnete Kunden',
    'active_client' => 'aktiver Kunde',
    'active_clients' => 'aktive Kunden',
    'invoices_past_due' => 'Fällige Rechnungen',
    'upcoming_invoices' => 'Ausstehende Rechnungen',
    'average_invoice' => 'Durchschnittlicher Rechnungsbetrag',
    'archive' => 'Archivieren',
    'delete' => 'löschen',
    'archive_client' => 'Kunde archivieren',
    'delete_client' => 'Kunde löschen',
    'archive_payment' => 'Zahlung archivieren',
    'delete_payment' => 'Zahlung löschen',
    'archive_credit' => 'Guthaben archivieren',
    'delete_credit' => 'Guthaben löschen',
    'show_archived_deleted' => 'Zeige archivierte/gelöschte',
    'filter' => 'Filter',
    'new_client' => 'Neuer Kunde',
    'new_invoice' => 'Neue Rechnung',
    'new_payment' => 'Zahlung eingeben',
    'new_credit' => 'Guthaben eingeben',
    'contact' => 'Kontakt',
    'date_created' => 'Erstellungsdatum',
    'last_login' => 'Letzter Login',
    'balance' => 'Saldo',
    'action' => 'Aktion',
    'status' => 'Status',
    'invoice_total' => 'Rechnungsbetrag',
    'frequency' => 'Häufigkeit',
    'range' => 'Bereich',
    'start_date' => 'Startdatum',
    'end_date' => 'Enddatum',
    'transaction_reference' => 'Abwicklungsreferenz',
    'method' => 'Verfahren',
    'payment_amount' => 'Zahlungsbetrag',
    'payment_date' => 'Zahlungsdatum',
    'credit_amount' => 'Guthabenbetrag',
    'credit_balance' => 'Guthabenstand',
    'credit_date' => 'Guthabendatum',
    'empty_table' => 'Es sind keine Daten vorhanden',
    'select' => 'Wählen',
    'edit_client' => 'Kunde bearbeiten',
    'edit_invoice' => 'Rechnung bearbeiten',
    'create_invoice' => 'Rechnung erstellen',
    'enter_credit' => 'Guthaben eingeben',
    'last_logged_in' => 'Zuletzt eingeloggt',
    'details' => 'Details',
    'standing' => 'Aktueller Stand',
    'credit' => 'Gutschrift',
    'activity' => 'Aktivität',
    'date' => 'Datum',
    'message' => 'Nachricht',
    'adjustment' => 'Anpassung',
    'are_you_sure' => 'Sind Sie sicher?',
    'payment_type_id' => 'Zahlungsart',
    'amount' => 'Betrag',
    'work_email' => 'E-Mail',
    'language_id' => 'Sprache',
    'timezone_id' => 'Zeitzone',
    'date_format_id' => 'Datumsformat',
    'datetime_format_id' => 'Datums-/Zeitformat',
    'users' => 'Benutzer',
    'localization' => 'Lokalisierung',
    'remove_logo' => 'Logo entfernen',
    'logo_help' => 'Unterstützt: JPEG, GIF und PNG',
    'payment_gateway' => 'Zahlungseingang',
    'gateway_id' => 'Zahlungsanbieter',
    'email_notifications' => 'E-Mail Benachrichtigungen',
    'email_sent' => 'Benachrichtigen, wenn eine Rechnung <strong>versendet</strong> wurde',
    'email_viewed' => 'Benachrichtigen, wenn eine Rechnung <strong>betrachtet</strong> wurde',
    'email_paid' => 'Benachrichtigen, wenn eine Rechnung <strong>bezahlt</strong> wurde',
    'site_updates' => 'Webseitenaktualisierungen',
    'custom_messages' => 'Benutzerdefinierte Nachrichten',
    'default_email_footer' => 'Standard-E-Mail Signatur',
    'select_file' => 'Bitte wähle eine Datei',
    'first_row_headers' => 'Benutze erste Zeile als Spaltenüberschrift',
    'column' => 'Spalte',
    'sample' => 'Beispiel',
    'import_to' => 'Importieren nach',
    'client_will_create' => 'Kunde wird erstellt',
    'clients_will_create' => 'Kunden werden erstellt',
    'email_settings' => 'E-Mail-Einstellungen',
    'client_view_styling' => 'Client View Styling',
    'pdf_email_attachment' => 'PDF anhängen',
    'custom_css' => 'Benutzerdefiniertes CSS',
    'import_clients' => 'Importiere Kundendaten',
    'csv_file' => 'Wähle CSV Datei',
    'export_clients' => 'Exportiere Kundendaten',
    'created_client' => 'Kunde erfolgreich angelegt',
    'created_clients' => ':count Kunden erfolgreich angelegt',
    'updated_settings' => 'Einstellungen erfolgreich aktualisiert',
    'removed_logo' => 'Logo erfolgreich entfernt',
    'sent_message' => 'Nachricht erfolgreich versendet',
    'invoice_error' => 'Bitte stelle sicher, dass ein Kunde ausgewählt und alle Fehler behoben wurden',
    'limit_clients' => 'Entschuldige, das überschreitet das Limit von :count Kunden',
    'payment_error' => 'Es ist ein Fehler während der Zahlung aufgetreten. Bitte versuche es später noch einmal.',
    'registration_required' => 'Bitte melde dich an um eine Rechnung zu versenden',
    'confirmation_required' => 'Bitte verifiziere deine E-Mail Adresse, :link um die E-Mail Bestätigung erneut zu senden.',
    'updated_client' => 'Kunde erfolgreich aktualisiert',
    'archived_client' => 'Kunde erfolgreich archiviert',
    'archived_clients' => ':count Kunden erfolgreich archiviert',
    'deleted_client' => 'Kunde erfolgreich gelöscht',
    'deleted_clients' => ':count Kunden erfolgreich gelöscht',
    'updated_invoice' => 'Rechnung erfolgreich aktualisiert',
    'created_invoice' => 'Rechnung erfolgreich erstellt',
    'cloned_invoice' => 'Rechnung erfolgreich dupliziert',
    'emailed_invoice' => 'Rechnung erfolgreich versendet',
    'and_created_client' => 'und Kunde erstellt',
    'archived_invoice' => 'Rechnung erfolgreich archiviert',
    'archived_invoices' => ':count Rechnungen erfolgreich archiviert',
    'deleted_invoice' => 'Rechnung erfolgreich gelöscht',
    'deleted_invoices' => ':count Rechnungen erfolgreich gelöscht',
    'created_payment' => 'Zahlung erfolgreich erstellt',
    'created_payments' => ':count Zahlung(en) erfolgreich erstellt',
    'archived_payment' => 'Zahlung erfolgreich archiviert',
    'archived_payments' => ':count Zahlungen erfolgreich archiviert',
    'deleted_payment' => 'Zahlung erfolgreich gelöscht',
    'deleted_payments' => ':count Zahlungen erfolgreich gelöscht',
    'applied_payment' => 'Zahlung erfolgreich angewandt',
    'created_credit' => 'Guthaben erfolgreich erstellt',
    'archived_credit' => 'Guthaben erfolgreich archiviert',
    'archived_credits' => ':count Guthaben erfolgreich archiviert',
    'deleted_credit' => 'Guthaben erfolgreich gelöscht',
    'deleted_credits' => ':count Guthaben erfolgreich gelöscht',
    'imported_file' => 'Datei erfolgreich importiert',
    'updated_vendor' => 'Lieferant erfolgreich aktualisiert',
    'created_vendor' => 'Lieferant erfolgreich erstellt',
    'archived_vendor' => 'Lieferant erfolgreich archiviert',
    'archived_vendors' => ':count Lieferanten erfolgreich archiviert',
    'deleted_vendor' => 'Lieferant erfolgreich gelöscht',
    'deleted_vendors' => ':count Lieferanten erfolgreich gelöscht',
    'confirmation_subject' => 'InvoiceNinja Kontobestätigung',
    'confirmation_header' => 'Kontobestätigung',
    'confirmation_message' => 'Bitte klicke auf den folgenden Link um dein Konto zu bestätigen.',
    'invoice_subject' => 'Neue Rechnung :number von :account',
    'invoice_message' => 'Um Ihre Rechnung über :amount einzusehen, klicken Sie bitte auf den folgenden Link:',
    'payment_subject' => 'Zahlungseingang',
    'payment_message' => 'Vielen Dank für Ihre Zahlung von :amount.',
    'email_salutation' => 'Sehr geehrte/r :name,',
    'email_signature' => 'Mit freundlichen Grüßen,',
    'email_from' => 'Das InvoiceNinja Team',
    'invoice_link_message' => 'Um deine Kundenrechnung anzuschauen, klicke auf den folgenden Link:',
    'notification_invoice_paid_subject' => 'Die Rechnung :invoice wurde von :client bezahlt.',
    'notification_invoice_sent_subject' => 'Rechnung :invoice wurde an :client versendet.',
    'notification_invoice_viewed_subject' => 'Die Rechnung :invoice wurde von :client angeschaut.',
    'notification_invoice_paid' => 'Eine Zahlung von :amount wurde von :client bezüglich Rechnung :invoice getätigt.',
    'notification_invoice_sent' => 'Rechnung :invoice über :amount wurde an den Kunden :client versendet.',
    'notification_invoice_viewed' => 'Der Kunde :client hat sich die Rechnung :invoice über :amount angesehen.',
    'reset_password' => 'Du kannst dein Passwort zurücksetzen, indem du auf den folgenden Link klickst:',
    'secure_payment' => 'Sichere Zahlung',
    'card_number' => 'Kartennummer',
    'expiration_month' => 'Ablaufmonat',
    'expiration_year' => 'Ablaufjahr',
    'cvv' => 'Kartenprüfziffer',
    'logout' => 'Abmelden',
    'sign_up_to_save' => 'Melde dich an, um deine Arbeit zu speichern',
    'agree_to_terms' => 'Ich stimme den :terms zu',
    'terms_of_service' => 'Service-Bedingungen',
    'email_taken' => 'Diese E-Mail-Adresse ist bereits registriert',
    'working' => 'Wird bearbeitet',
    'success' => 'Erfolg',
    'success_message' => 'Du hast dich erfolgreich registriert. Bitte besuche den Link in deiner Bestätigungsmail um deine E-Mail-Adresse zu verifizieren.',
    'erase_data' => 'Ihr Konto ist nicht registriert, diese Aktion wird Ihre Daten unwiderruflich löschen.',
    'password' => 'Passwort',
    'pro_plan_product' => 'Pro Plan',
    'pro_plan_success' => 'Danke, dass Sie Invoice Ninja\'s Pro gewählt haben!<p/>&nbsp;<br/>
                          <b>Nächste Schritte</b>Eine bezahlbare Rechnung wurde an die Mailadresse,
                          welche mit Ihrem Account verbunden ist, geschickt. Um alle der umfangreichen
                          Pro Funktionen freizuschalten, folgen Sie bitte den Anweisungen in der Rechnung um ein Jahr
                          die Pro Funktionen zu nutzen.
                          Sie finden die Rechnung nicht? Sie benötigen weitere Hilfe? Wir helfen gerne
                          -- schicken Sie uns doch eine Email an contact@invoice-ninja.com',
    'unsaved_changes' => 'Es liegen ungespeicherte Änderungen vor',
    'custom_fields' => 'Benutzerdefinierte Felder',
    'company_fields' => 'Firmenfelder',
    'client_fields' => 'Kundenfelder',
    'field_label' => 'Feldbezeichnung',
    'field_value' => 'Feldwert',
    'edit' => 'Bearbeiten',
    'set_name' => 'Den Firmennamen setzen',
    'view_as_recipient' => 'Als Empfänger betrachten',
    'product_library' => 'Produktbibliothek',
    'product' => 'Produkt',
    'products' => 'Produkte',
    'fill_products' => 'Produkte automatisch ausfüllen',
    'fill_products_help' => 'Beim Auswählen eines Produktes werden automatisch <strong>Beschreibung und Kosten ausgefüllt</strong>',
    'update_products' => 'Produkte automatisch aktualisieren',
    'update_products_help' => 'Beim Aktualisieren einer Rechnung werden die <strong>Produkte automatisch aktualisiert</strong>',
    'create_product' => 'Produkt erstellen',
    'edit_product' => 'Produkt bearbeiten',
    'archive_product' => 'Produkt archivieren',
    'updated_product' => 'Produkt erfolgreich aktualisiert',
    'created_product' => 'Produkt erfolgreich erstellt',
    'archived_product' => 'Produkt erfolgreich archiviert',
    'pro_plan_custom_fields' => ':link um durch eine Pro-Mitgliedschaft erweiterte Felder zu aktivieren',
    'advanced_settings' => 'Erweiterte Einstellungen',
    'pro_plan_advanced_settings' => ':link um durch eine Pro-Mitgliedschaft erweiterte Einstellungen zu aktivieren',
    'invoice_design' => 'Rechnungsdesign',
    'specify_colors' => 'Farben wählen',
    'specify_colors_label' => 'Wähle die in der Rechnung verwendeten Farben',
    'chart_builder' => 'Diagrammersteller',
    'ninja_email_footer' => 'Erstellt von :site | Erstelle. Sende. Werde bezahlt.',
    'go_pro' => 'Pro werden',
    'quote' => 'Angebot',
    'quotes' => 'Angebote',
    'quote_number' => 'Angebotsnummer',
    'quote_number_short' => 'Angebot #',
    'quote_date' => 'Angebotsdatum',
    'quote_total' => 'Angebotssumme',
    'your_quote' => 'Ihr Angebot',
    'total' => 'Gesamt',
    'clone' => 'Duplizieren',
    'new_quote' => 'Neues Angebot',
    'create_quote' => 'Angebot erstellen',
    'edit_quote' => 'Angebot bearbeiten',
    'archive_quote' => 'Angebot archivieren',
    'delete_quote' => 'Angebot löschen',
    'save_quote' => 'Angebot speichern',
    'email_quote' => 'Angebot per E-Mail senden',
    'clone_quote' => 'Als Angebot kopieren',
    'convert_to_invoice' => 'In Rechnung umwandeln',
    'view_invoice' => 'Rechnung anschauen',
    'view_client' => 'Kunde anschauen',
    'view_quote' => 'Angebot anschauen',
    'updated_quote' => 'Angebot erfolgreich aktualisiert',
    'created_quote' => 'Angebot erfolgreich erstellt',
    'cloned_quote' => 'Angebot erfolgreich dupliziert',
    'emailed_quote' => 'Angebot erfolgreich versendet',
    'archived_quote' => 'Angebot erfolgreich archiviert',
    'archived_quotes' => ':count Angebote erfolgreich archiviert',
    'deleted_quote' => 'Angebot erfolgreich gelöscht',
    'deleted_quotes' => ':count Angebote erfolgreich gelöscht',
    'converted_to_invoice' => 'Angebot erfolgreich in Rechnung umgewandelt',
    'quote_subject' => 'Neues Angebot :number von :account',
    'quote_message' => 'Klicken Sie auf den folgenden Link um das Angebot über :amount anzuschauen.',
    'quote_link_message' => 'Klicke auf den folgenden Link um das Angebot deines Kunden anzuschauen:',
    'notification_quote_sent_subject' => 'Angebot :invoice wurde an :client versendet',
    'notification_quote_viewed_subject' => 'Angebot :invoice wurde von :client angeschaut',
    'notification_quote_sent' => 'Der folgende Kunde :client erhielt das Angebot :invoice über :amount.',
    'notification_quote_viewed' => 'Der folgende Kunde :client hat sich das Angebot :client über :amount angesehen.',
    'session_expired' => 'Deine Sitzung ist abgelaufen.',
    'invoice_fields' => 'Rechnungsfelder',
    'invoice_options' => 'Rechnungsoptionen',
    'hide_paid_to_date' => '"Bereits gezahlt" ausblenden',
    'hide_paid_to_date_help' => '"Bereits gezahlt" nur anzeigen, wenn eine Zahlung eingegangen ist.',
    'charge_taxes' => 'Steuern erheben',
    'user_management' => 'Benutzerverwaltung',
    'add_user' => 'Benutzer hinzufügen',
    'send_invite' => 'Einladung versenden',
    'sent_invite' => 'Einladung erfolgreich versendet',
    'updated_user' => 'Benutzer erfolgreich aktualisiert',
    'invitation_message' => 'Du wurdest von :invitor eingeladen.',
    'register_to_add_user' => 'Bitte registrieren, um einen Benutzer hinzuzufügen',
    'user_state' => 'Status',
    'edit_user' => 'Benutzer bearbeiten',
    'delete_user' => 'Benutzer löschen',
    'active' => 'Aktiv',
    'pending' => 'Ausstehend',
    'deleted_user' => 'Benutzer erfolgreich gelöscht',
    'confirm_email_invoice' => 'Bist du sicher, dass du diese Rechnung per E-Mail versenden möchtest?',
    'confirm_email_quote' => 'Bist du sicher, dass du dieses Angebot per E-Mail versenden möchtest',
    'confirm_recurring_email_invoice' => 'Wiederkehrende Rechnung ist aktiv. Bis du sicher, dass du diese Rechnung weiterhin als E-Mail verschicken möchtest?',
    'confirm_recurring_email_invoice_not_sent' => 'Sind Sie sicher, dass Sie diese wiederkehrende Rechnung aktivieren wollen?',
    'cancel_account' => 'Konto kündigen',
    'cancel_account_message' => 'Warnung: Diese Aktion wird dein Konto unwiderruflich löschen.',
    'go_back' => 'Zurück',
    'data_visualizations' => 'Datenvisualisierungen',
    'sample_data' => 'Beispieldaten werden angezeigt',
    'hide' => 'Verbergen',
    'new_version_available' => 'Eine neue Version von :releases_link ist verfügbar. Du benutzt v:user_version, die aktuelle ist v:latest_version',
    'invoice_settings' => 'Rechnungseinstellungen',
    'invoice_number_prefix' => 'Präfix für Rechnungsnummer',
    'invoice_number_counter' => 'Zähler für Rechnungsnummer',
    'quote_number_prefix' => 'Präfix für Angebotsnummer',
    'quote_number_counter' => 'Zähler für Angebotsnummer',
    'share_invoice_counter' => 'Zähler der Rechnung teilen',
    'invoice_issued_to' => 'Rechnung ausgestellt für',
    'invalid_counter' => 'Bitte setze, um Probleme zu vermeiden, entweder ein Rechnungs- oder Angebotspräfix.',
    'mark_sent' => 'Als versendet markieren',
    'gateway_help_1' => ':link um sich bei Authorize.net anzumelden.',
    'gateway_help_2' => ':link um sich bei Authorize.net anzumelden.',
    'gateway_help_17' => ':link, um deine PayPal API-Signatur zu erhalten.',
    'gateway_help_27' => ':link to sign up for 2Checkout.com. To ensure payments are tracked set :complete_link as the redirect URL under Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link um ein WePay Konto zu erstellen.',
    'more_designs' => 'Weitere Designs',
    'more_designs_title' => 'Zusätzliche Rechnungsdesigns',
    'more_designs_cloud_header' => 'Werde Pro-Mitglied für zusätzliche Rechnungsdesigns',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kaufen',
    'bought_designs' => 'Die zusätzliche Rechnungsdesigns wurden erfolgreich hinzugefügt',
    'sent' => 'Versendet',
    'vat_number' => 'USt-IdNr.',
    'timesheets' => 'Zeittabellen',
    'payment_title' => 'Geben Sie Ihre Rechnungsadresse und Ihre Kreditkarteninformationen ein',
    'payment_cvv' => '*Dies ist die 3-4-stellige Nummer auf der Rückseite Ihrer Kreditkarte',
    'payment_footer1' => '*Die Rechnungsadresse muss mit der Adresse der Kreditkarte übereinstimmen.',
    'payment_footer2' => '*Bitte drücken Sie nur einmal auf "Jetzt bezahlen" - die  Verarbeitung der Transaktion kann bis zu einer Minute dauern.',
    'id_number' => 'Kundennummer',
    'white_label_link' => 'Branding entfernen',
    'white_label_header' => 'Branding entfernen',
    'bought_white_label' => 'Branding-freie Lizenz erfolgreich aktiviert',
    'white_labeled' => 'Branding entfernt',
    'restore' => 'Wiederherstellen',
    'restore_invoice' => 'Rechnung wiederherstellen',
    'restore_quote' => 'Angebot wiederherstellen',
    'restore_client' => 'Kunde wiederherstellen',
    'restore_credit' => 'Guthaben wiederherstellen',
    'restore_payment' => 'Zahlung wiederherstellen',
    'restored_invoice' => 'Rechnung erfolgreich wiederhergestellt',
    'restored_quote' => 'Angebot erfolgreich wiederhergestellt',
    'restored_client' => 'Kunde erfolgreich wiederhergestellt',
    'restored_payment' => 'Zahlung erfolgreich wiederhergestellt',
    'restored_credit' => 'Guthaben erfolgreich wiederhergestellt',
    'reason_for_canceling' => 'Hilf uns bitte, unser Angebot zu verbessern, indem du uns mitteilst, weswegen du dich dazu entschieden hast, unseren Service nicht länger zu nutzen.',
    'discount_percent' => 'Prozent',
    'discount_amount' => 'Wert',
    'invoice_history' => 'Rechnungshistorie',
    'quote_history' => 'Angebotshistorie',
    'current_version' => 'Aktuelle Version',
    'select_version' => 'Version auswählen',
    'view_history' => 'Historie anzeigen',
    'edit_payment' => 'Zahlung bearbeiten',
    'updated_payment' => 'Zahlung erfolgreich aktualisiert',
    'deleted' => 'Gelöscht',
    'restore_user' => 'Benutzer wiederherstellen',
    'restored_user' => 'Benutzer erfolgreich wiederhergestellt',
    'show_deleted_users' => 'Zeige gelöschte Benutzer',
    'email_templates' => 'E-Mail Vorlagen',
    'invoice_email' => 'Rechnungsmail',
    'payment_email' => 'Zahlungsmail',
    'quote_email' => 'Angebotsmail',
    'reset_all' => 'Alle zurücksetzen',
    'approve' => 'Angebot annehmen',
    'token_billing_type_id' => 'Token-Abrechnung',
    'token_billing_help' => 'Zahlungsdetails mit WePay, Stripe, Baintree oder GoCardless speichern.',
    'token_billing_1' => 'Deaktiviert',
    'token_billing_2' => 'Opt-in - Kontrollkästchen wird angezeigt ist aber nicht ausgewählt',
    'token_billing_3' => 'Opt-out - Kontrollkästchen wird angezeigt und ist ausgewählt',
    'token_billing_4' => 'Immer',
    'token_billing_checkbox' => 'Kreditkarteninformationen speichern',
    'view_in_gateway' => 'Auf :gateway anzeigen',
    'use_card_on_file' => 'Verwende gespeicherte Kreditkarte',
    'edit_payment_details' => 'Zahlungsdetails bearbeiten',
    'token_billing' => 'Kreditkarte merken',
    'token_billing_secure' => 'Die Daten werden sicher von :link gespeichert.',
    'support' => 'Support',
    'contact_information' => 'Kontakt-Informationen',
    '256_encryption' => '256-Bit Verschlüsselung',
    'amount_due' => 'Fälliger Betrag',
    'billing_address' => 'Rechnungsadresse',
    'billing_method' => 'Abrechnungsmethode',
    'order_overview' => 'Bestellübersicht',
    'match_address' => '*Die Rechnungsadresse muss mit der Adresse der Kreditkarte übereinstimmen.',
    'click_once' => '*Bitte drücken Sie nur einmal auf "Jetzt bezahlen" - die  Verarbeitung der Transaktion kann bis zu einer Minute dauern.',
    'invoice_footer' => 'Rechnungsfußzeile',
    'save_as_default_footer' => 'Als Standard-Fußzeile speichern',
    'token_management' => 'Token Verwaltung',
    'tokens' => 'Token',
    'add_token' => 'Token hinzufügen',
    'show_deleted_tokens' => 'Zeige gelöschte Token',
    'deleted_token' => 'Token erfolgreich gelöscht',
    'created_token' => 'Token erfolgreich erstellt',
    'updated_token' => 'Token erfolgreich aktualisiert',
    'edit_token' => 'Token bearbeiten',
    'delete_token' => 'Token löschen',
    'token' => 'Token',
    'add_gateway' => 'Zahlungsanbieter hinzufügen',
    'delete_gateway' => 'Zahlungsanbieter löschen',
    'edit_gateway' => 'Zahlungsanbieter bearbeiten',
    'updated_gateway' => 'Zahlungsanbieter aktualisiert',
    'created_gateway' => 'Zahlungsanbieter erfolgreich hinzugefügt',
    'deleted_gateway' => 'Zahlungsanbieter erfolgreich gelöscht',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Kreditkarte',
    'change_password' => 'Passwort ändern',
    'current_password' => 'Aktuelles Passwort',
    'new_password' => 'Neues Passwort',
    'confirm_password' => 'Passwort bestätigen',
    'password_error_incorrect' => 'Das aktuelle Passwort ist nicht korrekt.',
    'password_error_invalid' => 'Das neue Passwort ist ungültig.',
    'updated_password' => 'Passwort erfolgreich aktualisiert',
    'api_tokens' => 'API Token',
    'users_and_tokens' => 'Benutzer & Token',
    'account_login' => 'Konto Login',
    'recover_password' => 'Passwort wiederherstellen',
    'forgot_password' => 'Passwort vergessen?',
    'email_address' => 'E-Mail-Adresse',
    'lets_go' => 'Auf geht\'s',
    'password_recovery' => 'Passwort-Wiederherstellung',
    'send_email' => 'E-Mail senden',
    'set_password' => 'Passwort festlegen',
    'converted' => 'Umgewandelt',
    'email_approved' => 'Per E-Mail benachrichtigen, wenn ein Angebot  <b>angenommen</b> wurde',
    'notification_quote_approved_subject' => 'Angebot :invoice wurde von :client angenommen.',
    'notification_quote_approved' => 'Der folgende Kunde :client nahm das Angebot :invoice über :amount an.',
    'resend_confirmation' => 'Bestätigungsmail erneut senden',
    'confirmation_resent' => 'Bestätigungsemail wurde erneut versendet',
    'gateway_help_42' => ':link zum Registrieren auf BitPay.<br/>Hinweis: benutze einen Legacy API Key, keinen API token.',
    'payment_type_credit_card' => 'Kreditkarte',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'FAQ',
    'partial' => 'Teil-/Anzahlung',
    'partial_remaining' => ':partial von :balance',
    'more_fields' => 'Weitere Felder',
    'less_fields' => 'Weniger Felder',
    'client_name' => 'Kunde',
    'pdf_settings' => 'PDF-Einstellungen',
    'product_settings' => 'Produkt-Einstellungen',
    'auto_wrap' => 'Automatischer Zeilenumbruch',
    'duplicate_post' => 'Achtung: Die vorherige Seite wurde zweimal übermittelt. Die zweite Übermittlung wurde ignoriert.',
    'view_documentation' => 'Dokumentation anzeigen',
    'app_title' => 'Kostenlose Online Open-Source Rechnungsausstellung',
    'app_description' => 'InvoiceNinja ist eine kostenlose, quelloffene Lösung für die Rechnungsstellung und Abrechnung von Kunden. Mit Invoice Ninja kannst du einfach schöne Rechnungen erstellen und verschicken, von jedem Gerät mit Internetzugang. Deine Kunden können die Rechnungen drucken, als PDF Datei herunterladen und sogar online im System bezahlen.',
    'rows' => 'Zeilen',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomäne',
    'provide_name_or_email' => 'Bitte geben Sie einen Namen oder eine E-Mail-Adresse an',
    'charts_and_reports' => 'Diagramme & Berichte',
    'chart' => 'Diagramm',
    'report' => 'Bericht',
    'group_by' => 'Gruppieren nach',
    'paid' => 'Bezahlt',
    'enable_report' => 'Bericht',
    'enable_chart' => 'Diagramm',
    'totals' => 'Summe',
    'run' => 'Ausführen',
    'export' => 'Exportieren',
    'documentation' => 'Dokumentation',
    'zapier' => 'Zapier',
    'recurring' => 'Wiederkehrend',
    'last_invoice_sent' => 'Letzte Rechnung verschickt am :date',
    'processed_updates' => 'Update erfolgreich abgeschlossen',
    'tasks' => 'Zeiterfassung',
    'new_task' => 'Neue Aufgabe',
    'start_time' => 'Startzeit',
    'created_task' => 'Aufgabe erfolgreich erstellt',
    'updated_task' => 'Aufgabe erfolgreich aktualisiert',
    'edit_task' => 'Aufgabe bearbeiten',
    'clone_task' => 'Aufgabe kopieren',
    'archive_task' => 'Aufgabe archivieren',
    'restore_task' => 'Aufgabe wiederherstellen',
    'delete_task' => 'Aufgabe löschen',
    'stop_task' => 'Aufgabe Anhalten',
    'time' => 'Zeit',
    'start' => 'Starten',
    'stop' => 'Anhalten',
    'now' => 'Jetzt',
    'timer' => 'Zeitmesser',
    'manual' => 'Manuell',
    'date_and_time' => 'Datum & Uhrzeit',
    'second' => 'Sekunde',
    'seconds' => 'Sekunden',
    'minute' => 'Minute',
    'minutes' => 'Minuten',
    'hour' => 'Stunde',
    'hours' => 'Stunden',
    'task_details' => 'Aufgaben-Details',
    'duration' => 'Dauer',
    'time_log' => 'Zeiten',
    'end_time' => 'Endzeit',
    'end' => 'Ende',
    'invoiced' => 'In Rechnung gestellt',
    'logged' => 'Protokolliert',
    'running' => 'Läuft',
    'task_error_multiple_clients' => 'Die Aufgaben können nicht zu verschiedenen Kunden gehören',
    'task_error_running' => 'Bitte beenden Sie laufende Aufgaben zuerst',
    'task_error_invoiced' => 'Aufgaben wurden bereits in Rechnung gestellt',
    'restored_task' => 'Aufgabe erfolgreich wiederhergestellt',
    'archived_task' => 'Aufgabe erfolgreich archiviert',
    'archived_tasks' => ':count Aufgaben wurden erfolgreich archiviert',
    'deleted_task' => 'Aufgabe erfolgreich gelöscht',
    'deleted_tasks' => ':count Aufgaben wurden erfolgreich gelöscht',
    'create_task' => 'Aufgabe erstellen',
    'stopped_task' => 'Aufgabe erfolgreich angehalten',
    'invoice_task' => 'Aufgabe in Rechnung stellen',
    'invoice_labels' => 'Rechnung Spaltenüberschriften',
    'prefix' => 'Präfix',
    'counter' => 'Zähler',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link zum Registrieren auf Dwolla.',
    'partial_value' => 'Muss grösser als Null und kleiner als der Gesamtbetrag sein',
    'more_actions' => 'Weitere Aktionen',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Jetzt Upgraden!',
    'pro_plan_feature1' => 'Unlimitierte Anzahl Kunden erstellen',
    'pro_plan_feature2' => 'Zugriff auf 10 schöne Rechnungsdesigns',
    'pro_plan_feature3' => 'Benutzerdefinierte URLs - "DeineFirma.InvoiceNinja.com"',
    'pro_plan_feature4' => '"Erstellt durch Invoice Ninja" entfernen',
    'pro_plan_feature5' => 'Multi-Benutzer Zugriff & Aktivitätstracking',
    'pro_plan_feature6' => 'Angebote & pro-forma Rechnungen erstellen',
    'pro_plan_feature7' => 'Rechungstitelfelder und Nummerierung anpassen',
    'pro_plan_feature8' => 'PDFs an Kunden-Emails anhängen',
    'resume' => 'Fortfahren',
    'break_duration' => 'Pause',
    'edit_details' => 'Details bearbeiten',
    'work' => 'Arbeiten',
    'timezone_unset' => 'Bitte :link um deine Zeitzone zu setzen',
    'click_here' => 'hier klicken',
    'email_receipt' => 'Zahlungsbestätigung an Kunden per E-Mail senden',
    'created_payment_emailed_client' => 'Zahlung erfolgreich erstellt und Kunde per E-Mail benachrichtigt',
    'add_company' => 'Konto hinzufügen',
    'untitled' => 'Unbenannt',
    'new_company' => 'Neues Konto',
    'associated_accounts' => 'Konten erfolgreich verlinkt',
    'unlinked_account' => 'Konten erfolgreich getrennt',
    'login' => 'Login',
    'or' => 'oder',
    'email_error' => 'Es gab ein Problem beim Senden dieser E-Mail.',
    'confirm_recurring_timing' => 'Beachten Sie: E-Mails werden zu jeder vollen Stunde versendet.',
    'confirm_recurring_timing_not_sent' => 'Beachten Sie: Rechnungen werden zu jeder vollen Stunde erstellt.',
    'payment_terms_help' => 'Setzt das <b>Standardfälligkeitsdatum</b>',
    'unlink_account' => 'Konten trennen',
    'unlink' => 'Trennen',
    'show_address' => 'Adresse anzeigen',
    'show_address_help' => 'Verlange von Kunden, ihre Rechnungsadresse anzugeben',
    'update_address' => 'Adresse aktualisieren',
    'update_address_help' => 'Kundenadresse mit den gemachten Angaben aktualisieren',
    'times' => 'Zeiten',
    'set_now' => 'Auf Jetzt setzen',
    'dark_mode' => 'Dunkler Modus',
    'dark_mode_help' => 'Dunklen Hintergrund für Seitenleisten verwenden',
    'add_to_invoice' => 'Zur Rechnung :invoice hinzufügen',
    'create_new_invoice' => 'Neue Rechnung erstellen',
    'task_errors' => 'Bitte korrigieren Sie alle überlappenden Zeiten',
    'from' => 'Von',
    'to' => 'An',
    'font_size' => 'Schriftgröße',
    'primary_color' => 'Primäre Farbe',
    'secondary_color' => 'Sekundäre Farbe',
    'customize_design' => 'Design Anpassen',
    'content' => 'Inhalt',
    'styles' => 'Stile',
    'defaults' => 'Standards',
    'margins' => 'Außenabstände',
    'header' => 'Kopf',
    'footer' => 'Fußzeile',
    'custom' => 'Benutzerdefiniert',
    'invoice_to' => 'Rechnung an',
    'invoice_no' => 'Rechnung Nr.',
    'quote_no' => 'Angebot Nr.',
    'recent_payments' => 'Kürzliche Zahlungen',
    'outstanding' => 'Ausstehend',
    'manage_companies' => 'Unternehmen verwalten',
    'total_revenue' => 'Gesamteinnahmen',
    'current_user' => 'Aktueller Benutzer',
    'new_recurring_invoice' => 'Neue wiederkehrende Rechnung',
    'recurring_invoice' => 'Wiederkehrende Rechnung',
    'new_recurring_quote' => 'Neues wiederkehrendes Angebot',
    'recurring_quote' => 'Wiederkehrendes Angebot',
    'recurring_too_soon' => 'Es ist zu früh die nächste wiederkehrende Rechnung zu erstellen, die nächste ist am :date geplant',
    'created_by_invoice' => 'Erstellt durch :invoice',
    'primary_user' => 'Primärer Benutzer',
    'help' => 'Hilfe',
    'customize_help' => '<p>Wir verwenden :pdfmake_link, um die Rechnungsdesigns deklarativ zu definieren. Der pdfmake :playground_link bietet eine gute Möglichkeit, die Bibliothek in Aktion zu sehen.</p>
 <p>Wenn du Hilfe bei der Suche nach etwas brauchst, schicke eine Frage an unseren :forum_link mit dem von dir verwendeten Design.</p>',
    'playground' => 'Spielplatz',
    'support_forum' => 'Support-Forum',
    'invoice_due_date' => 'Fälligkeitsdatum',
    'quote_due_date' => 'Gültig bis',
    'valid_until' => 'Gültig bis',
    'reset_terms' => 'Zahlungsbedingungen zurücksetzen',
    'reset_footer' => 'Fußzeile zurücksetzen',
    'invoice_sent' => ':count Rechnung versendet',
    'invoices_sent' => ':count Rechnungen versendet',
    'status_draft' => 'Entwurf',
    'status_sent' => 'Versendet',
    'status_viewed' => 'Angesehen',
    'status_partial' => 'Teilweise',
    'status_paid' => 'Bezahlt',
    'status_unpaid' => 'Unbezahlt',
    'status_all' => 'Alle',
    'show_line_item_tax' => '<b>Steuern für Belegpositionen</b> in der jeweiligen Zeile anzeigen',
    'iframe_url' => 'Webseite',
    'iframe_url_help1' => 'Kopiere den folgenden Code in eine Seite auf deiner Website.',
    'iframe_url_help2' => 'Du kannst diese Funktion testen, in dem du für eine Rechnung \'Als Empfänger betrachten\'. anklickst.',
    'auto_bill' => 'Automatische Verrechnung',
    'military_time' => '24-Stunden-Zeit',
    'last_sent' => 'Zuletzt versendet',
    'reminder_emails' => 'Erinnerungs-Emails',
    'quote_reminder_emails' => 'Angebot Erinngerungs Emails',
    'templates_and_reminders' => 'Vorlagen & Erinnerungen',
    'subject' => 'Betreff',
    'body' => 'Inhalt',
    'first_reminder' => 'Erste Erinnerung',
    'second_reminder' => 'Zweite Erinnerung',
    'third_reminder' => 'Dritte Erinnerung',
    'num_days_reminder' => 'Tage nach Fälligkeit',
    'reminder_subject' => 'Erinnerung: Rechnung :invoice von :account',
    'reset' => 'Zurücksetzen',
    'invoice_not_found' => 'Die gewünschte Rechnung ist nicht verfügbar.',
    'referral_program' => 'Empfehlungs-Programm',
    'referral_code' => 'Empfehlungs-URL',
    'last_sent_on' => 'Zuletzt versendet am :date',
    'page_expire' => 'Diese Seite wird bald ablaufen, :click_here um weiter zu arbeiten',
    'upcoming_quotes' => 'Ausstehende Angebote',
    'expired_quotes' => 'Abgelaufene Angebote',
    'sign_up_using' => 'Anmelden mit',
    'invalid_credentials' => 'Diese Zugangsdaten können wir nicht finden.',
    'show_all_options' => 'Zeige alle Optionen',
    'user_details' => 'Benutzerdaten',
    'oneclick_login' => 'Verbundenes Konto',
    'disable' => 'Deaktivieren',
    'invoice_quote_number' => 'Rechnungs- und Angebotsnummern',
    'invoice_charges' => 'Rechnungsgebühren',
    'notification_invoice_bounced' => 'Die Rechnung :invoice an :contact konnte nicht zugestellt werden.',
    'notification_invoice_bounced_subject' => 'Rechnung :invoice nicht zugestellt.',
    'notification_quote_bounced' => 'Das Angebot :invoice an :contact konnte nicht zugestellt werden.',
    'notification_quote_bounced_subject' => 'Angebot :invoice wurde nicht zugestellt.',
    'custom_invoice_link' => 'Manueller Rechnungs-Link',
    'total_invoiced' => 'Rechnungs-Betrag',
    'open_balance' => 'Offener Betrag',
    'verify_email' => 'Bitte klicken sie auf den Link in der Bestätigungsmail, um die E-Mail-Adresse zu verifizieren.',
    'basic_settings' => 'Allgemeine Einstellungen',
    'pro' => 'Pro',
    'gateways' => 'Zahlungs-Gateways',
    'next_send_on' => 'Nächster Versand: :date',
    'no_longer_running' => 'Diese Rechnung wird momentan nicht automatisch erstellt.',
    'general_settings' => 'Allgemeine Einstellungen',
    'customize' => 'Anpassen',
    'oneclick_login_help' => 'Verbinde ein Benutzerkonto, um dich ohne Passwort anzumelden',
    'referral_code_help' => 'Verdiene Geld, wenn du unsere App online teilst',
    'enable_with_stripe' => 'aktiviere| Benötigt Stripe',
    'tax_settings' => 'Steuer-Einstellungen',
    'create_tax_rate' => 'Neuer Steuersatz',
    'updated_tax_rate' => 'Steuersatz aktualisiert',
    'created_tax_rate' => 'Steuersatz erstellt',
    'edit_tax_rate' => 'Steuersatz bearbeiten',
    'archive_tax_rate' => 'Steuersatz archivieren',
    'archived_tax_rate' => 'Steuersatz archiviert',
    'default_tax_rate_id' => 'Standard-Steuersatz',
    'tax_rate' => 'Steuersatz',
    'recurring_hour' => 'Wiederholende Stunde',
    'pattern' => 'Schema',
    'pattern_help_title' => 'Schema-Hilfe',
    'pattern_help_1' => 'Erstellen Sie benutzerdefinierte Nummernkreise durch eigene Nummernsschemata.',
    'pattern_help_2' => 'Verfügbare Variablen:',
    'pattern_help_3' => 'Zum Beispiel: :example würde zu :value konvertiert werden.',
    'see_options' => 'Optionen ansehen',
    'invoice_counter' => 'Rechnungszähler',
    'quote_counter' => 'Angebotszähler',
    'type' => 'Typ',
    'activity_1' => ':user erstellte Kunde :client',
    'activity_2' => ':user archivierte Kunde :client',
    'activity_3' => ':user löschte Kunde :client',
    'activity_4' => ':user erstellte Rechnung :invoice',
    'activity_5' => ':user aktualisierte Rechnung :invoice',
    'activity_6' => ':user mailte Rechnung :invoice für :client an :contact',
    'activity_7' => ':contact schaute Rechnung :invoice für :client an',
    'activity_8' => ':user archivierte Rechnung :invoice',
    'activity_9' => ':user löschte Rechnung :invoice',
    'activity_10' => ':contact gab Zahlungsinformation :payment über :payment_amount für Rechnung :invoice für Kunde :client',
    'activity_11' => ':user aktualisierte Zahlung :payment',
    'activity_12' => ':user archivierte Zahlung :payment',
    'activity_13' => ':user löschte Zahlung :payment',
    'activity_14' => ':user gab :credit Guthaben ein',
    'activity_15' => ':user aktualisierte :credit Guthaben',
    'activity_16' => ':user archivierte :credit Guthaben',
    'activity_17' => ':user löschte :credit Guthaben',
    'activity_18' => ':user erstellte Angebot :quote',
    'activity_19' => ':user aktualisierte Angebot :quote',
    'activity_20' => ':user mailte Angebot :quote für :client an :contact',
    'activity_21' => ':contact schaute Angebot :quote an',
    'activity_22' => ':user archivierte Angebot :quote',
    'activity_23' => ':user löschte Angebot :quote',
    'activity_24' => ':user stellte Angebot :quote wieder her',
    'activity_25' => ':user stellte Rechnung :invoice wieder her',
    'activity_26' => ':user stellte Kunde :client wieder her',
    'activity_27' => ':user stellte Zahlung :payment wieder her',
    'activity_28' => ':user stellte Guthaben :credit wieder her',
    'activity_29' => ':contact akzeptierte Angebot :quote für :client',
    'activity_30' => ':user hat Lieferant :vendor erstellt',
    'activity_31' => ':user hat Lieferant :vendor archiviert',
    'activity_32' => ':user hat Lieferant :vendor gelöscht',
    'activity_33' => ':user hat Lieferant :vendor wiederhergestellt',
    'activity_34' => ':user erstellte Ausgabe :expense',
    'activity_35' => ':user hat Ausgabe :expense archiviert',
    'activity_36' => ':user hat Ausgabe :expense gelöscht',
    'activity_37' => ':user hat Ausgabe :expense wiederhergestellt',
    'activity_42' => ':user hat Aufgabe :task erstellt',
    'activity_43' => ':user hat Aufgabe :task bearbeitet',
    'activity_44' => ':user hat Aufgabe :task archiviert',
    'activity_45' => ':user hat Aufgabe :task gelöscht',
    'activity_46' => ':user hat Aufgabe :task wiederhergestellt',
    'activity_47' => ':user hat Ausgabe :expense bearbeitet',
    'activity_48' => ':user hat Ticket :ticket bearbeitet',
    'activity_49' => ':user hat Ticket :ticket geschlossen',
    'activity_50' => ':user hat Ticket :ticket zusammengeführt',
    'activity_51' => ':user hat Ticket :ticket aufgeteilt',
    'activity_52' => ':contact hat Ticket :ticket geöffnet',
    'activity_53' => ':contact hat Ticket :ticket wieder geöffnet',
    'activity_54' => ':user hat Ticket :ticket wieder geöffnet',
    'activity_55' => ':contact hat auf Ticket :ticket geantwortet',
    'activity_56' => ':user  hat Ticket :ticket angesehen',

    'payment' => 'Zahlung',
    'system' => 'System',
    'signature' => 'E-Mail-Signatur',
    'default_messages' => 'Standardnachrichten',
    'quote_terms' => 'Angebotsbedingungen',
    'default_quote_terms' => 'Standard-Angebotsbedingungen',
    'default_invoice_terms' => 'Standard-Rechnungsbedingungen',
    'default_invoice_footer' => 'Standard-Fußzeile festlegen',
    'quote_footer' => 'Angebots-Fußzeile',
    'free' => 'Kostenlos',
    'quote_is_approved' => 'Erfolgreich freigegeben',
    'apply_credit' => 'Guthaben anwenden',
    'system_settings' => 'Systemeinstellungen',
    'archive_token' => 'Token archivieren',
    'archived_token' => 'Token erfolgreich archiviert',
    'archive_user' => 'Benutzer archivieren',
    'archived_user' => 'Benutzer erfolgreich archiviert',
    'archive_account_gateway' => 'Zahlungsanbieter löschen',
    'archived_account_gateway' => 'Gateway erfolgreich archiviert',
    'archive_recurring_invoice' => 'Wiederkehrende Rechnung archivieren',
    'archived_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich archiviert',
    'delete_recurring_invoice' => 'Wiederkehrende Rechnung löschen',
    'deleted_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich gelöscht',
    'restore_recurring_invoice' => 'Wiederkehrende Rechnung wiederherstellen',
    'restored_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich wiederhergestellt',
    'archive_recurring_quote' => 'Wiederkehrendes Angebot archivieren',
    'archived_recurring_quote' => 'Wiederkehrendes Angebot erfolgreich archiviert',
    'delete_recurring_quote' => 'Wiederkehrendes Angebot löschen',
    'deleted_recurring_quote' => 'Wiederkehrendes Angebot erfolgreich gelöscht',
    'restore_recurring_quote' => 'Wiederkehrendes Angebot wiederherstellen',
    'restored_recurring_quote' => 'Wiederkehrendes Angebot erfolgreich wiederhergestellt',
    'archived' => 'Archiviert',
    'untitled_account' => 'Unbenannte Firma',
    'before' => 'Vor',
    'after' => 'Nach',
    'reset_terms_help' => 'Auf die Standardzahlungsbedingungen des Kontos zurücksetzen',
    'reset_footer_help' => 'Auf die Standardfußzeile des Kontos zurücksetzen',
    'export_data' => 'Daten exportieren',
    'user' => 'Benutzer',
    'country' => 'Land',
    'include' => 'Hinzufügen',
    'logo_too_large' => 'Ihr Logo ist nur :size. Um eine bessere Darstellung im PDF Dokument zu erhalten, empfehlen wir ein Bild grösser als 200KB',
    'import_freshbooks' => 'Importiere von FreshBooks',
    'import_data' => 'Importiere Daten',
    'source' => 'Quelle',
    'csv' => 'CSV',
    'client_file' => 'Kunden Datei',
    'invoice_file' => 'Rechnungs Datei',
    'task_file' => 'Aufgaben Datei',
    'no_mapper' => 'Kein gültiges Mapping für die Datei',
    'invalid_csv_header' => 'Ungültige CSV Spaltenüberschrift',
    'client_portal' => 'Kunden-Portal',
    'admin' => 'Admin',
    'disabled' => 'Deaktiviert',
    'show_archived_users' => 'Zeige archivierte Benutzer',
    'notes' => 'Notizen',
    'invoice_will_create' => 'Die Rechnung wird erstellt',
    'invoices_will_create' => 'Rechnung wird erstellt',
    'failed_to_import' => 'Die folgenden Daten konnten nicht importiert werden. Entweder sind diese bereits vorhanden oder es fehlen benötigte Felder.',
    'publishable_key' => 'Öffentlicher Schlüssel',
    'secret_key' => 'Geheimer Schlüssel',
    'missing_publishable_key' => 'Legen Sie den Stripe-Schlüssel für einen verbesserten Checkout-Vorgang fest',
    'email_design' => 'E-Mail-Design',
    'due_by' => 'Fällig am :date',
    'enable_email_markup' => 'Markup erlauben',
    'enable_email_markup_help' => 'Machen Sie es einfacher für Ihre Kunden zu bezahlen, indem Sie schema.org Markup zu Ihren E-Mails hinzufügen.',
    'template_help_title' => 'Vorlagen Hilfe',
    'template_help_1' => 'Verfügbare Variablen:',
    'email_design_id' => 'E-Mail-Stil',
    'email_design_help' => 'Lass deine E-Mails durch die Verwendung von HTML Layouts professioneller aussehen.',
    'plain' => 'Einfach',
    'light' => 'Hell',
    'dark' => 'Dunkel',
    'industry_help' => 'Wird genutzt um Vergleiche zwischen den Durchschnittswerten von Firmen ähnlicher Größe und Branche ermitteln zu können.',
    'subdomain_help' => 'Passen Sie die Rechnungslink-Subdomäne an oder stellen Sie die Rechnung auf Ihrer eigenen Webseite zur Verfügung.',
    'website_help' => 'Zeige die Rechnung als iFrame auf deiner eigenen Webseite an',
    'invoice_number_help' => 'Geben Sie einen Präfix oder ein benutzerdefiniertes Schema an, um die Rechnungsnummer dynamisch zu erzeugen.',
    'quote_number_help' => 'Geben Sie einen Präfix oder ein benutzerdefiniertes Schema an, um die Angebotsnummer dynamisch zu erzeugen.',
    'custom_client_fields_helps' => 'Füge ein Kundenfeld hinzu. Optional kann die Feldbezeichnung und der Feldwert auch in PDF-Dokumenten ausgegeben werden.',
    'custom_account_fields_helps' => 'Füge ein Firmenfeld, mit Bezeichnung und zugehörigem Wert, zum Firmen-Detailabschnitt in der Rechnung hinzu.',
    'custom_invoice_fields_helps' => 'Füge ein Rechnungsfeld hinzu. Optional kann die Feldbezeichnung und der Feldwert auch in PDF-Dokumenten ausgegeben werden.',
    'custom_invoice_charges_helps' => 'Füge ein Rechnungsgebührenfeld hinzu. Erfasse die Kosten, wenn eine neue Rechnung erstellt wird und addiere sie in den Zwischensummen der Rechnung.',
    'token_expired' => 'Validierungstoken ist abgelaufen. Bitte probieren Sie es erneut.',
    'invoice_link' => 'Link zur Rechnung',
    'button_confirmation_message' => 'Bitte klicken um Ihre Email-Adresse zu bestätigen.',
    'confirm' => 'Bestätigen',
    'email_preferences' => 'Email Einstellungen',
    'created_invoices' => ':count Rechnung(en) erfolgreich erstellt',
    'next_invoice_number' => 'Die nächste Rechnungsnummer ist :number.',
    'next_quote_number' => 'Die nächste Angebotsnummer ist :number.',
    'days_before' => 'Tage vor dem',
    'days_after' => 'Tage nach dem ',
    'field_due_date' => 'Fälligkeitsdatum',
    'field_invoice_date' => 'Rechnungsdatum',
    'schedule' => 'Zeitgesteuert',
    'email_designs' => 'E-Mail-Designs',
    'assigned_when_sent' => 'Zugewiesen bei Versand',
    'white_label_purchase_link' => 'Kaufe eine Branding-freie Lizenz',
    'expense' => 'Ausgabe',
    'expenses' => 'Ausgaben',
    'new_expense' => 'Ausgabe eingeben',
    'enter_expense' => 'Ausgabe eingeben',
    'vendors' => 'Lieferanten',
    'new_vendor' => 'Neuer Lieferant',
    'payment_terms_net' => 'Netto',
    'vendor' => 'Lieferant',
    'edit_vendor' => 'Lieferant Bearbeiten',
    'archive_vendor' => 'Lieferant Archivieren',
    'delete_vendor' => 'Lieferant Löschen',
    'view_vendor' => 'Lieferant Ansehen',
    'deleted_expense' => 'Ausgabe erfolgreich gelöscht',
    'archived_expense' => 'Ausgabe erfolgreich archiviert',
    'deleted_expenses' => ' Ausgaben erfolgreich gelöscht',
    'archived_expenses' => 'Ausgaben erfolgreich archiviert',
    'expense_amount' => 'Ausgabensumme',
    'expense_balance' => 'Ausgabendifferenz',
    'expense_date' => 'Ausgabendatum',
    'expense_should_be_invoiced' => 'Soll diese Ausgabe in Rechnung gestellt werden?',
    'public_notes' => 'Öffentliche Notizen',
    'invoice_amount' => 'Rechnungssumme',
    'exchange_rate' => 'Wechselkurs',
    'yes' => 'Ja',
    'no' => 'Nein',
    'should_be_invoiced' => 'Sollte in Rechnung gestellt werden',
    'view_expense' => 'Ausgabe # :expense ansehen',
    'edit_expense' => 'Ausgabe Bearbeiten',
    'archive_expense' => 'Ausgabe Archivieren',
    'delete_expense' => 'Ausgabe Löschen',
    'view_expense_num' => 'Ausgabe # :expense',
    'updated_expense' => 'Ausgabe erfolgreich aktualisiert',
    'created_expense' => 'Ausgabe erfolgreich erstellt',
    'enter_expense' => 'Ausgabe eingeben',
    'view' => 'Ansehen',
    'restore_expense' => 'Ausgabe Wiederherstellen',
    'invoice_expense' => 'Ausgabe abrechnen',
    'expense_error_multiple_clients' => 'Die Ausgaben können nicht zu unterschiedlichen Kunden gehören',
    'expense_error_invoiced' => 'Ausgabe wurde bereits in Rechnung gestellt',
    'convert_currency' => 'Währung umrechnen',
    'num_days' => 'Anzahl Tage',
    'create_payment_term' => 'Erstelle Zahlungsbedingungen',
    'edit_payment_terms' => 'Bearbeite Zahlungsbedingungen',
    'edit_payment_term' => 'Bearbeite Zahlungsbedingungen',
    'archive_payment_term' => 'Archiviere Zahlungsbedingungen',
    'recurring_due_dates' => 'Wiederkehrende Rechnungen Fälligkeitsdatum',
    'recurring_due_date_help' => '<p>Legt automatisch ein Fälligkeitsdatem für die Rechnung fest.</p>
<p>Auf einen monatlichen oder jährlichen Wiederkehrungszyklus eingestellte Rechnungen werden erst im nächsten Monat bzw. Jahr fällig, sofern das Fälligkeitsdatum älter oder gleich dem Erstellungsdatum der Rechnung ist. Am 29. oder 30. eines Monats fällige Rechnungen werden stattdessen am letzten vorhandenen Tag eines Monats fällig, wenn er diese Tage nicht beinhaltet.</p>
<p>Auf einen wöchentlichen Wiederkehrungszyklus eingestellte Rechnungen, werden erst in der nächsten Woche fällig, wenn der Wochentag mit dem Wochentag des Erstellungsdatums übereinstimmt.</p>
<p>Zum Beispiel:</p>
<ul>
<li>Heute ist der 15. Januar, das Fälligkeitsdatum ist der 1. eines Monats. Das nächste Fälligkeitsdatum entspricht dem 1. des nächsten Monats, also dem 1. Februar.</li>
<li>Heute ist der 15. Januar, das Fälligkeitsdatum ist der letzte Tag eines Monats. Das nächste Fälligkeitsdatum entspricht dem letzten Tag des aktuellen Monats, also dem 31. Januar.
</li>
<li>Heute ist der 15. Januar, das Fälligkeitsdatum ist der 15. eines Moants. Das nächste Fälligkeitsdatum entspricht dem 15. des <strong>nächsten</strong> Monats, also dem 15. Februar.
</li>
<li>Heute ist Freitag, das Fälligkeitsdatum ist der Freitag einer jeden Woche. Das nächste Fälligkeitsdatum entspricht dem nächsten Freitag, also nicht heute.
</li>
</ul>',
    'due' => 'Fällig',
    'next_due_on' => 'Nächste Fälligkeit: :date',
    'use_client_terms' => 'Kunden-Bedingungen verwenden',
    'day_of_month' => ':ordinal Tag des Monats',
    'last_day_of_month' => 'Letzter Tag des Monats',
    'day_of_week_after' => ':ordinal :day nach',
    'sunday' => 'Sonntag',
    'monday' => 'Montag',
    'tuesday' => 'Dienstag',
    'wednesday' => 'Mittwoch',
    'thursday' => 'Donnerstag',
    'friday' => 'Freitag',
    'saturday' => 'Samstag',
    'header_font_id' => 'Kopf-Schriftart',
    'body_font_id' => 'Body-Schriftart',
    'color_font_help' => 'Info: Die primäre Farbe und Schriftarten werden auch im Kundenportal und im individuellen E-Mail-Design verwendet.',
    'live_preview' => 'Live-Vorschau',
    'invalid_mail_config' => 'E-Mails können nicht gesendet werden. Bitte überprüfen Sie, ob die E-Mail-Einstellungen korrekt sind.',
    'invoice_message_button' => 'Um Ihre Rechnung über :amount zu sehen, klicken Sie die Schaltfläche unten.',
    'quote_message_button' => 'Um Ihr Angebot über :amount zu sehen, klicken Sie die Schaltfläche unten.',
    'payment_message_button' => 'Vielen Dank für Ihre Zahlung von :amount.',
    'payment_type_direct_debit' => 'Einzugsermächtigung',
    'bank_accounts' => 'Kreditkarten & Banken',
    'add_bank_account' => 'Bankverbindung hinzufügen',
    'setup_account' => 'Konto einrichten',
    'import_expenses' => 'Ausgaben importieren',
    'bank_id' => 'Bank',
    'integration_type' => 'Integrations-Typ',
    'updated_bank_account' => 'Bankverbindung erfolgreich aktualisiert',
    'edit_bank_account' => 'Bankverbindung bearbeiten',
    'archive_bank_account' => 'Bankverbindung archivieren',
    'archived_bank_account' => 'Bankverbindung erfolgreich archiviert',
    'created_bank_account' => 'Bankverbindung erfolgreich erstellt',
    'validate_bank_account' => 'Bankverbindung bestätigen',
    'bank_password_help' => 'Info: Ihr Passwort wird sicher übertragen und zu keiner Zeit auf unseren Servern gespeichert.',
    'bank_password_warning' => 'Warnung: Ihr Passwort könnte in Klartext übertragen werden, wir empfehlen Ihnen HTTPS zu verwenden.',
    'username' => 'Benutzername',
    'account_number' => 'Kontonummer',
    'account_name' => 'Kontobezeichnung',
    'bank_account_error' => 'Fehler beim Abrufen der Kontodaten. Bitte überprüfen Sie Ihre Anmeldeinformationen.',
    'status_approved' => 'Angenommen',
    'quote_settings' => 'Angebotseinstellungen',
    'auto_convert_quote' => 'Automatisch konvertieren',
    'auto_convert_quote_help' => 'Das Angebot automatisch in eine Rechnung umwandeln wenn es vom Kunden angenommen wird.',
    'validate' => 'Überprüfe',
    'info' => 'Info',
    'imported_expenses' => 'Erfolgreich :count_vendors Lieferant(en) und :count_expenses Ausgabe(n) erstellt',
    'iframe_url_help3' => 'Anmerkung: Wenn Sie vorhaben Kreditkarten zu akzeptieren, empfehlen wir ausdrücklich die Verwendung von HTTPS-Webseitenverschlüsselung auf Ihrer Webseite.',
    'expense_error_multiple_currencies' => 'Die Ausgaben dürfen keine unterschiedlichen Währungen haben.',
    'expense_error_mismatch_currencies' => 'Die Währung des Kunden entspricht nicht der Währung der Ausgabe.',
    'trello_roadmap' => 'Trello Entwicklungskarte',
    'header_footer' => 'Kopf-/Fußzeile',
    'first_page' => 'Erste Seite',
    'all_pages' => 'Alle Seiten',
    'last_page' => 'Letzte Seite',
    'all_pages_header' => 'Zeige Kopf auf',
    'all_pages_footer' => 'Zeige Fußzeilen auf',
    'invoice_currency' => 'Rechnungs-Währung',
    'enable_https' => 'Wir empfehlen dringend HTTPS zu verwenden, um Kreditkarten online zu akzeptieren.',
    'quote_issued_to' => 'Angebot ausgefertigt an',
    'show_currency_code' => 'Währungscode',
    'free_year_message' => 'Dein Account wurde für ein Jahr kostenlos auf den PRO-Tarif hochgestuft.',
    'trial_message' => 'Ihr Account erhält zwei Wochen Probemitgliedschaft für unseren Pro-Plan.',
    'trial_footer' => 'Die Testversion deines Pro-Tarifs endet in :count Tagen. :link jetzt hochstufen.',
    'trial_footer_last_day' => 'Heute ist der letzte Tag Ihrer kostenlosen Probezeit, :link um das Upgrade jetzt durchzuführen.',
    'trial_call_to_action' => 'Kostenlose Probezeit starten',
    'trial_success' => 'Erfolgreich eine 2-Wochen Testversion aktiviert',
    'overdue' => 'Überfällig',


    'white_label_text' => 'Kaufen Sie eine Ein-Jahres-"White Label"-Lizenz für $:price um das Invoice Ninja Branding von den Rechnungen und dem Kundenportal zu entfernen.',
    'user_email_footer' => 'Um deine E-Mail-Benachrichtigungen anzupassen besuche bitte :link',
    'reset_password_footer' => 'Wenn du das Zurücksetzen des Passworts nicht beantragt hast, benachrichtige bitte unseren Support: :email',
    'limit_users' => 'Entschuldige, das würde das Limit von :limit Benutzern überschreiten',
    'more_designs_self_host_header' => 'Erhalte 6 zusätzliche Rechnungsdesigns für nur $:price',
    'old_browser' => 'Bitte verwende einen :link',
    'newer_browser' => 'neuerer Browser',
    'white_label_custom_css' => ':link für $:price um ein individuelles Styling zu ermöglichen und unser Projekt zu unterstützen.',
    'bank_accounts_help' => 'Fügen Sie eine Bankverbindung hinzu, um automatisch Ausgaben zu importieren und Lieferanten zu erstellen. Unterstützt American Express und :link',
    'us_banks' => '400+ US-Banken',

    'pro_plan_remove_logo' => ':link, um das InvoiceNinja-Logo zu entfernen, indem du dem Pro Plan beitrittst',
    'pro_plan_remove_logo_link' => 'Klicke hier',
    'invitation_status_sent' => 'Gesendet',
    'invitation_status_opened' => 'Geöffnet',
    'invitation_status_viewed' => 'Gesehen',
    'email_error_inactive_client' => 'Emails können nicht zu inaktiven Kunden gesendet werden',
    'email_error_inactive_contact' => 'Emails können nicht zu inaktiven Kontakten gesendet werden',
    'email_error_inactive_invoice' => 'Emails können nicht zu inaktiven Rechnungen gesendet werden',
    'email_error_inactive_proposal' => 'Emails können nicht für inaktive Vorschläge gesendet werden',
    'email_error_user_unregistered' => 'Bitte registrieren Sie sich um Emails zu versenden',
    'email_error_user_unconfirmed' => 'Bitte bestätigen Sie Ihr Konto um Emails zu senden',
    'email_error_invalid_contact_email' => 'Ungültige Kontakt Email Adresse',

    'navigation' => 'Navigation',
    'list_invoices' => 'Rechnungen anzeigen',
    'list_clients' => 'Kunden anzeigen',
    'list_quotes' => 'Angebote anzeigen',
    'list_tasks' => 'Aufgaben anzeigen',
    'list_expenses' => 'Ausgaben anzeigen',
    'list_recurring_invoices' => 'Wiederkehrende Rechnungen anzeigen',
    'list_payments' => 'Zahlungen anzeigen',
    'list_credits' => 'Guthaben anzeigen',
    'tax_name' => 'Steuersatz Name',
    'report_settings' => 'Bericht-Einstellungen',
    'search_hotkey' => 'Kürzel ist /',

    'new_user' => 'Neuer Benutzer',
    'new_product' => 'Neues Produkt',
    'new_tax_rate' => 'Neuer Steuersatz',
    'invoiced_amount' => 'Rechnungsbetrag',
    'invoice_item_fields' => 'Rechnungspositionsfeld',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Wiederkehrende Nummer',
    'recurring_invoice_number_prefix_help' => 'Gib ein Präfix an, das der Rechnungsnummer für wiederkehrende Rechnungen hinzugefügt werden soll.',

    // Client Passwords
    'enable_portal_password' => 'Rechnungen mit Passwort schützen',
    'enable_portal_password_help' => 'Erlaubt Ihnen ein Passwort für jeden Kontakt zu erstellen. Wenn ein Passwort erstellt wurde, muss der Kunde dieses eingeben, bevor er eine Rechnung ansehen darf.',
    'send_portal_password' => 'Automatisch generieren',
    'send_portal_password_help' => 'Wenn kein Passwort gesetzt wurde, wird eins generiert und mit der ersten Rechnung verschickt.',

    'expired' => 'Abgelaufen',
    'invalid_card_number' => 'Die Kreditkartennummer ist nicht gültig.',
    'invalid_expiry' => 'Das Ablaufdatum ist nicht gültig.',
    'invalid_cvv' => 'Der CVV Code ist nicht gültig.',
    'cost' => 'Kosten',
    'create_invoice_for_sample' => 'Hinweis: Erstellen Sie Ihre erste Rechnung um hier eine Vorschau zu sehen.',

    // User Permissions
    'owner' => 'Eigentümer',
    'administrator' => 'Administrator',
    'administrator_help' => 'Dem Benutzer erlauben, andere Benutzer zu administrieren, Einstellungen zu ändern und alle Einträge zu bearbeiten',
    'user_create_all' => 'Erstelle Kunden, Rechnungen, usw.',
    'user_view_all' => 'Alle Kunden, Rechnungen, usw. ansehen',
    'user_edit_all' => 'Alle Kunden, Rechnungen, usw. bearbeiten',
    'gateway_help_20' => ':link um sich bei Sage Pay zu registrieren.',
    'gateway_help_21' => ':link um sich bei Sage Pay zu registrieren.',
    'partial_due' => 'Anzahlung',
    'restore_vendor' => 'Lieferant wiederherstellen',
    'restored_vendor' => 'Lieferant erfolgreich wiederhergestellt',
    'restored_expense' => 'Ausgabe erfolgreich wiederhergestellt',
    'permissions' => 'Berechtigungen',
    'create_all_help' => 'Dem Benutzer erlauben, Einträge zu erstellen und zu verändern',
    'view_all_help' => 'Dem Benutzer erlauben, nicht selbst erstellte Einträge anzusehen',
    'edit_all_help' => 'Dem Benutzer erlauben, nicht selbst erstellte Einträge zu verändern',
    'view_payment' => 'Zahlung zeigen',

    'january' => 'Januar',
    'february' => 'Februar',
    'march' => 'März',
    'april' => 'April',
    'may' => 'Mai',
    'june' => 'Juni',
    'july' => 'Juli',
    'august' => 'August',
    'september' => 'September',
    'october' => 'Oktober',
    'november' => 'November',
    'december' => 'Dezember',

    // Documents
    'documents_header' => 'Dokumente:',
    'email_documents_header' => 'Dokumente:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Endgültig lieferbar.zip',
    'quote_documents' => 'Angebots-Dateien',
    'invoice_documents' => 'Rechnungs-Dateien',
    'expense_documents' => 'Ausgaben-Dateien',
    'invoice_embed_documents' => 'Dokumente einbetten',
    'invoice_embed_documents_help' => 'Bildanhänge zu den Rechnungen hinzufügen.',
    'document_email_attachment' => 'Dokumente anhängen',
    'ubl_email_attachment' => 'UBL anhängen',
    'download_documents' => 'Dokumente herunterladen (:size)',
    'documents_from_expenses' => 'Von Kosten:',
    'dropzone_default_message' => 'Dateien hierhin ziehen oder klicken, um Dateien hochzuladen',
    'dropzone_default_message_disabled' => 'Uploads deaktiviert',
    'dropzone_fallback_message' => 'Ihr Browser unterstützt keine "Drag \'n Drop" Datei-Uploads.',
    'dropzone_fallback_text' => 'Bitte verwenden Sie das untere Formular als Ausweichlösung, um Ihre Dateien wie in alten Zeiten hochladen zu können.',
    'dropzone_file_too_big' => 'Die Datei ist zu groß ({{filesize}}MiB). max. Dateigröße: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Du kannst Dateien von diesem Typ nicht hochladen.',
    'dropzone_response_error' => 'Der Server hat mit dem Code: {{statusCode}} geantwortet.',
    'dropzone_cancel_upload' => 'Hochladen abbrechen',
    'dropzone_cancel_upload_confirmation' => 'Bist du dir sicher, dass du das Hochladen abbrechen möchtest?',
    'dropzone_remove_file' => 'Datei löschen',
    'documents' => 'Dokumente',
    'document_date' => 'Dokumenten Datum',
    'document_size' => 'Größe',

    'enable_client_portal' => 'Kundenportal',
    'enable_client_portal_help' => 'Zeige das Dashboard im Kundenportal.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Zeige/Verstecke die Dashboard Seite im Kundenportal',

    // Plans
    'account_management' => 'Kontoverwaltung',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Upgraden',
    'plan_change' => 'Wechsle den Plan',
    'pending_change_to' => 'Änderungen zu',
    'plan_changes_to' => ':plan am :date',
    'plan_term_changes_to' => ':plan (:term) am :date',
    'cancel_plan_change' => 'Veränderungen abbrechen',
    'plan' => 'Plan',
    'expires' => 'Läuft ab',
    'renews' => 'Erneuern',
    'plan_expired' => ':plan Plan abgelaufen',
    'trial_expired' => ':plan Probezeit abgelaufen',
    'never' => 'Niemals',
    'plan_free' => 'kostenlos',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Unternehmen',
    'plan_white_label' => 'Self Hosted (Branding entfernt)',
    'plan_free_self_hosted' => 'Self Hosted (Kostenlos)',
    'plan_trial' => 'Test',
    'plan_term' => 'Laufzeit',
    'plan_term_monthly' => 'Monatlich',
    'plan_term_yearly' => 'Jährlich',
    'plan_term_month' => 'Monat',
    'plan_term_year' => 'Jahr',
    'plan_price_monthly' => ':price$ pro Monat',
    'plan_price_yearly' => ':price$ pro Jahr',
    'updated_plan' => 'Aktualisierte Zahlungsplan-Einstellungen',
    'plan_paid' => 'Laufzeit begonnen',
    'plan_started' => 'Zahlungsplan gestartet',
    'plan_expires' => 'Zahlungsplan läuft ab',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Einjährige Registrierung für den Invoice Ninja Pro-Plan.',
    'pro_plan_month_description' => 'Einmonatliche Registrierung für den Invoice Ninja Pro-Plan.',
    'enterprise_plan_product' => 'Unternehmensplan',
    'enterprise_plan_year_description' => 'Einjährige Registrierung für den Invoice Ninja Enterprise-Plan.',
    'enterprise_plan_month_description' => 'Einmonatliche Registrierung für den Invoice Ninja Enterprise-Plan.',
    'plan_credit_product' => 'Gutschrift',
    'plan_credit_description' => 'Gutschrift für nicht genutzte Laufzeit',
    'plan_pending_monthly' => 'Wird zu monatlich am :date gewechselt',
    'plan_refunded' => 'Eine Erstattung wurde erteilt.',

    'live_preview' => 'Live-Vorschau',
    'page_size' => 'Seitengröße',
    'live_preview_disabled' => 'Live-Vorschau wurde deaktiviert, um die gewählte Schriftart unterstützen zu können',
    'invoice_number_padding' => 'Innenabstand',
    'preview' => 'Vorschau',
    'list_vendors' => 'Lieferanten anzeigen',
    'add_users_not_supported' => 'Führen Sie ein Upgrade auf den Enterprise-Plan durch, um zusätzliche Nutzer zu Ihrem Account hinzufügen zu können.',
    'enterprise_plan_features' => 'Der Enterprise-Plan fügt Unterstützung für mehrere Nutzer und Dateianhänge hinzu. :link um die vollständige Liste der Features zu sehen.',
    'return_to_app' => 'Zurück zur App',


    // Payment updates
    'refund_payment' => 'Zahlung erstatten',
    'refund_max' => 'Max:',
    'refund' => 'Erstattung',
    'are_you_sure_refund' => 'Ausgewählte Zahlungen erstatten?',
    'status_pending' => 'Ausstehend',
    'status_completed' => 'Abgeschlossen',
    'status_failed' => 'Fehlgeschlagen',
    'status_partially_refunded' => 'Teilweise erstattet',
    'status_partially_refunded_amount' => ':amount erstattet',
    'status_refunded' => 'Erstattet',
    'status_voided' => 'Abgebrochen',
    'refunded_payment' => 'Zahlung erstattet',
    'activity_39' => ':user brach eine Zahlung über :payment_amount ab :payment',
    'activity_40' => ':user hat :adjustment von :payment_amount der Zahlung :payment zurück erstattet',
    'card_expiration' => 'Ablaufdatum:&nbsp:expires',

    'card_creditcardother' => 'Unbekannt',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Akzeptiere US-Bank-Transfers',
    'stripe_ach_help' => 'ACH-Untetstützung muss aktiviert werden unter :link.',
    'ach_disabled' => 'Es wurde bereits ein anderes Gateway für den Bankeinzug eingerichtet.',

    'plaid' => 'Plaid',
    'client_id' => 'Kundennummer',
    'secret' => 'Passwort',
    'public_key' => 'Öffentlicher Schlüssel',
    'plaid_optional' => '(optional)',
    'plaid_environment_help' => 'Wenn ein Stripe-Testschlüssel angegeben wird, wird die Entwicklungsumgebung (Tartan) von Plaid verwendet.',
    'other_providers' => 'Andere Anbieter',
    'country_not_supported' => 'Dieses Land wird nicht unterstützt.',
    'invalid_routing_number' => 'Die Bankleitzahl ist nicht gültig.',
    'invalid_account_number' => 'Die Kontonummer ist nicht gültig.',
    'account_number_mismatch' => 'Die Kontonummern stimmen nicht überein.',
    'missing_account_holder_type' => 'Bitte wählen Sie ein Einzel- oder Firmenkonto aus.',
    'missing_account_holder_name' => 'Bitten geben Sie den Namen des Kontoinhabers ein.',
    'routing_number' => 'Bankleitzahl',
    'confirm_account_number' => 'Kontonummer bestätigen',
    'individual_account' => 'Einzelkonto',
    'company_account' => 'Firmenkonto',
    'account_holder_name' => 'Name des Kontoinhabers',
    'add_account' => 'Konto hinzufügen',
    'payment_methods' => 'Zahlungsarten',
    'complete_verification' => 'Überprüfung abschliessen',
    'verification_amount1' => 'Betrag 1',
    'verification_amount2' => 'Betrag 2',
    'payment_method_verified' => 'Überprüfung erfolgreich abgeschlossen',
    'verification_failed' => 'Überprüfung fehlgeschlagen',
    'remove_payment_method' => 'Zahlungsart entfernen',
    'confirm_remove_payment_method' => 'Wollen Sie diese Zahlungart wirklich entfernen?',
    'remove' => 'Entfernen',
    'payment_method_removed' => 'Zahlungsart entfernt.',
    'bank_account_verification_help' => 'Wir haben zwei Überweisungen auf Ihr Konto mit dem Verwendungszweck "VERIFICATION" getätigt. Diese Überweisungen werden 1-2 Werktage benötigen, bis sie auf Ihrem Kontoauszug zu sehen sind. Bitte geben Sie die Überweisungssummen unten ein.',
    'bank_account_verification_next_steps' => 'Wir haben zwei Überweisungen auf Ihr Konto mit dem Verwendungszweck "VERIFICATION" getätigt. Diese Überweisungen werden 1-2 Werktage benötigen, bis sie auf Ihrem Kontoauszug zu sehen sind.
Sobald Sie die Beträge erhalten haben, kommen Sie bitte wieder zurück zu dieser Zahlungsmethoden-Seite und klicken Sie auf "Complete Verification" neben Ihrem Konto.',
    'unknown_bank' => 'Bank unbekannt',
    'ach_verification_delay_help' => 'Nach der Überprüfung können Sie das Konto sofort benutzen. Die Überprüfung dauert in der Regel 1-2 Arbeitstage.',
    'add_credit_card' => 'Kreditkarte hinzufügen',
    'payment_method_added' => 'Zahlungsart hinzugefügt.',
    'use_for_auto_bill' => 'Für Autobill verwenden',
    'used_for_auto_bill' => 'Autobill Zahlungsmethode',
    'payment_method_set_as_default' => 'Autobill Zahlungsmethode als Standard einstellen.',
    'activity_41' => ':payment_amount Zahlung (:payment) schlug fehl',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Sie müssen :link',
    'stripe_webhook_help_link_text' => 'fügen Sie diese URL als Endpunkt zu Stripe hinzu',
    'gocardless_webhook_help_link_text' => 'diese URL als Endpunkt in GoCardless hinzufügen',
    'payment_method_error' => 'Es gab einen Fehler beim Hinzufügen Ihrer Zahlungsmethode. Bitte versuchen Sie es später erneut.',
    'notification_invoice_payment_failed_subject' => 'Zahlung für Rechnung :invoice fehlgeschlagen',
    'notification_invoice_payment_failed' => 'Eine Zahlung Ihres Kunden :client für die Rechnung :invoice schlug fehl. Die Zahlung wurde als Fehlgeschlagen markiert und :amount wurde dem Saldo Ihres Kunden hinzugefügt.',
    'link_with_plaid' => 'Konto sofort mit Plaid verknüpfen',
    'link_manually' => 'Manuell verbinden',
    'secured_by_plaid' => 'Gesichert durch Plaid',
    'plaid_linked_status' => 'Ihr Konto bei :bank',
    'add_payment_method' => 'Zahlungsart hinzufügen',
    'account_holder_type' => 'Art des Kontoinhabers',
    'ach_authorization' => 'Ich autorisiere :company mein Bankkonto für künftige Zahlungen zu nutzen und, falls nötig, elektronisch mein Konto zu belasten, um falsche Abbuchungen korrigieren zu können. Ich bestätige verstanden zu haben, dass ich diese Autorisierung jederzeit durch Entfernung dieser Zahlungsmethode oder durch Kontaktaufnahme mit :email zurücknehmen kann.',
    'ach_authorization_required' => 'Sie müssen den ACH-Transaktionen zustimmen.',
    'off' => 'Aus',
    'opt_in' => 'Anmelden',
    'opt_out' => 'Abmelden',
    'always' => 'Immer',
    'opted_out' => 'Abgemeldet',
    'opted_in' => 'Angemeldet',
    'manage_auto_bill' => 'Auto-bill managen',
    'enabled' => 'Aktiviert',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'PayPal Zahlungen mittels BrainTree aktivieren',
    'braintree_paypal_disabled_help' => 'Das PayPal Gateway bearbeitet PayPal-Zahlungen',
    'braintree_paypal_help' => 'Sie müssen auch :link',
    'braintree_paypal_help_link_text' => 'PayPal Konto mit BrainTree verknüpfen',
    'token_billing_braintree_paypal' => 'Zahlungsdetails speichern',
    'add_paypal_account' => 'PayPal Konto hinzufügen',


    'no_payment_method_specified' => 'Keine Zahlungsart angegeben',
    'chart_type' => 'Diagrammtyp',
    'format' => 'Format',
    'import_ofx' => 'OFX importieren',
    'ofx_file' => 'OFX Datei',
    'ofx_parse_failed' => 'Einlesen der OFX Datei fehlgeschlagen',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Mit WePay anmelden',
    'use_another_provider' => 'Anderen Anbieter verwenden',
    'company_name' => 'Firmenname',
    'wepay_company_name_help' => 'Das erscheint auf den Kontoauszügen des Kunden.',
    'wepay_description_help' => 'Zweck des Kontos.',
    'wepay_tos_agree' => 'Ich stimme den :link zu',
    'wepay_tos_link_text' => 'WePay Servicebedingungen',
    'resend_confirmation_email' => 'Bestätigungsemail nochmal senden',
    'manage_account' => 'Account managen',
    'action_required' => 'Handeln erforderlich',
    'finish_setup' => 'Setup abschliessen',
    'created_wepay_confirmation_required' => 'Bitte prüfen Sie Ihr E-Mail Konto und bestätigen Sie Ihre E-Mail Adresse bei WePay.',
    'switch_to_wepay' => 'Wechsel zu WePay',
    'switch' => 'Switch',
    'restore_account_gateway' => 'Zahlungsanbieter wiederherstellen',
    'restored_account_gateway' => 'Zahlungsanbieter erfolgreich wiederhergestellt',
    'united_states' => 'Vereinigte Staaten von Amerika',
    'canada' => 'Kanada',
    'accept_debit_cards' => 'Debitkarten aktzeptieren',
    'debit_cards' => 'Debitkarten',

    'warn_start_date_changed' => 'Die nächste Rechnung wird zum neuen Startdatum versendet.',
    'warn_start_date_changed_not_sent' => 'Die nächste Rechnung wird zum neuen Startdatum versendet.',
    'original_start_date' => 'Originales Startdatum',
    'new_start_date' => 'Neues Startdatum',
    'security' => 'Sicherheit',
    'see_whats_new' => 'Neu in v:version',
    'wait_for_upload' => 'Bitte warten Sie bis der Dokumentenupload abgeschlossen wurde.',
    'upgrade_for_permissions' => 'Führen Sie ein Upgrade auf unseren Enterprise-Plan durch um Zugriffsrechte zu aktivieren.',
    'enable_second_tax_rate' => 'Aktiviere Spezifizierung einer <b>zweiten Steuerrate</b>',
    'payment_file' => 'Zahlungsdatei',
    'expense_file' => 'Ausgabenakte',
    'product_file' => 'Produktdatei',
    'import_products' => 'Produkte importieren',
    'products_will_create' => 'Produkte werden erstellt werden',
    'product_key' => 'Produkt',
    'created_products' => ':count Produkt(e) erfolgreich erstellt bzw. aktualisiert',
    'export_help' => 'Nutzen Sie JSON wenn Sie die Daten in Invoice Ninja importieren wollen.<br/>Die Datei beinhaltet Kunden, Produkte, Rechnungen, Angebote und Zahlungen.',
    'selfhost_export_help' => 'Wir empfehlen die Verwendung von mysqldump zur Herstellung einer vollständigen Sicherheitskopie.',
    'JSON_file' => 'JSON Datei',

    'view_dashboard' => 'Übersicht anzeigen',
    'client_session_expired' => 'Sitzung abgelaufen',
    'client_session_expired_message' => 'Ihre Sitzung ist abgelaufen. Bitte klicken Sie erneut auf den Link in Ihrer E-Mail.',

    'auto_bill_notification' => 'Der Rechnungsbetrag dieser Rechnung wird automatisch am :due_date per :payment_method abgebucht.',
    'auto_bill_payment_method_bank_transfer' => 'Bankkonto',
    'auto_bill_payment_method_credit_card' => 'Kreditkarte',
    'auto_bill_payment_method_paypal' => 'PayPal Konto',
    'auto_bill_notification_placeholder' => 'Der Rechnungsbetrag dieser Rechnung wird automatisch am Fälligkeitsdatum von Ihrer Kreditkarte abgebucht.',
    'payment_settings' => 'Zahlungseinstellungen',

    'on_send_date' => 'Am Rechnungsdatum',
    'on_due_date' => 'Am Fälligkeitsdatum',
    'auto_bill_ach_date_help' => 'Automatisierte Clearingstellen rechnen immer automatisch am Fälligkeitsdatum ab.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Bankkonto',
    'payment_processed_through_wepay' => 'ACH payments will be processed using WePay.',
    'wepay_payment_tos_agree' => 'Ich stimme den WePay :terms und :privacy_policy zu',
    'privacy_policy' => 'Datenschutzerklärung',
    'wepay_payment_tos_agree_required' => 'Sie müssen den WePay AGB und Datenschutzbestimmungen zustimmen.',
    'ach_email_prompt' => 'Bitte geben Sie eine gültige E-Mail-Adresse ein:',
    'verification_pending' => 'Überprüfung ausstehend',

    'update_font_cache' => 'Please force refresh the page to update the font cache.',
    'more_options' => 'Weitere Optionen',
    'credit_card' => 'Kreditkarte',
    'bank_transfer' => 'Überweisung',
    'no_transaction_reference' => 'We did not recieve a payment transaction reference from the gateway.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'Der Rechnungsbetrag dieser Rechnung wird automatisch am Fälligkeitsdatum per gewählter Zahlungsmethode abgebucht.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Datum :date hinzugefügt',
    'failed_remove_payment_method' => 'Zahlungsart entfernen fehlgeschlagen',
    'gateway_exists' => 'Dieser Zahlungsanbieter wurde bereits angelegt',
    'manual_entry' => 'Manuell hinzufügen',
    'start_of_week' => 'Erster Tag der Woche',

    // Frequencies
    'freq_inactive' => 'Inaktiv',
    'freq_daily' => 'Täglich',
    'freq_weekly' => 'Wöchentlich',
    'freq_biweekly' => 'Zweiwöchentlich',
    'freq_two_weeks' => 'Zweiwöchentlich',
    'freq_four_weeks' => 'Vierwöchentlich',
    'freq_monthly' => 'Monatlich',
    'freq_three_months' => 'Dreimonatlich',
    'freq_four_months' => 'Vier Monate',
    'freq_six_months' => 'Halbjährlich',
    'freq_annually' => 'Jährlich',
    'freq_two_years' => 'Zwei Jahre',

    // Payment types
    'payment_type_Apply Credit' => 'Guthaben anwenden',
    'payment_type_Bank Transfer' => 'Überweisung',
    'payment_type_Cash' => 'Bar',
    'payment_type_Debit' => 'Debit',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa-Karte',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Kreditkarte (andere)',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Scheck',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'SOFORT-Überweisung',
    'payment_type_SEPA' => 'SEPA-Lastschriftverfahren',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Buchhaltung und Rechnungswesen',
    'industry_Advertising' => 'Werbung',
    'industry_Aerospace' => 'Luft- und Raumfahrt',
    'industry_Agriculture' => 'Land- und Forstwirtschaft',
    'industry_Automotive' => 'Automobilbau',
    'industry_Banking & Finance' => 'Bank- und Finanzwesen',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Rundfunk',
    'industry_Business Services' => 'Business Dienstleistungen',
    'industry_Commodities & Chemicals' => 'Rohstoffe und Chemikalien',
    'industry_Communications' => 'Nachrichten und Kommunikation',
    'industry_Computers & Hightech' => 'Computer & Hightech',
    'industry_Defense' => 'Verteidung',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Unterhaltungsindustrie',
    'industry_Government' => 'Kommunal- und Staatsverwaltung',
    'industry_Healthcare & Life Sciences' => 'Gesundheitswesen',
    'industry_Insurance' => 'Versicherungswesen',
    'industry_Manufacturing' => 'Produzierendes Gewerbe',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medien',
    'industry_Nonprofit & Higher Ed' => 'Gemeinnützige Unternehmen',
    'industry_Pharmaceuticals' => 'Arzneimittel',
    'industry_Professional Services & Consulting' => 'Professionelle Dienstleistungen und Beratung',
    'industry_Real Estate' => 'Immobilien',
    'industry_Restaurant & Catering' => 'Gastronomie',
    'industry_Retail & Wholesale' => 'Einzel- und Grosshandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Verkehrswesen',
    'industry_Travel & Luxury' => 'Reisen und Luxus',
    'industry_Other' => 'Andere',
    'industry_Photography' => 'Fotografie',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albanien',
    'country_Antarctica' => 'Antarktis',
    'country_Algeria' => 'Algerien',
    'country_American Samoa' => 'Amerikanisch-Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua und Barbuda',
    'country_Azerbaijan' => 'Aserbaidschan',
    'country_Argentina' => 'Argentinien',
    'country_Australia' => 'Australien',
    'country_Austria' => 'Österreich',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesch',
    'country_Armenia' => 'Armenien',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgien',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivien',
    'country_Bosnia and Herzegovina' => 'Bosnien und Herzigowina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brasilien',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'Britisches Territorium im Indischen Ozean',
    'country_Solomon Islands' => 'Salomonen',
    'country_Virgin Islands, British' => 'Britische Jungferninseln',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bulgarien',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Weissrussland',
    'country_Cambodia' => 'Kambodscha',
    'country_Cameroon' => 'Kamerun',
    'country_Canada' => 'Kanada',
    'country_Cape Verde' => 'Kap Verde',
    'country_Cayman Islands' => 'Kaimaninseln',
    'country_Central African Republic' => 'Zentralafrikanische Republik',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Tschad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan',
    'country_Christmas Island' => 'Weihnachtsinsel',
    'country_Cocos (Keeling) Islands' => 'Kokosinseln',
    'country_Colombia' => 'Kolumbien',
    'country_Comoros' => 'Komoren',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Kongo',
    'country_Congo, the Democratic Republic of the' => 'Kongo, Demokratische Republik',
    'country_Cook Islands' => 'Cook Inseln',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Kroatien',
    'country_Cuba' => 'Kuba',
    'country_Cyprus' => 'Zypern',
    'country_Czech Republic' => 'Tschechische Republik',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Dänemark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominikanische Republik',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Äquatorialguinea',
    'country_Ethiopia' => 'Äthiopien',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estland',
    'country_Faroe Islands' => 'Färöer-Inseln',
    'country_Falkland Islands (Malvinas)' => 'Falklandinseln',
    'country_South Georgia and the South Sandwich Islands' => 'Südgeorgien und die Südlichen Sandwichinseln',
    'country_Fiji' => 'Fidschi',
    'country_Finland' => 'Finnland',
    'country_Åland Islands' => 'Åland',
    'country_France' => 'Frankreich',
    'country_French Guiana' => 'Französisch-Guayana',
    'country_French Polynesia' => 'Französisch-Polynesien',
    'country_French Southern Territories' => 'Französische Süd- und Antarktisgebiete',
    'country_Djibouti' => 'Dschibuti',
    'country_Gabon' => 'Gabun',
    'country_Georgia' => 'Georgien',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palästinensische Autonomiegebiete',
    'country_Germany' => 'Deutschland',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Griechenland',
    'country_Greenland' => 'Grönland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard und McDonaldinseln',
    'country_Holy See (Vatican City State)' => 'Vatikanstadt',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hongkong',
    'country_Hungary' => 'Ungarn',
    'country_Iceland' => 'Island',
    'country_India' => 'Indien',
    'country_Indonesia' => 'Indonesien',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italien',
    'country_Côte d\'Ivoire' => 'Elfenbeinküste',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kasachstan',
    'country_Jordan' => 'Jordanien',
    'country_Kenya' => 'Kenia',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kirgisistan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Libanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Lettland',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Lybien',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Litauen',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Malediven',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauretanien',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexiko',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolei',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Marokko',
    'country_Mozambique' => 'Mosambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Niederlande',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Neuseeland',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolkinsel',
    'country_Norway' => 'Norwegen',
    'country_Northern Mariana Islands' => 'Nördliche Marianen',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshallinseln',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua-Neuguinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippienen',
    'country_Pitcairn' => 'Pitcairninseln',
    'country_Poland' => 'Polen',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Osttimor',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Katar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumänien',
    'country_Russian Federation' => 'Russland',
    'country_Rwanda' => 'Ruanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'St. Kitts und Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi-Arabien',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbien',
    'country_Seychelles' => 'Seychellen',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapur',
    'country_Slovakia' => 'Slowakei',
    'country_Viet Nam' => 'Vietnam',
    'country_Slovenia' => 'Slovenien',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'Südafrika',
    'country_Zimbabwe' => 'Simbabwe',
    'country_Spain' => 'Spanien',
    'country_South Sudan' => 'Südsudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Schweden',
    'country_Switzerland' => 'Schweiz',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tadschikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad und Tobago',
    'country_United Arab Emirates' => 'Vereinigte Arabische Emirate',
    'country_Tunisia' => 'Tunesien',
    'country_Turkey' => 'Türkei',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks- und Caicosinseln',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Mazedonien',
    'country_Egypt' => 'Ägypten',
    'country_United Kingdom' => 'Vereinigtes Königreich',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'Vereinigte Staaten von Amerika',
    'country_Virgin Islands, U.S.' => 'Jungferninseln',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Usbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela',
    'country_Wallis and Futuna' => 'Wallis und Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Jemen',
    'country_Zambia' => 'Sambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brasilianisches Portugiesisch',
    'lang_Croatian' => 'Kroatisch',
    'lang_Czech' => 'Tschechisch',
    'lang_Danish' => 'Dänisch',
    'lang_Dutch' => 'Niederländisch',
    'lang_English' => 'Englisch',
    'lang_French' => 'Französisch',
    'lang_French - Canada' => 'Französisch - Kanada',
    'lang_German' => 'Deutsch',
    'lang_Italian' => 'Italienisch',
    'lang_Japanese' => 'Japanisch',
    'lang_Lithuanian' => 'Litauisch',
    'lang_Norwegian' => 'Norwegisch',
    'lang_Polish' => 'Polnisch',
    'lang_Spanish' => 'Spanisch',
    'lang_Spanish - Spain' => 'Spanisch - Spanien',
    'lang_Swedish' => 'Schwedisch',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Griechisch',
    'lang_English - United Kingdom' => 'Englisch (UK)',
    'lang_English - Australia' => 'Englisch - Australien',
    'lang_Slovenian' => 'Slowenisch',
    'lang_Finnish' => 'Finnisch',
    'lang_Romanian' => 'Romänisch',
    'lang_Turkish - Turkey' => 'Türkisch',
    'lang_Portuguese - Brazilian' => 'Portugiesisch - Brasilien',
    'lang_Portuguese - Portugal' => 'Portugiesisch - Portugal',
    'lang_Thai' => 'Thailändisch',
    'lang_Macedonian' => 'Mazedonier',
    'lang_Chinese - Taiwan' => 'Chinesisch - Taiwan',
    'lang_Serbian' => 'Serbisch',
    'lang_Bulgarian' => 'Bulgarisch',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Buchhaltung und Rechnungswesen',
    'industry_Advertising' => 'Werbung',
    'industry_Aerospace' => 'Luft- und Raumfahrt',
    'industry_Agriculture' => 'Land- und Forstwirtschaft',
    'industry_Automotive' => 'Automobilbau',
    'industry_Banking & Finance' => 'Bank- und Finanzwesen',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Rundfunk',
    'industry_Business Services' => 'Business Dienstleistungen',
    'industry_Commodities & Chemicals' => 'Rohstoffe und Chemikalien',
    'industry_Communications' => 'Nachrichten und Kommunikation',
    'industry_Computers & Hightech' => 'Computer & Hightech',
    'industry_Defense' => 'Verteidung',
    'industry_Energy' => 'Energie',
    'industry_Entertainment' => 'Unterhaltungsindustrie',
    'industry_Government' => 'Kommunal- und Staatsverwaltung',
    'industry_Healthcare & Life Sciences' => 'Gesundheitswesen',
    'industry_Insurance' => 'Versicherungswesen',
    'industry_Manufacturing' => 'Produzierendes Gewerbe',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Medien',
    'industry_Nonprofit & Higher Ed' => 'Gemeinnützige Unternehmen',
    'industry_Pharmaceuticals' => 'Arzneimittel',
    'industry_Professional Services & Consulting' => 'Professionelle Dienstleistungen und Beratung',
    'industry_Real Estate' => 'Immobilien',
    'industry_Retail & Wholesale' => 'Einzel- und Grosshandel',
    'industry_Sports' => 'Sport',
    'industry_Transportation' => 'Verkehrswesen',
    'industry_Travel & Luxury' => 'Reisen und Luxus',
    'industry_Other' => 'Andere',
    'industry_Photography' => 'Fotografie',

    'view_client_portal' => 'Kundenportal anzeigen',
    'view_portal' => 'Portal anzeigen',
    'vendor_contacts' => 'Lieferantenkontakte',
    'all' => 'Alle',
    'selected' => 'Gewählte',
    'category' => 'Kategorie',
    'categories' => 'Kategorien',
    'new_expense_category' => 'Neue Ausgabenkategorie',
    'edit_category' => 'Bearbeite Ausgabenkategorie',
    'archive_expense_category' => 'Archiviere Kategorie',
    'expense_categories' => 'Ausgabenkategorien',
    'list_expense_categories' => 'Ausgabenkategorien anzeigen',
    'updated_expense_category' => 'Ausgabenkategorie erfolgreich aktualisiert',
    'created_expense_category' => 'Ausgabenkategorie erfolgreich erstellt',
    'archived_expense_category' => 'Ausgabenkategorie erfolgreich archiviert',
    'archived_expense_categories' => ':count Ausgabenkategorien erfolgreich archiviert',
    'restore_expense_category' => 'Ausgabenkategorie wiederherstellen',
    'restored_expense_category' => 'Ausgabenkategorie erfolgreich wiederhergestellt',
    'apply_taxes' => 'Steuern anwenden',
    'min_to_max_users' => ':min bis :max Nutzer',
    'max_users_reached' => 'Die Höchstanzahl an Nutzern wurde erreicht.',
    'buy_now_buttons' => '"Kaufe jetzt"-Buttons',
    'landing_page' => 'Landeseite',
    'payment_type' => 'Zahlungsart',
    'form' => 'Formular',
    'link' => 'Link',
    'fields' => 'Felder',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Anmerkung: Kunden- und Rechnungsaufzeichnungen werden auch dann erstellt, wenn die Transaktion nicht abgeschlossen wurde.',
    'buy_now_buttons_disabled' => 'Diese Funktion setzt voraus, dass ein Produkt erstellt und ein Zahlungs-Gateway konfiguriert wurde.',
    'enable_buy_now_buttons_help' => 'Aktiviere Unterstützung für "Kaufe jetzt"-Buttons',
    'changes_take_effect_immediately' => 'Anmerkung: Änderungen treten sofort in Kraft',
    'wepay_account_description' => 'Zahlungsanbieter für Invoice Ninja',
    'payment_error_code' => 'Bei der Bearbeitung Ihrer Zahlung [:code] gab es einen Fehler. Bitte versuchen Sie es später erneut.',
    'standard_fees_apply' => 'Standardgebühren werden erhoben: 2,9% + 0,25€ pro erfolgreicher Belastung bei nicht-europäischen Kreditkarten und 1,4% + 0,25€ bei europäischen Kreditkarten.',
    'limit_import_rows' => 'Daten müssen in Stapeln von :count Zeilen oder weniger importiert werden',
    'error_title' => 'Etwas lief falsch',
    'error_contact_text' => 'Wenn Sie Hilfe benötigen,  schreiben Sie uns bitte eine E-Mail an :mailaddress',
    'no_undo' => 'Warnung: Dies kann nicht rückgängig gemacht werden.',
    'no_contact_selected' => 'Bitte wählen Sie einen Kontakt',
    'no_client_selected' => 'Bitte wählen Sie einen Kunden',

    'gateway_config_error' => 'Es kann helfen neue Passwörter zu setzen oder neue API-Schlüssel zu erzeugen.',
    'payment_type_on_file' => 'Gespeichert/e :type',
    'invoice_for_client' => 'Rechnung :invoice für :client',
    'intent_not_found' => 'Es tut mir Leid, ich verstehe nicht worum Sie bitten.',
    'intent_not_supported' => 'Es tut mir Leid, dazu bin ich nicht imstande.',
    'client_not_found' => 'Ich konnte den Kunden nicht finden',
    'not_allowed' => 'Es tut mir Leid, Sie haben nicht die nötigen Berechtigungen',
    'bot_emailed_invoice' => 'Ihre Rechnung wurde verschickt.',
    'bot_emailed_notify_viewed' => 'Ich schicke Ihnen nach Ansicht eine E-Mail.',
    'bot_emailed_notify_paid' => 'Ich schicke Ihnen nach der Zahlung eine E-Mail.',
    'add_product_to_invoice' => 'Füge 1 :product hinzu',
    'not_authorized' => 'Du bist nicht autorisiert',
    'bot_get_email' => 'Hallo! (Welle) <br/>Danke, dass du den Rechnungs Ninja Bot ausprobiert hast.<br/> Du musst ein kostenloses Konto erstellen, um diesen Bot zu nutzen. <br/>Schicke mir deine E-Mail-Adresse, um loszulegen.',
    'bot_get_code' => 'Danke! Ich habe dir eine E-Mail mit deinem Sicherheitscode geschickt.',
    'bot_welcome' => 'Das war es schon, dein Account ist verifiziert.<br/>',
    'email_not_found' => 'Ich konnte keinen verfügbaren Account für :email finden',
    'invalid_code' => 'Der Code ist nicht korrekt',
    'security_code_email_subject' => 'Sicherheitscode für Invoice Ninja Bot',
    'security_code_email_line1' => 'Dies ist Ihr Invoice Ninja Bot Sicherheitscode.',
    'security_code_email_line2' => 'Anmerkung: Er wird in 10 Minuten ablaufen.',
    'bot_help_message' => 'Ich unterstütze derzeit:<br/>• Erstellung\Aktualisierung\E-Mail-Versand von Rechnungen<br/>• Auflistung von Produkten<br/>Zum Beispiel:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Produkte anzeigen',

    'include_item_taxes_inline' => 'Steuern für Belegpositionen <b>in der  Summe anzeigen</b>',
    'created_quotes' => 'Erfolgreich :count Angebot(e) erstellt',
    'limited_gateways' => 'Anmerkung: Wir unterstützen ein Kreditkarten-Gateway pro Unternehmen.',

    'warning' => 'Warnung',
    'self-update' => 'Update',
    'update_invoiceninja_title' => 'Update Invoice Ninja',
    'update_invoiceninja_warning' => 'Vor dem Update von Invoice Ninja sollte ein Backup der Datenbank und der Dateien erstellt werden!',
    'update_invoiceninja_available' => 'Eine neue Version von Invoice Ninja ist verfügbar.',
    'update_invoiceninja_unavailable' => 'Keine neue Version von Invoice Ninja verfügbar.',
    'update_invoiceninja_instructions' => 'Bitte benutze den <em>Update durchführen</em>-Button, um die neue Version <strong>:version</strong> zu installieren. Du wirst danach zum Dashboard weitergeleitet.',
    'update_invoiceninja_update_start' => 'Update durchführen',
    'update_invoiceninja_download_start' => 'Download :version',
    'create_new' => 'Neu...',

    'toggle_navigation' => 'Navigation umschalten',
    'toggle_history' => 'History umschalten',
    'unassigned' => 'Nicht zugewiesen',
    'task' => 'Aufgabe',
    'contact_name' => 'Name des Kontakts',
    'city_state_postal' => 'Stadt / Bundesland / PLZ',
    'custom_field' => 'Benutzerdefinierte Felder',
    'account_fields' => 'Unternehmensfelder',
    'facebook_and_twitter' => 'Facebook und Twitter',
    'facebook_and_twitter_help' => 'Folge unseren Feeds um unser Projekt zu unterstützen',
    'reseller_text' => 'Anmerkung: die "White-Label"-Lizenz ist für Ihre persönliche Nutzung gedacht. Bitte schicken Sie uns eine E-Mail an :email wenn Sie unsere App weiterverkaufen wollen.',
    'unnamed_client' => 'Unbenannter Kunde',

    'day' => 'Tag',
    'week' => 'Woche',
    'month' => 'Monat',
    'inactive_logout' => 'Sie wurden aufgrund von Inaktivität ausgeloggt',
    'reports' => 'Berichte',
    'total_profit' => 'Gesamtprofit',
    'total_expenses' => 'Gesamtausgaben',
    'quote_to' => 'Angebot an',

    // Limits
    'limit' => 'Grenzwerte',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Keine Grenzwerte',
    'set_limits' => 'Setze :gateway_type Grenzwerte',
    'enable_min' => 'Min aktivieren',
    'enable_max' => 'Max aktivieren',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Diese Rechnung entspricht nicht den Grenzwerten für diese Zahlungsart.',

    'date_range' => 'Datumsbereich',
    'raw' => 'Rohdaten',
    'raw_html' => 'Unverarbeiteter HTML-Code',
    'update' => 'Update',
    'invoice_fields_help' => 'Felder verschieben, um ihre Reihenfolge und Position zu ändern',
    'new_category' => 'Neue Kategorie',
    'restore_product' => 'Produkt wiederherstellen',
    'blank' => 'Leer',
    'invoice_save_error' => 'Die Rechnung konnte nicht gespeichert werden',
    'enable_recurring' => 'Wiederkehrend Aktivieren',
    'disable_recurring' => 'Wiederkehrend Deaktivieren',
    'text' => 'Text',
    'expense_will_create' => 'Ausgabe wird erstellt werden',
    'expenses_will_create' => 'Ausgaben werden erstellt werden',
    'created_expenses' => ':count Ausgabe(n) erfolgreich erstellt',

    'translate_app' => 'Hilf uns unsere Übersetzungen mit :link zu verbessern',
    'expense_category' => 'Ausgabenkategorie',

    'go_ninja_pro' => 'Jetzt Ninja Pro werden!',
    'go_enterprise' => 'Enterprise Version bestellen!',
    'upgrade_for_features' => 'Upgraden Sie um mehr Funktionen zu erhalten',
    'pay_annually_discount' => 'Bezahlen Sie jährlich für 10 Monate und erhalten Sie 2 gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'IhreMarke.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Passen Sie alle Aspekte Ihrer Rechnung an!',
    'enterprise_upgrade_feature1' => 'Setzen Sie Berechtigungen für mehrere Nutzer',
    'enterprise_upgrade_feature2' => 'Hängen Sie Dateien Dritter an Rechnungen und Ausgaben',
    'much_more' => 'Vieles Mehr!',
    'all_pro_fetaures' => 'Zusätzlich alle Pro Funktionen!',

    'currency_symbol' => 'Währungssymbol',
    'currency_code' => 'Währungscode',

    'buy_license' => 'Lizenz kaufen',
    'apply_license' => 'Lizenz anwenden',
    'submit' => 'Abschicken',
    'white_label_license_key' => 'Lizenzschlüssel',
    'invalid_white_label_license' => 'Die "White-Label"-Lizenz ist nicht gültig',
    'created_by' => 'Erstellt von :name',
    'modules' => 'Module',
    'financial_year_start' => 'Erster Monat des Jahres',
    'authentication' => 'Authentifizierung',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Unterschrift',
    'show_accept_invoice_terms' => 'Checkbox für Rechnungsbedingungen',
    'show_accept_invoice_terms_help' => 'Erfordern Sie die Bestätigung der Rechnungsbedingungen durch den Kunden.',
    'show_accept_quote_terms' => 'Checkbox für Angebotsbedingungen',
    'show_accept_quote_terms_help' => 'Erfordern Sie die Bestätigung der Angebotsbedingungen durch den Kunden.',
    'require_invoice_signature' => 'Rechnungsunterschrift',
    'require_invoice_signature_help' => 'Erfordern Sie die Unterschrift des Kunden bei Rechnungen.',
    'require_quote_signature' => 'Angebotsunterschrift',
    'require_quote_signature_help' => 'Erfordern Sie die Unterschrift des Kunden bei Angeboten.',
    'i_agree' => 'Ich stimme den Bedingungen zu',
    'sign_here' => 'Bitte unterschreiben Sie hier:',
    'authorization' => 'Genehmigung',
    'signed' => 'unterzeichnet',

    // BlueVine
    'bluevine_promo' => 'Factoring und Bonitätsauskünfte von BlueVine bestellen.',
    'bluevine_modal_label' => 'Anmelden mit BlueVine',
    'bluevine_modal_text' => '<h3>Schnelle Finanzierung ohne Papierkram.</h3>
<ul><li>Flexible Bonitätsprüfung und Factoring.</li></ul>',
    'bluevine_create_account' => 'Konto erstellen',
    'quote_types' => 'Angebot erhalten für',
    'invoice_factoring' => 'Factoring',
    'line_of_credit' => 'Bonitätsprüfung',
    'fico_score' => 'Ihre FICO Bewertung',
    'business_inception' => 'Gründungsdatum',
    'average_bank_balance' => 'durchschnittlicher Kontostand',
    'annual_revenue' => 'Jahresertrag',
    'desired_credit_limit_factoring' => 'Gewünschtes Factoring Limit',
    'desired_credit_limit_loc' => 'gewünschter Kreditrahmen',
    'desired_credit_limit' => 'gewünschtes Kreditlimit',
    'bluevine_credit_line_type_required' => 'Sie müssen mindestens eine auswählen',
    'bluevine_field_required' => 'Dies ist ein Pflichtfeld',
    'bluevine_unexpected_error' => 'Ein unerwarteter Fehler ist aufgetreten.',
    'bluevine_no_conditional_offer' => 'Mehr Information ist vonnöten um ein Angebot erstellen zu können. Bitte klicken Sie unten auf Weiter.',
    'bluevine_invoice_factoring' => 'Factoring',
    'bluevine_conditional_offer' => 'Freibleibendes Angebot',
    'bluevine_credit_line_amount' => 'Kreditline',
    'bluevine_advance_rate' => 'Finanzierungsanteil',
    'bluevine_weekly_discount_rate' => 'Wöchentlicher Rabatt',
    'bluevine_minimum_fee_rate' => 'Minimale Gebühr',
    'bluevine_line_of_credit' => 'Kreditline',
    'bluevine_interest_rate' => 'Zinssatz',
    'bluevine_weekly_draw_rate' => 'Wöchtentliche Rückzahlungsquote',
    'bluevine_continue' => 'Weiter zu BlueVine',
    'bluevine_completed' => 'BlueVine Anmeldung abgeschlossen',

    'vendor_name' => 'Lieferant',
    'entity_state' => 'Status',
    'client_created_at' => 'Erstellungsdatum',
    'postmark_error' => 'Beim Senden der E-Mail durch Postmark ist ein Problem aufgetreten: :link',
    'project' => 'Projekt',
    'projects' => 'Projekte',
    'new_project' => 'neues Projekt',
    'edit_project' => 'Projekt bearbeiten',
    'archive_project' => 'Projekt archivieren',
    'list_projects' => 'Projekte anzeigen',
    'updated_project' => 'Projekt erfolgreich aktualisiert',
    'created_project' => 'Projekt erfolgreich erstellt',
    'archived_project' => 'Projekt erfolgreich archiviert',
    'archived_projects' => 'Erfolgreich :count Projekte archiviert',
    'restore_project' => 'Projekt wiederherstellen',
    'restored_project' => 'Projekt erfolgreich wiederhergestellt',
    'delete_project' => 'Projekt löschen',
    'deleted_project' => 'Projekt erfolgreich gelöscht',
    'deleted_projects' => 'Erfolgreich :count Projekte gelöscht',
    'delete_expense_category' => 'Kategorie löschen',
    'deleted_expense_category' => 'Kategorie erfolgreich gelöscht',
    'delete_product' => 'Produkt löschen',
    'deleted_product' => 'Produkt erfolgreich gelöscht',
    'deleted_products' => 'Erfolgreich :count Produkte gelöscht',
    'restored_product' => 'Produkt erfolgreich wiederhergestellt',
    'update_credit' => 'Saldo aktualisieren',
    'updated_credit' => 'Saldo erfolgreich aktualisiert',
    'edit_credit' => 'Saldo bearbeiten',
    'realtime_preview' => 'Echtzeit Vorschau',
    'realtime_preview_help' => 'Echtzeit Aktualisierung der PDF Vorschau während der Rechnungs-Bearbeitung. <br/> Deaktivieren um die Performance während des Bearbeitens zu verbessern.',
    'live_preview_help' => 'Live PDF Vorschau auf Rechnungsseite anzeigen.',
    'force_pdfjs_help' => 'Ersetze den eingebauten PDF-Viewer in :chrome_link und :firefox_link.<br/>Aktiviere dies, wenn dein Browser die PDFs automatisch herunterlädt.',
    'force_pdfjs' => 'Verhindere Download',
    'redirect_url' => 'Umleitungs-URL',
    'redirect_url_help' => 'Gebe optional eine URL an, zu der umgeleitet werden soll, wenn eine Zahlung getätigt wurde.',
    'save_draft' => 'Speichere Entwurf',
    'refunded_credit_payment' => 'Ausgleichszahlung',
    'keyboard_shortcuts' => 'Tastatur-Schnellzugriffe',
    'toggle_menu' => 'Menü umschalten',
    'new_...' => 'Neu(e) ...',
    'list_...' => 'Liste',
    'created_at' => 'Erstellt am',
    'contact_us' => 'Kontaktieren Sie uns',
    'user_guide' => 'Nutzer-Anleitung',
    'promo_message' => 'Lizenz erneuern bevor :expires, erhalten Sie :amount% Rabatt auf das erste Jahr unserer Pro oder Enterprise-Pakete.',
    'discount_message' => ':amount Rabatt läuft ab :expires',
    'mark_paid' => 'Als bezahlt markieren',
    'marked_sent_invoice' => 'Rechnung erfolgreich als versendet markiert',
    'marked_sent_invoices' => 'Rechnungen erfolgreich als versendet markiert',
    'invoice_name' => 'Rechnung',
    'product_will_create' => 'Produkt wird erstellt werden',
    'contact_us_response' => 'Wir haben Ihre Nachricht erhalten! Wir antworten sobald wie möglich',
    'last_7_days' => 'Letzte 7 Tage',
    'last_30_days' => 'Letzte 30 Tage',
    'this_month' => 'Dieser Monat',
    'last_month' => 'Letzter Monat',
    'current_quarter' => 'Aktuelles Quartal',
    'last_quarter' => 'Letztes Quartal',
    'last_year' => 'Letztes Jahr',
    'custom_range' => 'Benutzerdefinierter Bereich',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Benötigt',
    'license_expiring' => 'Anmerkung: Ihre Lizenz läuftin :count Tagen ab, :link um sie zu erneuern.',
    'security_confirmation' => 'Deine E-Mail Adresse wurde bestätigt.',
    'white_label_expired' => 'Deine White Label Lizenz ist ausgelaufen, bitte denke darüber nach diese zu verlängern um unser Projekt zu unterstützen.',
    'renew_license' => 'Verlängere die Lizenz',
    'iphone_app_message' => 'Berücksichtigen Sie unsere :link herunterzuladen',
    'iphone_app' => 'iPhone-App',
    'android_app' => 'Android App',
    'logged_in' => 'Eingeloggt',
    'switch_to_primary' => 'Wechseln Sie zu Ihrem Primärunternehmen (:name), um Ihren Plan zu managen.',
    'inclusive' => 'Inklusive',
    'exclusive' => 'Exklusive',
    'postal_city_state' => 'Plz/Stadt/Staat',
    'phantomjs_help' => 'In bestimmten Fällen nutzt diese App :link_phantom um PDFs zu erzeugen. Installieren Sie :link_docs, um diese lokal zu erzeugen.',
    'phantomjs_local' => 'Benutze lokale PhantomJS Instanz',
    'client_number' => 'Kundennummer',
    'client_number_help' => 'Geben Sie einen Präfix oder ein benutzerdefiniertes Schema an, um die Kundennummer dynamisch zu erzeugen.',
    'next_client_number' => 'Die nächste Kundennummer ist :number.',
    'generated_numbers' => 'Generierte Nummern',
    'notes_reminder1' => 'erste Erinnerung',
    'notes_reminder2' => 'zweite Erinnerung',
    'notes_reminder3' => 'dritte Erinnerung',
    'notes_reminder4' => 'Erinnerung',
    'bcc_email' => 'BCC E-Mail',
    'tax_quote' => 'Steuerquote',
    'tax_invoice' => 'Steuerrechnung',
    'emailed_invoices' => 'Rechnungen erfolgreich versendet',
    'emailed_quotes' => 'Angebote erfolgreich versendet',
    'website_url' => 'Webadresse',
    'domain' => 'Domäne',
    'domain_help' => 'Wird im Kunden-Portal und beim Versenden von E-Mails verwendet.',
    'domain_help_website' => 'Wird beim Versenden von E-Mails verwendet.',
    'import_invoices' => 'Rechnungen importieren',
    'new_report' => 'Neuer Bericht',
    'edit_report' => 'Bericht bearbeiten',
    'columns' => 'Spalten',
    'filters' => 'Filter',
    'sort_by' => 'Sortiere nach',
    'draft' => 'Entwurf',
    'unpaid' => 'Unbezahlt',
    'aging' => 'Versendet',
    'age' => 'Alter',
    'days' => 'Tage',
    'age_group_0' => '0 - 30 Tage',
    'age_group_30' => '30 - 60 Tage',
    'age_group_60' => '60 - 90 Tage',
    'age_group_90' => '90 - 120 Tage',
    'age_group_120' => '120+ Tage',
    'invoice_details' => 'Rechnungsdetails',
    'qty' => 'Menge',
    'profit_and_loss' => 'Gewinn und Verlust',
    'revenue' => 'Einnahmen',
    'profit' => 'Profit',
    'group_when_sorted' => 'Gruppensortierung',
    'group_dates_by' => 'Gruppiere Daten nach',
    'year' => 'Jahr',
    'view_statement' => 'Zeige Bericht',
    'statement' => 'Bericht',
    'statement_date' => 'Bericht Datum',
    'mark_active' => 'Markiere aktiv',
    'send_automatically' => 'Automatisch senden',
    'initial_email' => 'Initiale E-Mail',
    'invoice_not_emailed' => 'Diese Rechnung wurde nicht per E-Mail verschickt.',
    'quote_not_emailed' => 'Dieses Angebot wurde nicht per E-Mail verschickt.',
    'sent_by' => 'Gesendet von :user',
    'recipients' => 'Empfänger',
    'save_as_default' => 'Als Standard speichern',
    'start_of_week_help' => 'Verwendet von <b>Datumsselektoren</b>',
    'financial_year_start_help' => 'Verwendet von <b>Datumsbereichsselektoren</b>',
    'reports_help' => 'Umschalt + Klicken, um nach mehreren Spalten zu sortieren, Strg + Klicken, um die Gruppierung zu löschen.',
    'this_year' => 'Dieses Jahr',

    // Updated login screen
    'ninja_tagline' => 'Erstelle. Sende. Werde bezahlt.',
    'login_or_existing' => 'Oder melde dich mit einem verbundenen Konto an.',
    'sign_up_now' => 'Jetzt anmelden',
    'not_a_member_yet' => 'Noch kein Mitglied?',
    'login_create_an_account' => 'Konto erstellen!',

    // New Client Portal styling
    'invoice_from' => 'Rechnungen von:',
    'email_alias_message' => 'Wir benötigen von jedem Benutzer eine einzigartige E-Mail-Adresse. Verwenden Sie einen Alias, z.B.: email+label@example.com',
    'full_name' => 'Voller Name',
    'month_year' => 'Monat/Jahr',
    'valid_thru' => 'Gültig\nthru',

    'product_fields' => 'Produktfelder',
    'custom_product_fields_help' => 'Füge ein Produktfeld hinzu, wenn ein neues Produkt oder eine Rechnung erstellt wird und zeige die Bezeichnung und den Wert auf der Rechnung an.',
    'freq_two_months' => 'Zwei Monate',
    'freq_yearly' => 'Jährlich',
    'profile' => 'Profil',
    'payment_type_help' => 'Setze die Standard <b>manuelle Zahlungsmethode</b>.',
    'industry_Construction' => 'Bauwesen',
    'your_statement' => 'Deine Abrechnung',
    'statement_issued_to' => 'Abrechnung ausgestellt für',
    'statement_to' => 'Abrechnung für',
    'customize_options' => 'Optionen anpassen',
    'created_payment_term' => 'Zahlungsbedingung erfolgreich erstellt',
    'updated_payment_term' => 'Zahlungsbedingung erfolgreich aktualisiert',
    'archived_payment_term' => 'Zahlungsbedingung erfolgreich archiviert',
    'resend_invite' => 'Einladung erneut versenden',
    'credit_created_by' => 'Guthaben erstellt durch Zahlung :transaction_reference',
    'created_payment_and_credit' => 'Zahlung und Guthaben erfolgreich erstellt',
    'created_payment_and_credit_emailed_client' => 'Zahlung und Guthaben erfolgreich erstellt und Kunde per E-Mail benachrichtigt',
    'create_project' => 'Projekt erstellen',
    'create_vendor' => 'Lieferanten erstellen',
    'create_expense_category' => 'Kategorie erstellen',
    'pro_plan_reports' => ':link zur Aktivierung von Berichten durch Beitritt zum Pro Plan',
    'mark_ready' => 'Als bereit markieren',

    'limits' => 'Grenzwerte',
    'fees' => 'Gebühren',
    'fee' => 'Gebühr',
    'set_limits_fees' => ':gateway_type Limits/Gebühren festlegen',
    'fees_tax_help' => 'Aktivieren Sie Einzelposten Steuern, um die Gebührensteuersätze festzulegen.',
    'fees_sample' => 'Die Gebühren für eine Rechnung über :amount  würden :total betragen.',
    'discount_sample' => 'Der Rabatt für eine Rechnungen über :amount würde :total betragen.',
    'no_fees' => 'Keine Gebühren',
    'gateway_fees_disclaimer' => 'Achtung: Nicht alle Länder oder Zahlungsdienstleister erlauben es, Gebühren zu erheben. Beachten Sie die jeweiligen gesetzlichen Bestimmungen bzw. Nutzungsbedingungen.',
    'percent' => 'Prozent',
    'location' => 'Ort',
    'line_item' => 'Posten',
    'surcharge' => 'Gebühr',
    'location_first_surcharge' => 'Aktiviert - Erste Mahngebühr',
    'location_second_surcharge' => 'Aktiviert - Zweite Mahngebühr',
    'location_line_item' => 'Aktiv - Posten',
    'online_payment_surcharge' => 'Gebühr für Online-Zahlung',
    'gateway_fees' => 'Transaktionsgebühren',
    'fees_disabled' => 'Gebühren sind deaktiviert',
    'gateway_fees_help' => 'Automatisch einen Online-Zahlungszuschlag oder Rabatt hinzufügen.',
    'gateway' => 'Provider',
    'gateway_fee_change_warning' => 'Wenn es unbezahlte Rechnungen mit Gebühren gibt, müssen diese manuell aktualisiert werden.',
    'fees_surcharge_help' => 'Gebühren anpassen :link.',
    'label_and_taxes' => 'Bezeichnung und Steueren',
    'billable' => 'Abrechenbar',
    'logo_warning_too_large' => 'Die Bilddatei ist zu groß.',
    'logo_warning_fileinfo' => 'Warnung: Um gif-Dateien zu unterstützen muss die fileinfo PHP-Erweiterung aktiv sein.',
    'logo_warning_invalid' => 'Es gab ein Problem beim Einlesen der Bilddatei. Bitte verwende ein anderes Dateiformat.',

    'error_refresh_page' => 'Es ist ein Fehler aufgetreten. Bitte aktualisiere die Webseite und probiere es erneut.',
    'data' => 'Daten',
    'imported_settings' => 'Einstellungen erfolgreich aktualisiert',
    'reset_counter' => 'Zähler-Reset',
    'next_reset' => 'Nächster Reset',
    'reset_counter_help' => 'Setze automatisch den Rechnungs- und Angebotszähler zurück.',
    'auto_bill_failed' => 'Automatische Abrechnung für :invoice_number fehlgeschlagen',
    'online_payment_discount' => 'Online-Zahlungsrabatt',
    'created_new_company' => 'Neues Unternehmen erfolgreich erstellt',
    'fees_disabled_for_gateway' => 'Gebühren sind für diesen Gateway deaktiviert.',
    'logout_and_delete' => 'Ausloggen/Konto löschen',
    'tax_rate_type_help' => 'Inklusive Steuersätze beeinflussen die Kosten der Rechnungspositionen, wenn sie ausgewählt werden. Nur exklusive Steuersätze können als Standard verwendet werden.',
    'invoice_footer_help' => 'Verwende $pageNumber und $pageCount um Seiteninformationen anzuzeigen.',
    'credit_note' => 'Gutschrift',
    'credit_issued_to' => 'Kreditkarte ausgestellt auf',
    'credit_to' => 'Gutschreiben an',
    'your_credit' => 'Ihr Guthaben',
    'credit_number' => 'Gutschriftnummer',
    'create_credit_note' => 'Gutschrift erstellen',
    'menu' => 'Menü',
    'error_incorrect_gateway_ids' => 'Fehler: Die Tabelle des Gateways enthält fehlerhafte IDs.',
    'purge_data' => 'Daten säubern',
    'delete_data' => 'Daten löschen',
    'purge_data_help' => 'Alle Daten endgültig löschen, aber Konto und Einstellungen behalten.',
    'cancel_account_help' => 'Lösche unwiderruflich das Konto, mitsamt aller Daten und Einstellungen.',
    'purge_successful' => 'Die Kontodaten wurden erfolgreich gelöscht',
    'forbidden' => 'Verboten',
    'purge_data_message' => 'Achtung: Alle Daten werden vollständig gelöscht. Dieser Vorgang kann nicht rückgängig gemacht werden.',
    'contact_phone' => 'Telefonnummer des Kontakts',
    'contact_email' => 'E-Mail-Adresse des Kontakts',
    'reply_to_email' => 'Antwort-E-Mail-Adresse',
    'reply_to_email_help' => 'Gib die Antwort-E-Mail-Adresse an, die für den Kundenkontakt genutzt werden soll.',
    'bcc_email_help' => 'Sende unsichtbar zusätzlich alle ausgehenden E-Mails an die hier angegebene Adresse.',
    'import_complete' => 'Ihr Import wurde erfolgreich abgeschlossen.',
    'confirm_account_to_import' => 'Bitte bestätigen Sie Ihr Konto um Daten zu importieren.',
    'import_started' => 'Ihr Import wurde gestartet, wir senden Ihnen eine E-Mail zu, sobald er abgeschlossen wurde.',
    'listening' => 'Höre zu...',
    'microphone_help' => 'Sagen Sie "neue Rechnung für [client]" oder "zeige mir für [client] archivierte Zahlungen".',
    'voice_commands' => 'Sprachbefehle',
    'sample_commands' => 'Beispiele für Sprachbefehle',
    'voice_commands_feedback' => 'Wir arbeiten aktiv daran, dieses Feature zu verbessern. Wenn es einen Befehl gibt, den wir unterstützen sollen, senden Sie uns bitte eine E-Mail an :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Zahlunganweisung',
    'archived_products' => 'Archivierung erfolgreich :Produktzähler',
    'recommend_on' => 'Wir empfehlen diese Einstellung zu <b>aktivieren</b>.',
    'recommend_off' => 'Wir empfehlen diese Einstellung zu <b>deaktivieren</b>.',
    'notes_auto_billed' => 'Automatisch verrechnet',
    'surcharge_label' => 'Aufschlagsfeldbezeichnung',
    'contact_fields' => 'Kontaktfelder',
    'custom_contact_fields_help' => 'Füge ein Kontaktfeld hinzu. Optional kann die Feldbezeichnung und der Feldwert auch in PDF-Dokumenten ausgegeben werden.',
    'datatable_info' => 'Zeige Eintrag :start bis :end von :total',
    'credit_total' => 'Gesamtguthaben',
    'mark_billable' => 'zur Verrechnung kennzeichnen',
    'billed' => 'Verrechnet',
    'company_variables' => 'Firmen-Variablen',
    'client_variables' => 'Kunden-Variablen',
    'invoice_variables' => 'Rechnungs Variablen',
    'navigation_variables' => 'Navigations Variablen',
    'custom_variables' => 'Benutzerdefinierte Variablen',
    'invalid_file' => 'Ungültiger Dateityp',
    'add_documents_to_invoice' => 'Fügen Sie Dokumente zur Rechnung hinzu',
    'mark_expense_paid' => 'Als bezahlt markieren',
    'white_label_license_error' => 'Die Lizenz nicht validiert werden. Überprüfen Sie die Datei Storage/logs/laravel-error. log auf Fehler.',
    'plan_price' => 'Tarifkosten',
    'wrong_confirmation' => 'Falscher Bestätigungscode',
    'oauth_taken' => 'Dieses Konto ist bereits registriert',
    'emailed_payment' => 'Zahlungs eMail erfolgreich gesendet',
    'email_payment' => 'Sende Zahlungs eMail',
    'invoiceplane_import' => 'Benutzer :link für die Datenmigration von InvoicePlane.',
    'duplicate_expense_warning' => 'Achtung: :link evtl. schon vorhanden.',
    'expense_link' => 'Ausgabe',
    'resume_task' => 'Aufgabe fortsetzen',
    'resumed_task' => 'Aufgabe fortgesetzt',
    'quote_design' => 'Angebots-Layout',
    'default_design' => 'Standard-Layout',
    'custom_design1' => 'Eigenes Layout 1',
    'custom_design2' => 'Eigenes Layout 2',
    'custom_design3' => 'Eigenes Layout 3',
    'empty' => 'Leer',
    'load_design' => 'Designvorlage laden',
    'accepted_card_logos' => 'Logos der akzeptierten Kreditkarten',
    'phantomjs_local_and_cloud' => 'PhantomJS wird lokal verwendet, die Cloud-Version wird als Fallback verwendet',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Zahlungen verfolgen über :link',
    'start_date_required' => 'Das Anfangsdatum muss angegeben werden',
    'application_settings' => 'Anwendungs-Einstellungen',
    'database_connection' => 'Datenbank-Verbindung',
    'driver' => 'Treiber',
    'host' => 'Host',
    'database' => 'Datenbank',
    'test_connection' => 'Verbindung testen',
    'from_name' => 'Absendername',
    'from_address' => 'Absenderadresse',
    'port' => 'Port',
    'encryption' => 'Verschlüsselung',
    'mailgun_domain' => 'Mailgun Domäne',
    'mailgun_private_key' => 'Mailgun privater Schlüssel',
    'send_test_email' => 'Test-E-Mail verschicken',
    'select_label' => 'Bezeichnung wählen',
    'label' => 'Label',
    'service' => 'Dienst',
    'update_payment_details' => 'Aktualisiere Zahlungsdetails',
    'updated_payment_details' => 'Zahlungsdetails erfolgreich aktualisiert',
    'update_credit_card' => 'Aktualisiere Kreditkarte',
    'recurring_expenses' => 'Wiederkehrende Ausgaben',
    'recurring_expense' => 'Wiederkehrende Ausgabe',
    'new_recurring_expense' => 'Wiederkehrende Ausgabe eingeben',
    'edit_recurring_expense' => 'Wiederkehrende Ausgabe bearbeiten',
    'archive_recurring_expense' => 'Wiederkehrende Ausgabe archivieren',
    'list_recurring_expense' => 'Wiederkehrende Ausgabe auflisten',
    'updated_recurring_expense' => 'Wiederkehrende Ausgabe wurde aktualisiert',
    'created_recurring_expense' => 'Wiederkehrende Ausgabe wurde erstellt',
    'archived_recurring_expense' => 'Wiederkehrende Ausgabe wurde archiviert',
    'restore_recurring_expense' => 'Wiederkehrende Ausgabe wiederherstellen',
    'restored_recurring_expense' => 'Wiederkehrende Ausgabe wurde wiederhergestellt',
    'delete_recurring_expense' => 'Wiederkehrende Ausgabe Löschen',
    'deleted_recurring_expense' => 'Projekt wurde gelöscht',
    'view_recurring_expense' => 'Wiederkehrende Ausgabe Anzeigen',
    'taxes_and_fees' => 'Steuern und Gebühren',
    'import_failed' => 'Import fehlgeschlagen',
    'recurring_prefix' => 'Wiederkehrender Präfix',
    'options' => 'Optionen',
    'credit_number_help' => 'Geben Sie einen Präfix oder ein benutzerdefiniertes Schema an, um die Gutschriftnummer dynamisch zu erzeugen.',
    'next_credit_number' => 'Die nächste Gutschriftnummer ist :number.',
    'padding_help' => 'Anzahl der Stellen, mit der die Nummern dargestellt werden.',
    'import_warning_invalid_date' => 'Achtung: Das Datumsformat ist ungültig',
    'product_notes' => 'Produktnotizen',
    'app_version' => 'App-Version',
    'ofx_version' => 'OFX-Version',
    'gateway_help_23' => ':link um Ihre Stripe API-Keys zu erhalten.',
    'error_app_key_set_to_default' => 'Fehler: APP_KEY ist auf einen Standardwert gesetzt. Um ihn zu aktualisieren, sichere deine Datenbank und führe dann <code>php artisan ninja:update-key</code> aus',
    'charge_late_fee' => 'Verspätungszuschlag berechnen',
    'late_fee_amount' => 'Höhe des Verspätungszuschlags',
    'late_fee_percent' => 'Verspätungszuschlag Prozent',
    'late_fee_added' => 'Verspätungszuschlag hinzugefügt am :date',
    'download_invoice' => 'Rechnung herunterladen',
    'download_quote' => 'Angebot herunterladen',
    'invoices_are_attached' => 'Ihre PDF-Rechnungsdokumente finden Sie im Anhang.',
    'downloaded_invoice' => 'Die Rechnung wird als PDF per E-Mail versendet',
    'downloaded_quote' => 'Das Angebot wird als PDF per E-Mail versendet',
    'downloaded_invoices' => 'Die Rechnungen werden als PDF per E-Mail versendet',
    'downloaded_quotes' => 'Die Angebote werden als PDF per E-Mail versendet',
    'clone_expense' => 'Ausgabe duplizieren',
    'default_documents' => 'Standard-Dokumente',
    'send_email_to_client' => 'E-Mail an den Kunden senden',
    'refund_subject' => 'Erstattung wurde durchgeführt',
    'refund_body' => 'Sie haben eine Rückerstattung über :Betrag für Rechnung :Rechnungsnummer erhalten.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'Britische Pfund',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Südafrikanischer Rand',
    'currency_danish_krone' => 'Dänische Kronen',
    'currency_israeli_shekel' => 'Israelische Shekel',
    'currency_swedish_krona' => 'Schwedische Kronen',
    'currency_kenyan_shilling' => 'Keniansche Schilling',
    'currency_canadian_dollar' => 'Kanadische Dollar',
    'currency_philippine_peso' => 'Philippinischer Peso',
    'currency_indian_rupee' => 'Indische Rupie',
    'currency_australian_dollar' => 'Australische Dollar',
    'currency_singapore_dollar' => 'Singapur Dollar',
    'currency_norske_kroner' => 'Norwegische Kronen',
    'currency_new_zealand_dollar' => 'Neuseeland Dollar',
    'currency_vietnamese_dong' => 'Vietnamesische Dong',
    'currency_swiss_franc' => 'Schweizer Franken',
    'currency_guatemalan_quetzal' => 'Guatemaltekischer Quetzal',
    'currency_malaysian_ringgit' => 'Malaysischer Ringgit',
    'currency_brazilian_real' => 'Brasilianischer Real',
    'currency_thai_baht' => 'Thailändischer Baht',
    'currency_nigerian_naira' => 'Nigerianische Naira',
    'currency_argentine_peso' => 'Argentinischer Peso',
    'currency_bangladeshi_taka' => 'Bangladesch Taka',
    'currency_united_arab_emirates_dirham' => 'Vereinigte Arabische Emirate Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesische Rupiah',
    'currency_mexican_peso' => 'Mexikanische Peso',
    'currency_egyptian_pound' => 'Ägyptische Pfund',
    'currency_colombian_peso' => 'Kolumbianischer Peso',
    'currency_west_african_franc' => 'Westafrikanischer Franc',
    'currency_chinese_renminbi' => 'Chinesischer Renminbi',
    'currency_rwandan_franc' => 'Ruanda-Franc',
    'currency_tanzanian_shilling' => 'Tansania-Schilling',
    'currency_netherlands_antillean_guilder' => 'Niederländische-Antillen-Gulden',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad und Tobago-Dollar',
    'currency_east_caribbean_dollar' => 'Ostkaribischer Dollar',
    'currency_ghanaian_cedi' => 'Ghanaischer Cedi',
    'currency_bulgarian_lev' => 'Bulgarische Lev',
    'currency_aruban_florin' => 'Aruba-Florin',
    'currency_turkish_lira' => 'Türkische Lira',
    'currency_romanian_new_leu' => ' Rumänischer Leu',
    'currency_croatian_kuna' => 'Kroatische Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanische Yen',
    'currency_maldivian_rufiyaa' => 'Malediven-Rupie',
    'currency_costa_rican_colon' => 'Costa-Rica-Colón',
    'currency_pakistani_rupee' => 'Pakistanische Rupie',
    'currency_polish_zloty' => 'Polnische Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lanka-Rupie ',
    'currency_czech_koruna' => 'Tschechische Kronen',
    'currency_uruguayan_peso' => 'Uruguayischer Peso',
    'currency_namibian_dollar' => 'Namibischer Dollar',
    'currency_tunisian_dinar' => 'Tunesischer Dinar',
    'currency_russian_ruble' => 'Russische Rubel',
    'currency_mozambican_metical' => 'Mosambik-Metical',
    'currency_omani_rial' => 'Omanischer Rial',
    'currency_ukrainian_hryvnia' => 'Ukraininische Hrywnja',
    'currency_macanese_pataca' => 'Macao-Pataca',
    'currency_taiwan_new_dollar' => 'Neuer Taiwan-Dollar',
    'currency_dominican_peso' => 'Dominikanischer Peso',
    'currency_chilean_peso' => 'Chilenischer Peso',
    'currency_icelandic_krona' => 'Isländische Krone',
    'currency_papua_new_guinean_kina' => 'Papua-Neuguinea Kina',
    'currency_jordanian_dinar' => 'Jordanischer Dinar',
    'currency_myanmar_kyat' => 'Myanmar-Kyat',
    'currency_peruvian_sol' => 'Peruanischer Sol',
    'currency_botswana_pula' => 'Botswanischer Pula',
    'currency_hungarian_forint' => 'Ungarischer Forint',
    'currency_ugandan_shilling' => 'Uganda-Schilling',
    'currency_barbadian_dollar' => 'Barbados-Dollar',
    'currency_brunei_dollar' => 'Brunei-Dollar',
    'currency_georgian_lari' => 'Georgischer Lari',
    'currency_qatari_riyal' => ' Katar-Riyal',
    'currency_honduran_lempira' => 'Honduranische Lempira',
    'currency_surinamese_dollar' => 'Surinamischer Dollar',
    'currency_bahraini_dinar' => 'Bahrainischer Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelanische Bolivars',
    'currency_south_korean_won' => 'Südkoreanischer Won',
    'currency_moroccan_dirham' => 'Marokkanischer Dirham',
    'currency_jamaican_dollar' => 'Jamaikanischer Dollar',
    'currency_angolan_kwanza' => 'Angolanische Kwanza',
    'currency_haitian_gourde' => 'Haitianischer Gourde',
    'currency_zambian_kwacha' => 'Sambische Kwacha',
    'currency_nepalese_rupee' => 'Nepalesische Rupie',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritianische Rupie',
    'currency_cape_verdean_escudo' => 'Kapverdischer Escudo',
    'currency_kuwaiti_dinar' => 'Kuwait-Dinar',
    'currency_algerian_dinar' => 'Algerische Dinar',
    'currency_macedonian_denar' => 'Mazedonischer Denar',
    'currency_fijian_dollar' => 'Fidschi-Dollar',
    'currency_bolivian_boliviano' => 'Boliviano',
    'currency_albanian_lek' => 'Albanische Lek',
    'currency_serbian_dinar' => 'Serbische Dinar',
    'currency_lebanese_pound' => 'Libanesische Pfund',
    'currency_armenian_dram' => 'Armenischer Dram',
    'currency_azerbaijan_manat' => 'Aserbaidschan-Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnien und Herzegovina Konvertible Mark',
    'currency_belarusian_ruble' => 'Weißrussischer Rubel',
    'currency_moldovan_leu' => 'Moldauischer Leu',
    'currency_kazakhstani_tenge' => 'Kasachischer Tenge',
    'currency_gibraltar_pound' => 'Gibraltar-Pfund',

    'review_app_help' => 'Wir hoffen, dass Ihnen die App gefällt. Wenn Sie :link in Betracht ziehen würden, wären wir Ihnen sehr dankbar!',
    'writing_a_review' => 'Schreiben einer Rezension',

    'use_english_version' => 'Achten Sie darauf, die englische Version der Dateien zu verwenden. Wir verwenden die Spaltenüberschriften, um die Felder abzugleichen.',
    'tax1' => 'Steuern',
    'tax2' => 'Aufschlag',
    'fee_help' => 'Gateway-Gebühren sind die Kosten, die für die Nutzung der Finanznetzwerke anfallen, über die Online-Bezahlungen abgewickelt werden.',
    'format_export' => 'Export-Format',
    'custom1' => 'Benutzerdefiniert 1',
    'custom2' => 'Benutzerdefiniert 2',
    'contact_first_name' => 'Kontakt Vorname',
    'contact_last_name' => 'Kontakt Nachname',
    'contact_custom1' => 'Kontakt Benutzerdefiniert 1',
    'contact_custom2' => 'Kontakt Benutzerdefiniert 2',
    'currency' => 'Währung',
    'ofx_help' => 'Um Probleme zu beheben, überprüfen Sie auf Kommentare zu :ofxhome_link und testen Sie mit :ofxget_link.',
    'comments' => 'Kommentare',

    'item_product' => 'Bezeichnung',
    'item_notes' => 'Beschreibung',
    'item_cost' => 'Preis',
    'item_quantity' => 'Menge',
    'item_tax_rate' => 'Steuern für Position',
    'item_tax_name' => 'Steuern',
    'item_tax1' => 'Position Steuern 1',
    'item_tax2' => 'Position Steuern 2',

    'delete_company' => 'Firma löschen',
    'delete_company_help' => 'Die Firma unwiderruflich mit allen Daten löschen.',
    'delete_company_message' => 'Achtung: Dadurch wird Ihre Firma unwiderruflich gelöscht. Es gibt kein Zurück.',

    'applied_discount' => 'Der Coupon wurde angewendet, der Planpreis wurde um :discount% reduziert.',
    'applied_free_year' => 'Der Gutschein wurde verwendet. Ihr Konto wurde für ein Jahr auf Pro aktualisiert.',

    'contact_us_help' => 'Wenn Sie einen Fehler melden, fügen Sie bitte alle relevanten Informationen aus storage/logs/laravel-error.log hinzu.',
    'include_errors' => 'Fehler einschließen',
    'include_errors_help' => ':link von storage/logs/laravel-error.log einschließen',
    'recent_errors' => 'Kürzliche Fehler',
    'customer' => 'Kunde',
    'customers' => 'Kunden',
    'created_customer' => 'Kunde erfolgreich erstellt',
    'created_customers' => ':count Kunden erfolgreich erstellt',

    'purge_details' => 'Ihre Firmendaten (:account) wurden erfolgreich gelöscht.',
    'deleted_company' => 'Unternehmen erfolgreich gelöscht',
    'deleted_account' => 'Konto erfolgreich gelöscht',
    'deleted_company_details' => 'Ihre Firma (:account) wurde erfolgreich gelöscht.',
    'deleted_account_details' => 'Dein Konto (:account) wurde erfolgreich gelöscht.',

    'alipay' => 'Alipay',
    'sofort' => 'SOFORT-Überweisung',
    'sepa' => 'SEPA-Lastschrift',
    'enable_alipay' => 'Alipay akzeptieren',
    'enable_sofort' => 'EU-Überweisungen akzeptieren',
    'stripe_alipay_help' => 'Dieses Gateway muss unter :link aktiviert werden.',
    'calendar' => 'Kalender',
    'pro_plan_calendar' => ':link um den Kalender im Pro-Tarif zu aktivieren',

    'what_are_you_working_on' => 'Woran arbeiten Sie?',
    'time_tracker' => 'Zeiterfassung',
    'refresh' => 'Aktualisieren',
    'filter_sort' => 'Filter/Sortieren',
    'no_description' => 'Keine Beschreibung',
    'time_tracker_login' => 'Zeiterfassung Login',
    'save_or_discard' => 'Änderungen speichern oder verwerfen',
    'discard_changes' => 'Änderungen verwerfen',
    'tasks_not_enabled' => 'Aufgaben sind nicht aktiv.',
    'started_task' => 'Aufgabe erfolgreich gestartet',
    'create_client' => 'Kunden erstellen',

    'download_desktop_app' => 'Lade die Desktop-App herunter',
    'download_iphone_app' => 'Lade die iPhone-App herunter',
    'download_android_app' => 'Lade die Android-App herunter',
    'time_tracker_mobile_help' => 'Task auswählen mit Doppelklick',
    'stopped' => 'Angehalten',
    'ascending' => 'Aufsteigend',
    'descending' => 'Absteigend',
    'sort_field' => 'Sortierung',
    'sort_direction' => 'Richtung',
    'discard' => 'Verwerfen',
    'time_am' => 'Vormittags',
    'time_pm' => 'Nachmittags',
    'time_mins' => 'Minuten',
    'time_hr' => 'Stunde',
    'time_hrs' => 'Stunden',
    'clear' => 'Löschen',
    'warn_payment_gateway' => 'Hinweis: Die Annahme von Online-Zahlungen erfordert einen Zahlungsanbieter. Zum hinzufügen :link.',
    'task_rate' => 'Kosten für Tätigkeit',
    'task_rate_help' => 'Legen Sie den Standardtarif für fakturierte Aufgaben fest.',
    'past_due' => 'Überfällig',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Rechnung/Kosten',
    'invoice_pdfs' => 'Rechnungs-PDFs',
    'enable_sepa' => 'SEPA-Lastschriften akzeptieren',
    'enable_bitcoin' => 'Bitcoin akzeptieren',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Mit der Angabe Ihrer IBAN und der Bestätigung dieser Zahlung ermächtigen Sie :company und unseren Zahlungsdienstleister Stripe, Ihr Konto mit dem Rechnungsbetragzu belasten. Sie haben Anspruch auf Rückerstattung von Ihrer Bank zu den Bedingungen und Konditionen, die Sie mit Ihrer Bank vereinbart haben. Die Rückerstattung muss innerhalb von 8 Wochen ab dem Datum der Belastung Ihres Kontos erfolgen.',
    'recover_license' => 'Lizenz wiederherstellen',
    'purchase' => 'Kaufen',
    'recover' => 'Wiederherstellen',
    'apply' => 'Anwenden',
    'recover_white_label_header' => 'White-Label-Lizenz wiederherstellen',
    'apply_white_label_header' => 'White-Label-Lizent wiederherstellen',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Zurück zur Rechnung',
    'gateway_help_13' => 'Um ITN zu benutzen, lassen Sie das PDT-Feld leer.',
    'partial_due_date' => 'Teilzahlungsziel',
    'task_fields' => 'Aufgabenfelder',
    'product_fields_help' => 'Felder verschieben, um ihre Reihenfolge zu ändern',
    'custom_value1' => 'Benutzerdefinierten Wert',
    'custom_value2' => 'Benutzerdefinierten Wert',
    'enable_two_factor' => 'Zwei-Faktor-Authentifizierung',
    'enable_two_factor_help' => 'Bestätige beim Anmelden mit deinem Telefon deine Identität',
    'two_factor_setup' => 'Zwei-Faktor Einrichtung',
    'two_factor_setup_help' => 'Barcode mit :link kompatibler App scannen.',
    'one_time_password' => 'Einmaliges Passwort',
    'set_phone_for_two_factor' => 'Legen Sie Ihre Handynummer als Backup für die Aktivierung fest.',
    'enabled_two_factor' => 'Zwei-Faktor-Authentifizierung erfolgreich aktiviert',
    'add_product' => 'Produkt hinzufügen',
    'email_will_be_sent_on' => 'Hinweis: Das E-Mail wird am :date gesendet.',
    'invoice_product' => 'Rechnungsprodukt',
    'self_host_login' => 'Eigenes-Hosting Anmeldung',
    'set_self_hoat_url' => 'Eigenes-Hosting URL',
    'local_storage_required' => 'Fehler: Lokaler Speicherplatz ist nicht verfügbar.',
    'your_password_reset_link' => 'Dein Passwort zurücksetzen Link',
    'subdomain_taken' => 'Die Subdomäne wird bereits verwendet',
    'client_login' => 'Kundenanmeldung',
    'converted_amount' => 'Umgerechneter Betrag',
    'default' => 'Standard',
    'shipping_address' => 'Lieferadresse',
    'bllling_address' => 'Rechnungsadresse',
    'billing_address1' => 'Strasse Rechnungsanschrift',
    'billing_address2' => 'Rechnung Adresszusatz',
    'billing_city' => 'Stadt Rechnungsanschrift',
    'billing_state' => 'Rechnung Bundesland',
    'billing_postal_code' => 'Postleitzahl Rechnungsanschrift',
    'billing_country' => 'Rechnungsland',
    'shipping_address1' => 'Strasse Versandanschrift',
    'shipping_address2' => 'Versand Adresszusatz',
    'shipping_city' => 'Stadt Versandanschrift',
    'shipping_state' => 'Versand Bundesland',
    'shipping_postal_code' => 'Postleitzahl Versandanschrift',
    'shipping_country' => 'Lieferungsland',
    'classify' => 'Klassifizieren',
    'show_shipping_address_help' => 'Verlange von Kunden, ihre Versandadresse anzugeben',
    'ship_to_billing_address' => 'An die Rechnungsadresse versenden',
    'delivery_note' => 'Lieferschein',
    'show_tasks_in_portal' => 'Zeige Aufgaben im Kundenportal',
    'cancel_schedule' => 'Plan abgebrochen',
    'scheduled_report' => 'Geplanter Bericht',
    'scheduled_report_help' => ':report Bericht als :format an E-Mail senden',
    'created_scheduled_report' => 'Bericht erfolgreich eingeplant',
    'deleted_scheduled_report' => 'Eingeplanten Bericht erfolgreich gelöscht',
    'scheduled_report_attached' => 'Ihr geplanter Bericht vom Typ :type ist angehängt.',
    'scheduled_report_error' => 'Fehler beim Erstellen des geplanten Berichts.',
    'invalid_one_time_password' => 'Ungültiges Einmalpasswort',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Akzeptiere Apple Pay und Pay mit Google',
    'requires_subdomain' => 'Diese Zahlungsart erfordert einen :link.',
    'subdomain_is_set' => 'subdomain ist gesetzt',
    'verification_file' => 'Verifizierungsdatei',
    'verification_file_missing' => 'Die Verifikationsdatei wird benötigt, um Zahlungen zu akzeptieren.',
    'apple_pay_domain' => 'Nutze <code>:domain</code>als die Domain in :link',
    'apple_pay_not_supported' => 'Es tut uns leid, Apple/Google Pay ist nicht von Ihrem Browser unterstützt',
    'optional_payment_methods' => 'Optionale Zahlungsmethoden',
    'add_subscription' => 'Abonnement hinzufügen',
    'target_url' => 'Ziel',
    'target_url_help' => 'Wenn das ausgewählte Ereignis eintritt, wird die App die Entität an die Ziel-URL senden.',
    'event' => 'Ereignis',
    'subscription_event_1' => 'Erstellter Kunde',
    'subscription_event_2' => 'Erstellte Rechnung',
    'subscription_event_3' => 'Angebot erstellt',
    'subscription_event_4' => 'Zahlung erstellt',
    'subscription_event_5' => 'Erstellte Lieferanten',
    'subscription_event_6' => 'Angebot aktualisiert',
    'subscription_event_7' => 'Angebot gelöscht',
    'subscription_event_8' => 'Aktualisierte Rechnung',
    'subscription_event_9' => 'Gelöschte Rechnung',
    'subscription_event_10' => 'Kunde aktualisiert',
    'subscription_event_11' => 'Kunde gelöscht',
    'subscription_event_12' => 'Zahlung löschen',
    'subscription_event_13' => 'Lieferant aktualisiert',
    'subscription_event_14' => 'Lieferant gelöscht',
    'subscription_event_15' => 'Ausgabe erstellt',
    'subscription_event_16' => 'Ausgabe aktualisiert',
    'subscription_event_17' => 'Ausgabe gelöscht',
    'subscription_event_18' => 'Aufgabe erstellt',
    'subscription_event_19' => 'Aufgabe aktualisiert',
    'subscription_event_20' => 'Aufgabe gelöscht',
    'subscription_event_21' => 'Angebot angenommen',
    'subscriptions' => 'Abonnements',
    'updated_subscription' => 'Abonnement erfolgreich aktualisiert',
    'created_subscription' => 'Abonnement erfolgreich erstellt',
    'edit_subscription' => 'Abonnement bearbeiten',
    'archive_subscription' => 'Abonnement archivieren',
    'archived_subscription' => 'Abonnement erfolgreich archiviert',
    'project_error_multiple_clients' => 'Die Projekte können nicht zu verschiedenen Kunden gehören',
    'invoice_project' => 'Projekt berechnen',
    'module_recurring_invoice' => 'Wiederkehrende Rechnungen',
    'module_credit' => 'Guthaben',
    'module_quote' => 'Angebote und Vorschläge',
    'module_task' => 'Aufgaben und Projekte',
    'module_expense' => 'Ausgaben & Lieferanten',
    'module_ticket' => 'Tickets',
    'reminders' => 'Erinnerungen',
    'send_client_reminders' => 'E-Mail Erinnerungen versenden',
    'can_view_tasks' => 'Aufgaben sind im Portal sichtbar',
    'is_not_sent_reminders' => 'Erinnerungen werden nicht gesendet',
    'promotion_footer' => 'Ihre Promotion läuft bald ab, :link, um jetzt ein Upgrade durchzuführen.',
    'unable_to_delete_primary' => 'Hinweis: Um diese Firma zu löschen, löschen Sie zunächst alle verknüpften Unternehmen.',
    'please_register' => 'Bitte erstellen Sie sich einen Account',
    'processing_request' => 'Anfrage verarbeiten',
    'mcrypt_warning' => 'Warnung: Mcrypt ist veraltet, führen sie :command aus, um Ihre Verschlüsselung zu aktualisieren.',
    'edit_times' => 'Zeiten bearbeiten',
    'inclusive_taxes_help' => 'Schließe <b>Steuern in die Kosten ein.</b>',
    'inclusive_taxes_notice' => 'Diese Einstellung kann nicht mehr geändert werden, sobald eine Rechnung erstellt wurde.',
    'inclusive_taxes_warning' => 'Warnung: Existierende Rechnungen müssen erneut gespeichert werden',
    'copy_shipping' => 'Versand kopieren',
    'copy_billing' => 'Zahlung kopieren',
    'quote_has_expired' => 'Das Angebot ist abgelaufen, bitte kontaktieren Sie den Verkäufer',
    'empty_table_footer' => 'Zeige 0 bis 0 von 0 Einträgen',
    'do_not_trust' => 'Dieses Gerät nicht merken',
    'trust_for_30_days' => 'Für 30 Tage vertrauen',
    'trust_forever' => 'Für immer vertrauen',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Bereit zu machen',
    'in_progress' => 'In Bearbeitung',
    'add_status' => 'Status hinzufügen',
    'archive_status' => 'Status archivieren',
    'new_status' => 'Neuer Status',
    'convert_products' => 'Produkte konvertieren',
    'convert_products_help' => 'Produktpreise automatisch in die Währung des Kunden konvertieren',
    'improve_client_portal_link' => 'Eine Subdomain verwenden, um den Link zum Kundenportal zu verkürzen.',
    'budgeted_hours' => 'Budgetierte Stunden',
    'progress' => 'Fortschritt',
    'view_project' => 'Projekt ansehen',
    'summary' => 'Zusammenfassung',
    'endless_reminder' => 'Endlose Erinnnerung',
    'signature_on_invoice_help' => 'Füge den folgenden Code hinzu, um die Unterschrift des Kunden auf dem PDF anzuzeigen.',
    'signature_on_pdf' => 'Auf PDF anzeigen',
    'signature_on_pdf_help' => 'Unterschrift des Kunden auf dem Angebots/Rechnungs PDF anzeigen.',
    'expired_white_label' => 'Die White-Label-Lizenz ist abgelaufen.',
    'return_to_login' => 'Zurück zum Login',
    'convert_products_tip' => 'Hinweis: Fügen Sie unter :link ein Rechnungsfeld namens ":name" hinzu, um den Wechselkurs anzuzeigen.',
    'amount_greater_than_balance' => 'Der Betrag ist größer als der Rechnungsbetrag, es wird eine Gutschrift mit dem Restbetrag erstellt.',
    'custom_fields_tip' => 'Verwenden Sie <code>Label|Option1,Option2</code> um ein Auswahlfeld anzuzeigen.',
    'client_information' => 'Kundeninformation',
    'updated_client_details' => 'Kundendaten erfolgreich aktualisiert',
    'auto' => 'Automatisch',
    'tax_amount' => 'Steuerwert',
    'tax_paid' => 'Steuern bezahlt',
    'none' => 'Nichts',
    'proposal_message_button' => 'Um Ihren Vorschlag über :amount zu sehen, klicken Sie auf den Knopf unten.',
    'proposal' => 'Vorschlag',
    'proposals' => 'Vorschläge',
    'list_proposals' => 'Vorschläge auflisten',
    'new_proposal' => 'Neuer Vorschlag',
    'edit_proposal' => 'Vorschlag bearbeiten',
    'archive_proposal' => 'Vorschlag archivieren',
    'delete_proposal' => 'Vorschlag löschen',
    'created_proposal' => 'Vorschlag erfolgreich erstellt',
    'updated_proposal' => 'Vorschlag erfolgreich aktualisiert',
    'archived_proposal' => 'Vorschlag erfolgreich archiviert',
    'deleted_proposal' => 'Vorschlag erfolgreich archiviert',
    'archived_proposals' => 'Erfolgreich :count Vorschläge archiviert',
    'deleted_proposals' => 'Erfolgreich :count Vorschläge archiviert',
    'restored_proposal' => 'Vorschlag erfolgreich wiederhergestellt',
    'restore_proposal' => 'Vorschlag wiederherstellen',
    'snippet' => 'Schnipsel',
    'snippets' => 'Schnipsel',
    'proposal_snippet' => 'Schnipsel',
    'proposal_snippets' => 'Schnipsel',
    'new_proposal_snippet' => 'Neuer Schnipsel',
    'edit_proposal_snippet' => 'Schnipsel bearbeiten',
    'archive_proposal_snippet' => 'Schnipsel archivieren',
    'delete_proposal_snippet' => 'Schnipsel löschen',
    'created_proposal_snippet' => 'Schnipsel erfolgreich erstellt',
    'updated_proposal_snippet' => 'Schnipsel erfolgreich geändert',
    'archived_proposal_snippet' => 'Schnipsel erfolgreich archiviert',
    'deleted_proposal_snippet' => 'Schnipsel erfolgreich archiviert',
    'archived_proposal_snippets' => ':count Schnipsel erfolgreich archiviert',
    'deleted_proposal_snippets' => ':count Schnipsel erfolgreich archiviert',
    'restored_proposal_snippet' => 'Schnipsel erfolgreich wieder hergestellt',
    'restore_proposal_snippet' => 'Schnipsel wieder herstellen',
    'template' => 'Vorlage',
    'templates' => 'Vorlagen',
    'proposal_template' => 'Vorlage',
    'proposal_templates' => 'Vorlagen',
    'new_proposal_template' => 'Neue Vorlage',
    'edit_proposal_template' => 'Vorlage bearbeiten',
    'archive_proposal_template' => 'Vorlage archivieren',
    'delete_proposal_template' => 'Vorlage löschen',
    'created_proposal_template' => 'Vorlage erfolgreich erstellt',
    'updated_proposal_template' => 'Vorlage erfolgreich aktualisiert',
    'archived_proposal_template' => 'Vorlage erfolgreich archiviert',
    'deleted_proposal_template' => 'Vorlage erfolgreich archiviert',
    'archived_proposal_templates' => ' :count Vorlagen wurden erfolgreich archiviert',
    'deleted_proposal_templates' => ' :count Vorlagen wurden erfolgreich archiviert',
    'restored_proposal_template' => 'Vorlage erfolgreich wiederhergestellt',
    'restore_proposal_template' => 'Vorlage wiederherstellen',
    'proposal_category' => 'Kategorie',
    'proposal_categories' => 'Kategorien',
    'new_proposal_category' => 'Neue Kategorie',
    'edit_proposal_category' => 'Kategorie bearbeiten',
    'archive_proposal_category' => 'Kategorie archivieren',
    'delete_proposal_category' => 'Kategorie löschen',
    'created_proposal_category' => 'Kategorie erfolgreich erstellt',
    'updated_proposal_category' => 'Kategorie erfolgreich aktualisiert',
    'archived_proposal_category' => 'Kategorie erfolgreich archiviert',
    'deleted_proposal_category' => 'Kategorie erfolgreich archiviert',
    'archived_proposal_categories' => 'Erfolgreich :count Kategorien archiviert',
    'deleted_proposal_categories' => 'Erfolgreich :count Kategorien archiviert',
    'restored_proposal_category' => 'Kategorie erfolgreich wiederhergestellt',
    'restore_proposal_category' => 'Kategorie wiederherstellen',
    'delete_status' => 'Status löschen',
    'standard' => 'Standard',
    'icon' => 'Symbol',
    'proposal_not_found' => 'Der angeforderte Vorschlag ist nicht verfügbar',
    'create_proposal_category' => 'Kategorie erstellen',
    'clone_proposal_template' => 'Vorlage kopieren',
    'proposal_email' => 'Vorschlags Email',
    'proposal_subject' => 'Neuer Vorschlag :number von :account',
    'proposal_message' => 'Um Ihren Vorschlag über :amount zu sehen, klicken Sie auf die Schaltfläche unten.',
    'emailed_proposal' => 'Vorschlag erfolgreich versendet',
    'load_template' => 'Vorlage laden',
    'no_assets' => 'Keine Bilder, hierhin ziehen zum hochladen',
    'add_image' => 'Bild hinzufügen',
    'select_image' => 'Bild auswählen',
    'upgrade_to_upload_images' => 'Upgrade auf den Unternehmensplan zum Hochladen von Bildern',
    'delete_image' => 'Bild löschen',
    'delete_image_help' => 'Warnung: Wenn Sie das Bild löschen, wird es aus allen Vorschlägen entfernt.',
    'amount_variable_help' => 'Hinweis: Das Rechnungsfeld $amount verwendet das Feld Teil-/Anzahlung. Wenn nicht anders eingestellt, wird der Rechnungsbetrag verwendet.',
    'taxes_are_included_help' => 'Hinweis: Inklusive Steuern wurden aktiviert.',
    'taxes_are_not_included_help' => 'Hinweis: Inklusive Steuern sind nicht aktiviert.',
    'change_requires_purge' => 'Die Änderung dieser Einstellung erfordert eine :link der Kontodaten.',
    'purging' => 'Bereinigung',
    'warning_local_refund' => 'Die Rückerstattung wird in der App erfasst, aber NICHT vom Zahlungs-Gateway verarbeitet.',
    'email_address_changed' => 'E-Mail Adresse wurde geändert',
    'email_address_changed_message' => 'Die E-Mail-Adresse für dein Konto wurde von :old_email auf :new_email geändert.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exportieren zu ZIP benötigt die GMP Erweiterung',
    'email_history' => 'E-Mail Historie',
    'loading' => 'Lädt',
    'no_messages_found' => 'Keine Nachrichten gefunden',
    'processing' => 'Verarbeite',
    'reactivate' => 'reaktivieren',
    'reactivated_email' => 'Die E-Mail Adresse wurde wieder aktiviert',
    'emails' => 'E-Mails',
    'opened' => 'Geöffnet',
    'bounced' => 'Abpraller',
    'total_sent' => 'Gesamt gesendet',
    'total_opened' => 'Gesamt geöffnet',
    'total_bounced' => 'Gesamt abgeprallt',
    'total_spam' => 'Gesamt Spam',
    'platforms' => 'Plattformen',
    'email_clients' => 'Email Kunden',
    'mobile' => 'Mobil',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Gruppe',
    'subgroup' => 'Untergruppe',
    'unset' => 'nicht gesetzt',
    'received_new_payment' => 'Du hast eine neue Zahlung erhalten',
    'slack_webhook_help' => 'Erhalten Sie Zahlungsbenachrichtigungen',
    'slack_incoming_webhooks' => 'Slack eingehende Webhooks',
    'accept' => 'Akzeptieren',
    'accepted_terms' => 'Die neuesten Nutzungsbedingungen wurden akzeptiert.',
    'invalid_url' => 'Ungültige URL',
    'workflow_settings' => 'Workflow Einstellungen',
    'auto_email_invoice' => 'Automatische Email',
    'auto_email_invoice_help' => 'Senden Sie wiederkehrende Rechnungen automatisch per E-Mail, wenn sie erstellt werden.',
    'auto_archive_invoice' => 'Automatisches Archiv',
    'auto_archive_invoice_help' => 'Archivieren Sie Rechnungen automatisch, wenn sie bezahlt sind.',
    'auto_archive_quote' => 'Automatisches Archiv',
    'auto_archive_quote_help' => 'Archivieren Sie Angebote automatisch, wenn sie konvertiert werden.',
    'require_approve_quote' => 'Bestätigung für Angebot erfordern',
    'require_approve_quote_help' => 'Erfordern sie die Bestätigung des Kunden für Angebote.',
    'allow_approve_expired_quote' => 'Genehmigung des abgelaufenen Angebots erlauben',
    'allow_approve_expired_quote_help' => 'Erlaube es Kunden, abgelaufene Angebote zu anzunehmen.',
    'invoice_workflow' => 'Rechnungs-Workflow',
    'quote_workflow' => 'Angebots-Workflow',
    'client_must_be_active' => 'Fehler: Der Kunde muss aktiv sein.',
    'purge_client' => 'Kunden bereinigen',
    'purged_client' => 'Kunde erfolgreich bereinigt',
    'purge_client_warning' => 'Alle zugehörigen Datensätze (Rechnungen, Aufgaben, Ausgaben, Dokumente usw.) werden ebenfalls gelöscht.',
    'clone_product' => 'Produkt duplizieren',
    'item_details' => 'Artikeldetails',
    'send_item_details_help' => 'Senden Sie die Einzelpostendetails an das Zahlungsportal.',
    'view_proposal' => 'Vorschlag ansehen',
    'view_in_portal' => 'Im Portal anzeigen',
    'cookie_message' => 'Diese Website verwendet Cookies, um sicherzustellen, dass Sie das beste Ergebnis auf unserer Website erzielen.',
    'got_it' => 'Verstanden!',
    'vendor_will_create' => 'Lieferant wird erstellt',
    'vendors_will_create' => 'Lieferanten werden erstellt',
    'created_vendors' => 'Erfolgreich erstellte :count Lieferant(en)',
    'import_vendors' => 'Lieferanten importieren',
    'company' => 'Firma',
    'client_field' => 'Kundenfeld',
    'contact_field' => 'Kontaktfeld',
    'product_field' => 'Produktfeld',
    'task_field' => 'Aufgabenfeld',
    'project_field' => 'Projektfeld',
    'expense_field' => 'Ausgabenfeld',
    'vendor_field' => 'Lieferantenfeld',
    'company_field' => 'Firmenfeld',
    'invoice_field' => 'Rechnungsfeld',
    'invoice_surcharge' => 'Rechnungsgebühr',
    'custom_task_fields_help' => 'Füge ein Aufgabenfeld hinzu.',
    'custom_project_fields_help' => 'Füge ein Projektfeld hinzu.',
    'custom_expense_fields_help' => 'Füge ein Ausgabenfeld hinzu.',
    'custom_vendor_fields_help' => 'Füge ein Lieferantenfeld hinzu.',
    'messages' => 'Nachrichten',
    'unpaid_invoice' => 'Unbezahlte Rechnung',
    'paid_invoice' => 'Bezahlte Rechnung',
    'unapproved_quote' => 'Nicht genehmigtes Angebot',
    'unapproved_proposal' => 'Nicht genehmigter Vorschlag',
    'autofills_city_state' => 'Automatische Ausfüllung der Stadt / des Bundeslandes',
    'no_match_found' => 'Kein Treffer gefunden',
    'password_strength' => 'Passwortqualität',
    'strength_weak' => 'Schwach',
    'strength_good' => 'Gut',
    'strength_strong' => 'Stark',
    'mark' => 'Markierung',
    'updated_task_status' => 'Aufgabenstatus erfolgreich aktualisiert',
    'background_image' => 'Hintergrundbild',
    'background_image_help' => 'Verwenden Sie den :link zur Verwaltung Ihres Bildes. Wir empfehlen die Verwendung einer kleinen Datei.',
    'proposal_editor' => 'Vorschlag Editor',
    'background' => 'Hintergrund',
    'guide' => 'Leitfaden',
    'gateway_fee_item' => 'Gateway-Gebühren Position',
    'gateway_fee_description' => 'Gateway-Gebühren Zuschlag',
    'gateway_fee_discount_description' => 'Gateway-Gebühren Nachlass',
    'show_payments' => 'Zeige Zahlungen',
    'show_aging' => 'Zeige Alterung',
    'reference' => 'Referenz',
    'amount_paid' => 'Bezahlter Betrag',
    'send_notifications_for' => 'Benachrichtigungen senden für',
    'all_invoices' => 'Alle Rechnungen',
    'my_invoices' => 'Meine Rechnungen',
    'payment_reference' => 'Zahlungsreferenz',
    'maximum' => 'Maximum',
    'sort' => 'Sortierung',
    'refresh_complete' => 'Aktualisieren beendet',
    'please_enter_your_email' => 'Bitte geben Sie Ihre E-Mail-Adresse ein',
    'please_enter_your_password' => 'Bitte geben Sie Ihr Passwort ein',
    'please_enter_your_url' => 'Bitte geben Sie Ihre URL ein',
    'please_enter_a_product_key' => 'Bitte geben Sie Ihren Produkt schlüssel ein',
    'an_error_occurred' => 'Ein Fehler ist aufgetreten',
    'overview' => 'Übersicht',
    'copied_to_clipboard' => ':value in die Zwischenablage kopiert',
    'error' => 'Fehler',
    'could_not_launch' => 'Konnte nicht gestartet werden',
    'additional' => 'Zusätzlich',
    'ok' => 'Ok',
    'email_is_invalid' => 'E-Mail ist ungültig',
    'items' => 'Element',
    'partial_deposit' => 'Teil-/Anzahlung',
    'add_item' => 'Artikel hinzufügen',
    'total_amount' => 'Gesamtbetrag',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Rechnungs Status',
    'click_plus_to_add_item' => 'Klicken Sie auf +, um ein Element hinzuzufügen.',
    'count_selected' => ':count ausgewählt',
    'dismiss' => 'Verwerfen',
    'please_select_a_date' => 'Bitte wählen Sie ein Datum',
    'please_select_a_client' => 'Bitte wählen Sie einen Kunden',
    'language' => 'Sprache',
    'updated_at' => 'Aktualisiert',
    'please_enter_an_invoice_number' => 'Bitte geben Sie eine Rechnungs Nummer ein',
    'please_enter_a_quote_number' => 'Bitte geben Sie eine Angebots Nummer ein',
    'clients_invoices' => ':client\'s Rechnungen',
    'viewed' => 'Angesehen',
    'approved' => 'Bestätigt',
    'invoice_status_1' => 'Entwurf',
    'invoice_status_2' => 'Versendet',
    'invoice_status_3' => 'Angesehen',
    'invoice_status_4' => 'Bestätigt',
    'invoice_status_5' => 'Teilweise',
    'invoice_status_6' => 'Bezahlt',
    'marked_invoice_as_sent' => 'Rechnung erfolgreich als versendet markiert',
    'please_enter_a_client_or_contact_name' => 'Bitte geben Sie einen Kunden- oder Kontaktnamen ein',
    'restart_app_to_apply_change' => 'Starten Sie die App neu, um die Änderung zu übernehmen.',
    'refresh_data' => 'Daten aktualisieren',
    'blank_contact' => 'Leerer Kontakt',
    'no_records_found' => 'Kein Einträge gefunden',
    'industry' => 'Kategorie',
    'size' => 'Größe',
    'net' => 'Netto',
    'show_tasks' => 'Aufgaben anzeigen',
    'email_reminders' => 'E-Mail Erinnerungen',
    'reminder1' => 'Erste Erinnerung',
    'reminder2' => 'Zweite Erinnerung',
    'reminder3' => 'Dritte Erinnerung',
    'send' => 'Senden',
    'auto_billing' => 'Automatische Rechnungsstellung',
    'button' => 'Knopf',
    'more' => 'Mehr',
    'edit_recurring_invoice' => 'Bearbeite wiederkehrende Rechnung',
    'edit_recurring_quote' => 'Bearbeite wiederkehrendes Angebot',
    'quote_status' => 'Angebotsstatus',
    'please_select_an_invoice' => 'Bitte wählen Sie eine Rechnung aus',
    'filtered_by' => 'Gefiltert nach',
    'payment_status' => 'Zahlungsstatus',
    'payment_status_1' => 'Ausstehend',
    'payment_status_2' => 'entwertet',
    'payment_status_3' => 'Fehlgeschlagen',
    'payment_status_4' => 'Abgeschlossen',
    'payment_status_5' => 'Teilweise erstattet',
    'payment_status_6' => 'Erstattet',
    'send_receipt_to_client' => 'Quittung an den Kunden senden',
    'refunded' => 'Erstattet',
    'marked_quote_as_sent' => 'Angebot erfolgreich als versendet markiert',
    'custom_module_settings' => 'Benutzerdefinierte Moduleinstellungen',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'Neues Ticket',
    'edit_ticket' => 'Ticket bearbeiten',
    'view_ticket' => 'Ticket anzeigen',
    'archive_ticket' => 'Ticket archivieren',
    'restore_ticket' => 'Ticket wieder herstellen',
    'delete_ticket' => 'Ticket löschen',
    'archived_ticket' => 'Ticket erfolgreich archiviert',
    'archived_tickets' => 'Ticket erfolgreich archiviert',
    'restored_ticket' => 'Ticket erfolgreich wieder hergestellt',
    'deleted_ticket' => 'Ticket erfolgreich gelöscht',
    'open' => 'Offen',
    'new' => 'Neu',
    'closed' => 'Geschlossen',
    'reopened' => 'Wieder geöffnet',
    'priority' => 'Priorität',
    'last_updated' => 'Zuletzt aktualisiert',
    'comment' => 'Kommentare',
    'tags' => 'Stichworte',
    'linked_objects' => 'Verknüpfte Objekte',
    'low' => 'Niedrig',
    'medium' => 'Mittel',
    'high' => 'Hoch',
    'no_due_date' => 'Kein Fälligkeitsdatum festgelegt',
    'assigned_to' => 'Zugewiesen an',
    'reply' => 'Antwort',
    'awaiting_reply' => 'Warten auf Antwort',
    'ticket_close' => 'Ticket schließen',
    'ticket_reopen' => 'Ticket wieder öffnen',
    'ticket_open' => 'Ticket öffnen',
    'ticket_split' => 'Ticket teilen',
    'ticket_merge' => 'Ticket zusammenführen',
    'ticket_update' => 'Ticket aktualisieren',
    'ticket_settings' => 'Ticket Einstelungen',
    'updated_ticket' => 'Ticket aktualisiert',
    'mark_spam' => 'Als Spam markieren',
    'local_part' => 'Lokaler Teil',
    'local_part_unavailable' => 'Name übernommen',
    'local_part_available' => 'Name verfügbar',
    'local_part_invalid' => 'Ungültiger Name (nur alphanumerisch, keine Leerzeichen)',
    'local_part_help' => 'Passen Sie den lokalen Teil Ihrer Inbound-Support-E-Mail an, z.B. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => '"Von Name" ist der erkennbare Absender, der anstelle der E-Mail-Adresse angezeigt wird, z.B. "Support Center".',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Anhänge',
    'client_upload' => 'Kunden-Uploads',
    'enable_client_upload_help' => 'Ermöglicht es Kunden, Dokumente/Anhänge hochzuladen.',
    'max_file_size_help' => 'Die maximale Dateigröße (KB) wird durch die Variablen post_max_size und upload_max_filesize begrenzt, wie sie in Ihrer PHP.INI festgelegt sind.',
    'max_file_size' => 'Maximale Dateigröße',
    'mime_types' => 'Mime-Typen',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Kommagetrennte Liste der zulässigen Mime-Typen, leer lassen für alle',
    'ticket_number_start_help' => 'Die Ticketnummer muss größer sein als die aktuelle Ticketnummer.',
    'new_ticket_template_id' => 'Neues Ticket',
    'new_ticket_autoresponder_help' => 'Die Auswahl einer Vorlage sendet eine automatische Antwort an einen Kunden/Kontakt, wenn ein neues Ticket erstellt wird.',
    'update_ticket_template_id' => 'Ticket aktualisiert',
    'update_ticket_autoresponder_help' => 'Die Auswahl einer Vorlage sendet eine automatische Antwort an einen Kunden/Kontakt, wenn ein Ticket aktualisiert wird.',
    'close_ticket_template_id' => 'Ticket geschlossen',
    'close_ticket_autoresponder_help' => 'Die Auswahl einer Vorlage sendet eine automatische Antwort an einen Kunden/Kontakt, wenn ein Ticket geschlossen ist.',
    'default_priority' => 'Standardpriorität',
    'alert_new_comment_id' => 'Neuer Kommentar',
    'alert_comment_ticket_help' => 'Die Auswahl einer Vorlage sendet eine Benachrichtigung (an den Agenten), wenn ein Kommentar abgegeben wird.',
    'alert_comment_ticket_email_help' => 'Komma getrennte E-Mails an bcc bei neuem Kommentar.',
    'new_ticket_notification_list' => 'Zusätzliche neue Ticket-Benachrichtigungen',
    'update_ticket_notification_list' => 'Zusätzliche Benachrichtigungen über neue Kommentare',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticketzuweisung',
    'alert_ticket_assign_agent_id_hel' => 'Die Auswahl einer Vorlage sendet eine Benachrichtigung (an den Agenten), wenn ein Ticket zugewiesen wird.',
    'alert_ticket_assign_agent_id_notifications' => 'Zusätzliche Ticketbenachrichtigungen',
    'alert_ticket_assign_agent_id_help' => 'Komma getrennte E-Mails an bcc bei der Ticketvergabe.',
    'alert_ticket_transfer_email_help' => 'Komma getrennte E-Mails an bcc bei der Ticketübertragung.',
    'alert_ticket_overdue_agent_id' => 'Ticket überfällig',
    'alert_ticket_overdue_email' => 'Zusätzliche überfällige Ticket-Benachrichtigungen',
    'alert_ticket_overdue_email_help' => 'Komma getrennte E-Mails an bcc bei überfälligem Ticket.',
    'alert_ticket_overdue_agent_id_help' => 'Die Auswahl einer Vorlage sendet eine Benachrichtigung (an den Agenten), wenn ein Ticket überfällig wird.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Hat die Fähigkeit, Tickets zuzuordnen und zu übertragen. Wird als Standard-Agent für alle Tickets zugewiesen.',
    'default_agent' => 'Standard-Agent',
    'default_agent_help' => 'Wenn ausgewählt, wird er automatisch allen eingehenden Tickets zugeordnet.',
    'show_agent_details' => 'Zeigen Sie Agentendetails in den Antworten an',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Avatar entfernen',
    'ticket_not_found' => 'Ticket nicht gefunden',
    'add_template' => 'Vorlage hinzufügen',
    'ticket_template' => 'Ticket Vorlage',
    'ticket_templates' => 'Ticket Vorlagen',
    'updated_ticket_template' => 'Ticket Vorlage aktualisiert',
    'created_ticket_template' => 'Ticket Vorlage erstellt',
    'archive_ticket_template' => 'Vorlage archiviert',
    'restore_ticket_template' => 'Vorlage wieder herstellen',
    'archived_ticket_template' => 'Vorlage erfolgreich archiviert',
    'restored_ticket_template' => 'Vorlage erfolgreich wieder hergestellt',
    'close_reason' => 'Lassen Sie uns wissen, warum Sie dieses Ticket schließen.',
    'reopen_reason' => 'Lassen Sie uns wissen, warum Sie dieses Ticket wieder öffnen.',
    'enter_ticket_message' => 'Bitte geben Sie eine Nachricht ein, um das Ticket zu aktualisieren.',
    'show_hide_all' => 'Alle anzeigen / verstecken',
    'subject_required' => 'Betreff erforderlich',
    'mobile_refresh_warning' => 'Wenn Sie die mobile App verwenden, müssen Sie möglicherweise eine vollständige Aktualisierung durchführen.',
    'enable_proposals_for_background' => 'So laden Sie ein Hintergrundbild hoch :link zum Aktivieren des Vorschlagsmoduls.',
    'ticket_assignment' => 'Ticket :ticket_number wurde dem :agent zugewiesen.',
    'ticket_contact_reply' => 'Ticket :ticket_number wurde vom Kunden :contact aktualisiert',
    'ticket_new_template_subject' => 'Ticket :ticket_number wurde erstellt.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number wurde aktualisiert.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number wurde geschlossen.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number ist jetzt überfällig.',
    'merge' => 'Zusammenführen',
    'merged' => 'Zusammengeführt',
    'agent' => 'Agent',
    'parent_ticket' => 'Übergeordnetes Ticket',
    'linked_tickets' => 'Verknüpfte Tickets',
    'merge_prompt' => 'Geben Sie die Ticketnummer ein, mit der Sie zusammenführen möchten.',
    'merge_from_to' => 'Ticket #:old_ticket mit Ticket #:new_ticket zusammengeführt',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket wurde geschlossen und in Ticket#:new_ticket zusammengeführt -:: Subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket wurde geschlossen und mit diesem Ticket zusammengeführt.',
    'merge_placeholder' => 'Zusammenführen von Ticket #:ticket in das folgende Ticket',
    'select_ticket' => 'Ticket auswählen',
    'new_internal_ticket' => 'Neues internes Ticket',
    'internal_ticket' => 'Internes Ticket',
    'create_ticket' => 'Ticket erstellen',
    'allow_inbound_email_tickets_external' => 'Neue Tickets per E-Mail (Kunde)',
    'allow_inbound_email_tickets_external_help' => 'Ermöglicht es Kunden, neue Tickets per E-Mail zu erstellen.',
    'include_in_filter' => 'In den Filter aufnehmen',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Vergleiche',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Vielen Dank für Ihre Geduld, während wir an der Implementierung dieser Funktionen arbeiten. Wir hoffen, dass sie in den nächsten Monaten fertiggestellt werden.... Bis dahin werden wir weiterhin die',
    'legacy_mobile_app' => 'legacy Mobile App',
    'today' => 'Heute',
    'current' => 'Aktuell',
    'previous' => 'Vorherige',
    'current_period' => 'Aktuelle Periode',
    'comparison_period' => 'Vergleichsperiode',
    'previous_period' => 'Vorherige Periode',
    'previous_year' => 'Vorjahr',
    'compare_to' => 'Vergleiche mit',
    'last_week' => 'Letzte Woche',
    'clone_to_invoice' => 'Klone in Rechnung',
    'clone_to_quote' => 'Klone in Angebot',
    'convert' => 'Konvertiere',
    'last7_days' => 'Letzte 7 Tage',
    'last30_days' => 'Letzte 30 Tage',
    'custom_js' => 'Benutzerdefiniert JS',
    'adjust_fee_percent_help' => 'Gebühren Prozentsatz an das Konto anpassen',
    'show_product_notes' => 'Produktdetails anzeigen',
    'show_product_notes_help' => 'Fügt die <b>Beschreibung und die Kosten</b> in die Produkt-Dropdown-Liste ein',
    'important' => 'Wichtig',
    'thank_you_for_using_our_app' => 'Vielen Dank, dass Sie unsere App nutzen!',
    'if_you_like_it' => 'Wenn es dir gefällt, bitte',
    'to_rate_it' => ', um es zu bewerten.',
    'average' => 'Durchschnittlich',
    'unapproved' => 'Nicht genehmigt',
    'authenticate_to_change_setting' => 'Bitte authentifizieren Sie sich, um diese Einstellung zu ändern.',
    'locked' => 'Gesperrt',
    'authenticate' => 'Authentifizieren',
    'please_authenticate' => 'Bitte authentifizieren Sie sich',
    'biometric_authentication' => 'Biometrische Authentifizierung',
    'auto_start_tasks' => 'Aufgaben für den automatischen Start',
    'budgeted' => 'Budgetiert',
    'please_enter_a_name' => 'Bitte geben Sie einen Namen ein',
    'click_plus_to_add_time' => 'Klicken Sie auf +, um die Zeit hinzuzufügen.',
    'design' => 'Design',
    'password_is_too_short' => 'Das Passwort ist zu kurz',
    'failed_to_find_record' => 'Eintrag konnte nicht gefunden werden',
    'valid_until_days' => 'Gültig bis',
    'valid_until_days_help' => 'Setzt <b>Gültig bis</b> von Angeboten automatisch auf die Anzahl der Tage in der Zukunft. Zum deaktivieren Feld frei lassen.    ',
    'usually_pays_in_days' => 'Tage',
    'requires_an_enterprise_plan' => 'Benötigt einen Enterprise Plan',
    'take_picture' => 'Bild aufnehmen',
    'upload_file' => 'Datei hochladen',
    'new_document' => 'Neues Dokument',
    'edit_document' => 'Dokument bearbeiten',
    'uploaded_document' => 'Dokument erfolgreich hochgeladen',
    'updated_document' => 'Dokument erfolgreich aktualisiert',
    'archived_document' => 'Dokument erfolgreich archiviert',
    'deleted_document' => 'Dokument erfolgreich gelöscht',
    'restored_document' => 'Dokument erfolgreich wiederhergestellt',
    'no_history' => 'Kein Verlauf',
    'expense_status_1' => 'Aufgezeichnet',
    'expense_status_2' => 'Ausstehend',
    'expense_status_3' => 'Fakturiert',
    'no_record_selected' => 'Kein Eintrag ausgewählt',
    'error_unsaved_changes' => 'Bitte speichern oder verwerfen Sie Ihre Änderungen',
    'thank_you_for_your_purchase' => 'Vielen Dank für Ihren Kauf!',
    'redeem' => 'Einlösen',
    'back' => 'Zurück',
    'past_purchases' => 'Vergangene Käufe',
    'annual_subscription' => 'Jahres-Abonnement',
    'pro_plan' => 'Pro-Tarif',
    'enterprise_plan' => 'Enterprise-Tarif',
    'count_users' => ':count Benutzer',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Bitte geben Sie einen Vornamen ein',
    'please_enter_a_last_name' => 'Bitte geben Sie einen Nachnamen ein',
    'please_agree_to_terms_and_privacy' => 'Bitte stimmen Sie den Nutzungsbedingungen und der Datenschutzerklärung zu, um ein Konto zu erstellen.',
    'i_agree_to_the' => 'Ich stimme den',
    'terms_of_service_link' => 'Nutzungsbedingungen',
    'privacy_policy_link' => 'Datenschutzerklärung',
    'view_website' => 'Webseite anschauen',
    'create_account' => 'Konto erstellen',
    'email_login' => 'E-Mail-Anmeldung',
    'late_fees' => 'Verspätungszuschläge',
    'payment_number' => 'Zahlungsnummer',
    'before_due_date' => 'Vor dem Fälligkeitsdatum',
    'after_due_date' => 'Nach dem Fälligkeitsdatum',
    'after_invoice_date' => 'Nach dem Rechnungsdatum',
    'filtered_by_user' => 'Gefiltert nach Benutzer',
    'created_user' => 'Benutzer erfolgreich erstellt',
    'primary_font' => 'Primäre Schriftart',
    'secondary_font' => 'Sekundäre Schriftart',
    'number_padding' => 'Nummernabstand',
    'general' => 'Allgemein',
    'surcharge_field' => 'Zuschlagsfeld',
    'company_value' => 'Firmenwert',
    'credit_field' => 'Kredit-Feld',
    'payment_field' => 'Zahlungs-Feld',
    'group_field' => 'Gruppen-Feld',
    'number_counter' => 'Nummernzähler',
    'number_pattern' => 'Nummernschema',
    'custom_javascript' => 'Benutzerdefiniertes JavaScript',
    'portal_mode' => 'Portalmodus',
    'attach_pdf' => 'PDF anhängen',
    'attach_documents' => 'Dokumente anhängen',
    'attach_ubl' => 'UBL anhängen',
    'email_style' => 'E-Mail-Stil',
    'processed' => 'Verarbeitet',
    'fee_amount' => 'Zuschlag Betrag',
    'fee_percent' => 'Zuschlag Prozent',
    'fee_cap' => 'Gebührenobergrenze',
    'limits_and_fees' => 'Grenzwerte/Gebühren',
    'credentials' => 'Zugangsdaten',
    'require_billing_address_help' => 'Kunde muss seine Rechnungsadresse angeben',
    'require_shipping_address_help' => 'Kunde muss seine Lieferadresse angeben',
    'deleted_tax_rate' => 'Steuersatz erfolgreich gelöscht',
    'restored_tax_rate' => 'Steuersatz erfolgreich wiederhergestellt',
    'provider' => 'Anbieter',
    'company_gateway' => 'Zahlungs-Gateway',
    'company_gateways' => 'Zahlungs-Gateways',
    'new_company_gateway' => 'Neues Gateway',
    'edit_company_gateway' => 'Gateway bearbeiten',
    'created_company_gateway' => 'Gateway erfolgreich erstellt',
    'updated_company_gateway' => 'Gateway erfolgreich aktualisiert',
    'archived_company_gateway' => 'Gateway erfolgreich archiviert',
    'deleted_company_gateway' => 'Gateway erfolgreich gelöscht',
    'restored_company_gateway' => 'Gateway erfolgreich wiederhergestellt',
    'continue_editing' => 'Weiterbearbeiten',
    'default_value' => 'Standardwert',
    'currency_format' => 'Währungsformat',
    'first_day_of_the_week' => 'Erster Tag der Woche',
    'first_month_of_the_year' => 'Erster Monat des Jahres',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Datumsformat',
    'datetime_format' => 'Datums-/Zeitformat',
    'send_reminders' => 'Erinnerungen senden',
    'timezone' => 'Zeitzone',
    'filtered_by_group' => 'Gefiltert nach Gruppe',
    'filtered_by_invoice' => 'Gefiltert nach Rechnung',
    'filtered_by_client' => 'Gefiltert nach Kunde',
    'filtered_by_vendor' => 'Gefiltert nach Lieferant',
    'group_settings' => 'Gruppeneinstellungen',
    'groups' => 'Gruppen',
    'new_group' => 'Neue Gruppe',
    'edit_group' => 'Gruppe bearbeiten',
    'created_group' => 'Gruppe erfolgreich erstellt',
    'updated_group' => 'Gruppe erfolgreich aktualisiert',
    'archived_group' => 'Gruppe erfolgreich archiviert',
    'deleted_group' => 'Gruppe erfolgreich gelöscht',
    'restored_group' => 'Gruppe erfolgreich wiederhergestellt',
    'upload_logo' => 'Logo hochladen',
    'uploaded_logo' => 'Logo erfolgreich hochgeladen',
    'saved_settings' => 'Einstellungen erfolgreich gespeichert',
    'device_settings' => 'Geräteeinstellungen',
    'credit_cards_and_banks' => 'Kreditkarten & Banken',
    'price' => 'Preis',
    'email_sign_up' => 'E-Mail-Registrierung',
    'google_sign_up' => 'Registrierung via Google',
    'sign_up_with_google' => 'Mit Google registrieren',
    'long_press_multiselect' => 'Mehrfachauswahl durch langes Drücken',
    'migrate_to_next_version' => 'Zur nächsten Version von Invoice Ninja migrieren',
    'migrate_intro_text' => 'Wir haben an der nächsten Invoice Ninja Version gearbeitet. Klicke auf den Button unten um die Migration auf die neue Version zu starten.',
    'start_the_migration' => 'Starte die Migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Herzlich willkommen zur neuen Version von Invoice Ninja',
    'next_step_data_download' => 'Im nächsten Schritt können Sie Ihre Daten für die Migration herunterladen.',
    'download_data' => 'Drücke den Button darunter, um die Daten herunterzuladen.',
    'migration_import' => 'Fantastisch! Jetzt bist du bereit, die Migrationsdaten zu importieren. Gehe zu deiner neuen Installation, um deine Daten zu importieren.',
    'continue' => 'Weiter',
    'company1' => 'Benutzerdefinierte Firma 1',
    'company2' => 'Benutzerdefinierte Firma 2',
    'company3' => 'Benutzerdefinierte Firma 3',
    'company4' => 'Benutzerdefinierte Firma 4',
    'product1' => 'Benutzerdefiniertes Produkt 1',
    'product2' => 'Benutzerdefiniertes Produkt 2',
    'product3' => 'Benutzerdefiniertes Produkt 3',
    'product4' => 'Benutzerdefiniertes Produkt 4',
    'client1' => 'Benutzerdefinierter Kunde 1',
    'client2' => 'Benutzerdefinierter Kunde 2',
    'client3' => 'Benutzerdefinierter Kunde 3',
    'client4' => 'Benutzerdefinierter Kunde 4',
    'contact1' => 'Benutzerdefinierter Kontakt 1',
    'contact2' => 'Benutzerdefinierter Kontakt 2',
    'contact3' => 'Benutzerdefinierter Kontakt 3',
    'contact4' => 'Benutzerdefinierter Kontakt 4',
    'task1' => 'Benutzerdefinierte Aufgabe 1',
    'task2' => 'Benutzerdefinierte Aufgabe 2',
    'task3' => 'Benutzerdefinierte Aufgabe 3',
    'task4' => 'Benutzerdefinierte Aufgabe 4',
    'project1' => 'Benutzerdefiniertes Projekt 1',
    'project2' => 'Benutzerdefiniertes Projekt 2',
    'project3' => 'Benutzerdefiniertes Projekt 3',
    'project4' => 'Benutzerdefiniertes Projekt 4',
    'expense1' => 'Benutzerdefinierte Ausgabe 1',
    'expense2' => 'Benutzerdefinierte Ausgabe 2',
    'expense3' => 'Benutzerdefinierte Ausgabe 3',
    'expense4' => 'Benutzerdefinierte Ausgabe 4',
    'vendor1' => 'Benutzerdefinierter Lieferant 1',
    'vendor2' => 'Benutzerdefinierter Lieferant 2',
    'vendor3' => 'Benutzerdefinierter Lieferant 3',
    'vendor4' => 'Benutzerdefinierter Lieferant 4',
    'invoice1' => 'Benutzerdefinierte Rechnung 1',
    'invoice2' => 'Benutzerdefinierte Rechnung 2',
    'invoice3' => 'Benutzerdefinierte Rechnung 3',
    'invoice4' => 'Benutzerdefinierte Rechnung 4',
    'payment1' => 'Benutzerdefinierte Zahlung 1',
    'payment2' => 'Benutzerdefinierte Zahlung 2',
    'payment3' => 'Benutzerdefinierte Zahlung 3',
    'payment4' => 'Benutzerdefinierte Zahlung 4',
    'surcharge1' => 'Benutzerdefinierter Zuschlag 1',
    'surcharge2' => 'Benutzerdefinierter Zuschlag 2',
    'surcharge3' => 'Benutzerdefinierter Zuschlag 3',
    'surcharge4' => 'Benutzerdefinierter Zuschlag 4',
    'group1' => 'Benutzerdefinierte Gruppe 1',
    'group2' => 'Benutzerdefinierte Gruppe 2',
    'group3' => 'Benutzerdefinierte Gruppe 3',
    'group4' => 'Benutzerdefinierte Gruppe 4',
    'number' => 'Nummer',
    'count' => 'Anzahl',
    'is_active' => 'Ist aktiv',
    'contact_last_login' => 'Letzter Login des Kontakts',
    'contact_full_name' => 'Vollständiger Name des Kontakts',
    'contact_custom_value1' => 'Kontakt Benutzerdefinierter Wert 1',
    'contact_custom_value2' => 'Kontakt Benutzerdefinierter Wert 2',
    'contact_custom_value3' => 'Kontakt Benutzerdefinierter Wert 3',
    'contact_custom_value4' => 'Kontakt Benutzerdefinierter Wert 4',
    'assigned_to_id' => 'Zugewiesen zur ID',
    'created_by_id' => 'Erstellt von ID',
    'add_column' => 'Spalte hinzufügen',
    'edit_columns' => 'Spalten bearbeiten',
    'to_learn_about_gogle_fonts' => 'um über Google Fonts zu lernen',
    'refund_date' => 'Erstattungsdatum',
    'multiselect' => 'Mehrfachauswahl',
    'verify_password' => 'Passwort überprüfen',
    'applied' => 'Angewendet',
    'include_recent_errors' => 'Kürzliche Fehler aus den Logs einfügen',
    'your_message_has_been_received' => 'Wir haben ihre Nachricht erhalten und bemühen uns schnellstmöglich zu antworten.',
    'show_product_details' => 'Produktdetails anzeigen',
    'show_product_details_help' => 'Beschreibung und Kosten in die Produkt-Dropdown-Liste einfügen',
    'pdf_min_requirements' => 'Der PDF-Renderer benötigt :version',
    'adjust_fee_percent' => 'Anpassungszuschlag Prozent',
    'configure_settings' => 'Einstellungen bearbeiten',
    'about' => 'Über',
    'credit_email' => 'Guthaben E-Mail',
    'domain_url' => 'Domain-URL',
    'password_is_too_easy' => 'Das Passwort muss einen Großbuchstaben und eine Nummer enthalten',
    'client_portal_tasks' => 'Kundenportal-Aufgaben',
    'client_portal_dashboard' => 'Kundenportal-Übersicht',
    'please_enter_a_value' => 'Bitte einen Wert eingeben',
    'deleted_logo' => 'Logo erfolgreich gelöscht',
    'generate_number' => 'Nummer generieren',
    'when_saved' => 'Wenn gespeichert',
    'when_sent' => 'Wenn gesendet',
    'select_company' => 'Firma auswählen',
    'float' => 'Schwebend',
    'collapse' => 'Einklappen',
    'show_or_hide' => 'Anzeigen/verstecken',
    'menu_sidebar' => 'Menüleiste',
    'history_sidebar' => 'Verlaufs-Seitenleiste',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Modul',
    'first_custom' => 'Erste benutzerdefinierte',
    'second_custom' => 'Zweite benutzerdefinierte',
    'third_custom' => 'Dritte benutzerdefinierte',
    'show_cost' => 'Kosten anzeigen',
    'show_cost_help' => 'Feld für Einkaufspreis anzeigen, um Gewinnspanne zu verfolgen',
    'show_product_quantity' => 'Produktanzahl anzeigen',
    'show_product_quantity_help' => 'Zeigen ein Mengenangabe Feld, sonst den Standardwert 1',
    'show_invoice_quantity' => 'Rechnungsanzahl anzeigen',
    'show_invoice_quantity_help' => 'Zeige ein Rechnungsposten Anzahlfeld, sonst den Standardwert 1',
    'default_quantity' => 'Standardanzahl',
    'default_quantity_help' => 'Setze den Rechnungsposten automatisch auf Anzahl 1',
    'one_tax_rate' => 'Ein Steuersatz',
    'two_tax_rates' => 'Zwei Steuersätze',
    'three_tax_rates' => 'Drei Steuersätze',
    'default_tax_rate' => 'Standard-Steuersatz',
    'invoice_tax' => 'Rechnungssteuer',
    'line_item_tax' => 'Belegposition Steuer',
    'inclusive_taxes' => 'Inklusive Steuern',
    'invoice_tax_rates' => 'Rechnungs-Steuersätze',
    'item_tax_rates' => 'Element-Steuersätze',
    'configure_rates' => 'Steuersätze bearbeiten',
    'tax_settings_rates' => 'Steuersätze',
    'accent_color' => 'Akzent-Farbe',
    'comma_sparated_list' => 'Komma-separierte Liste',
    'single_line_text' => 'Einzeiliger Text',
    'multi_line_text' => 'Mehrzeiliger Text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Feldtyp',
    'recover_password_email_sent' => 'Eine Passwort-Wiederherstellungs-Mail wurde versendet',
    'removed_user' => 'Benutzer erfolgreich entfernt',
    'freq_three_years' => 'Drei Jahre',
    'military_time_help' => '24-Stunden-Anzeige',
    'click_here_capital' => 'Klicke hier',
    'marked_invoice_as_paid' => 'Die Rechnung wurde erfolgreich als "versendet" markiert',
    'marked_invoices_as_sent' => 'Erfolgreich Rechnungen als versendet markiert',
    'marked_invoices_as_paid' => 'Die Rechnung wurde erfolgreich als "versendet" markiert',
    'activity_57' => 'Das System konnte die Rechnung :invoice nicht per E-Mail versenden',
    'custom_value3' => 'Benutzerdefinierter Wert 3',
    'custom_value4' => 'Benutzerdefinierter Wert 4',
    'email_style_custom' => 'Benutzer definierter E-Mail-Stil',
    'custom_message_dashboard' => 'Benutzerdefinierte Dashboard-Nachricht',
    'custom_message_unpaid_invoice' => 'Benutzerdefinierte Nachricht für unbezahlte Rechnung',
    'custom_message_paid_invoice' => 'Benutzerdefinierte Nachricht für bezahlte Rechnung',
    'custom_message_unapproved_quote' => 'Benutzerdefinierte Nachricht für nicht genehmigten Kostenvoranschlag',
    'lock_sent_invoices' => 'Sperre versendete Rechnungen',
    'translations' => 'Übersetzungen',
    'task_number_pattern' => 'Aufgabennummernschema',
    'task_number_counter' => 'Aufgabennummernzähler',
    'expense_number_pattern' => 'Ausgabennummernschema',
    'expense_number_counter' => 'Ausgabennummernzähler',
    'vendor_number_pattern' => 'Lieferantennummernschema',
    'vendor_number_counter' => 'Lieferantennummernzähler',
    'ticket_number_pattern' => 'Ticketnummernschema',
    'ticket_number_counter' => 'Ticketnummernzähler',
    'payment_number_pattern' => 'Zahlungsnummernschema',
    'payment_number_counter' => 'Zahlungsnummernzähler',
    'invoice_number_pattern' => 'Rechnungsnummernschema',
    'quote_number_pattern' => 'Kostenvoranschlags-Nummernschema',
    'client_number_pattern' => 'Gutschriftnummernschema',
    'client_number_counter' => 'Gutschriftnummernzähler',
    'credit_number_pattern' => 'Gutschriftnummernzähler',
    'credit_number_counter' => 'Gutschriftnummernzähler',
    'reset_counter_date' => 'Zählerdatum zurücksetzen',
    'counter_padding' => 'Zähler-Innenabstand',
    'shared_invoice_quote_counter' => 'Gemeinsamen Nummernzähler für Rechnungen und Angebote verwenden',
    'default_tax_name_1' => 'Standard-Steuername 1',
    'default_tax_rate_1' => 'Standard-Steuersatz 1',
    'default_tax_name_2' => 'Standard-Steuername 2',
    'default_tax_rate_2' => 'Standard-Steuersatz 2',
    'default_tax_name_3' => 'Standard-Steuername 3',
    'default_tax_rate_3' => 'Standard-Steuersatz 3',
    'email_subject_invoice' => 'EMail Rechnung Betreff',
    'email_subject_quote' => 'EMail Angebot Betreff',
    'email_subject_payment' => 'EMail Zahlung Betreff',
    'switch_list_table' => 'Listenansicht umschalten',
    'client_city' => 'Kunden-Stadt',
    'client_state' => 'Kunden-Bundesland/Kanton',
    'client_country' => 'Kunden-Land',
    'client_is_active' => 'Kunde ist aktiv',
    'client_balance' => 'Kunden Betrag',
    'client_address1' => 'Straße des Kunden',
    'client_address2' => 'Adresszusatz',
    'client_shipping_address1' => 'Strasse Kundenlieferanschrift',
    'client_shipping_address2' => 'Addresszusatz Kundenlieferadresse',
    'tax_rate1' => 'Steuersatz 1',
    'tax_rate2' => 'Steuersatz 2',
    'tax_rate3' => 'Steuersatz 3',
    'archived_at' => 'Archiviert um',
    'has_expenses' => 'Hat Ausgaben',
    'custom_taxes1' => 'Benutzerdefinierte Steuern 1',
    'custom_taxes2' => 'Benutzerdefinierte Steuern 2',
    'custom_taxes3' => 'Benutzerdefinierte Steuern 3',
    'custom_taxes4' => 'Benutzerdefinierte Steuern 4',
    'custom_surcharge1' => 'Benutzerdefinierter Zuschlag 1',
    'custom_surcharge2' => 'Benutzerdefinierter Zuschlag 2',
    'custom_surcharge3' => 'Benutzerdefinierter Zuschlag 3',
    'custom_surcharge4' => 'Benutzerdefinierter Zuschlag 4',
    'is_deleted' => 'ist gelöscht',
    'vendor_city' => 'Lieferanten-Stadt',
    'vendor_state' => 'Lieferanten-Bundesland/Kanton',
    'vendor_country' => 'Lieferanten-Land',
    'credit_footer' => 'Guthaben-Fußzeile',
    'credit_terms' => 'Gutschrift Bedingungen',
    'untitled_company' => 'Unbenannte FIrma',
    'added_company' => 'Erfolgreich Firma hinzugefügt',
    'supported_events' => 'Unterstützte Ereignisse',
    'custom3' => 'Benutzerdefiniert 3',
    'custom4' => 'Benutzerdefiniert 3',
    'optional' => 'optional',
    'license' => 'Lizenz',
    'invoice_balance' => 'Rechnungssaldo',
    'saved_design' => 'Design erfolgreich gespeichert',
    'client_details' => 'Kundeninformationen',
    'company_address' => 'Firmenadresse',
    'quote_details' => 'Kostenvoranschlag-Details',
    'credit_details' => 'Gutschrift Details',
    'product_columns' => 'Produktspalten',
    'task_columns' => 'Aufgabenspalten',
    'add_field' => 'Feld hinzufügen',
    'all_events' => 'Alle Ereignisse',
    'owned' => 'Eigentümer',
    'payment_success' => 'Bezahlung erfolgreich',
    'payment_failure' => 'Bezahlung fehlgeschlagen',
    'quote_sent' => 'Kostenvoranschlag versendet',
    'credit_sent' => 'Guthaben gesendet',
    'invoice_viewed' => 'Rechnung angesehen',
    'quote_viewed' => 'Kostenvoranschlag angesehen',
    'credit_viewed' => 'Guthaben angesehen',
    'quote_approved' => 'Kostenvoranschlag angenommen',
    'receive_all_notifications' => 'Empfange alle Benachrichtigungen',
    'purchase_license' => 'Lizenz kaufen',
    'enable_modules' => 'Module aktivieren',
    'converted_quote' => 'Angebot erfolgreichen konvertiert',
    'credit_design' => 'Guthaben Design',
    'includes' => 'Beinhaltet',
    'css_framework' => 'CSS-Framework',
    'custom_designs' => 'Benutzerdefinierte Designs',
    'designs' => 'Designs',
    'new_design' => 'Neues Design',
    'edit_design' => 'Design bearbeiten',
    'created_design' => 'Design erfolgreich erstellt',
    'updated_design' => 'Design erfolgreich aktualisiert',
    'archived_design' => 'Design erfolgreich archiviert',
    'deleted_design' => 'Design erfolgreich gelöscht',
    'removed_design' => 'Design erfolgreich entfernt',
    'restored_design' => 'Design erfolgreich wiederhergestellt',
    'recurring_tasks' => 'Wiederkehrende Aufgabe',
    'removed_credit' => 'Guthaben erfolgreich entfernt',
    'latest_version' => 'Neueste Version',
    'update_now' => 'Jetzt aktualisieren',
    'a_new_version_is_available' => 'Eine neue Version der Webapp ist verfügbar.',
    'update_available' => 'Update verfügbar',
    'app_updated' => 'Update erfolgreich',
    'integrations' => 'Integrationen',
    'tracking_id' => 'Sendungsnummer',
    'slack_webhook_url' => 'Slack-Webhook-URL',
    'partial_payment' => 'Teilzahlung',
    'partial_payment_email' => 'Teilzahlungsmail',
    'clone_to_credit' => 'Duplizieren in Gutschrift',
    'emailed_credit' => 'Guthaben erfolgreich per E-Mail versendet',
    'marked_credit_as_sent' => 'Guthaben erfolgreich als versendet markiert',
    'email_subject_payment_partial' => 'EMail Teilzahlung Betreff',
    'is_approved' => 'Wurde angenommen',
    'migration_went_wrong' => 'Upps, da ist etwas schiefgelaufen! Stellen Sie sicher, dass Sie InvoiceNinja v5 richtig eingerichtet haben, bevor Sie die Migration starten.',
    'cross_migration_message' => 'Kontoübergreifende Migration ist nicht erlaubt. Mehr Informationen finden Sie hier:
https://invoiceninja.github.io/docs/migration/#troubleshooting',
    'email_credit' => 'Guthaben per E-Mail versenden',
    'client_email_not_set' => 'Es wurde noch keine E-Mail Adresse beim Kunden eingetragen.',
    'ledger' => 'Hauptbuch',
    'view_pdf' => 'Zeige PDF',
    'all_records' => 'Alle Einträge',
    'owned_by_user' => 'Eigentümer',
    'credit_remaining' => 'Verbleibendes Guthaben',
    'use_default' => 'Benutze Standardwert',
    'reminder_endless' => 'Endlose Reminder',
    'number_of_days' => 'Anzahl Tage',
    'configure_payment_terms' => 'Zahlungsbedingungen bearbeiten',
    'payment_term' => 'Zahlungsbedingung',
    'new_payment_term' => 'Neue Zahlungsbedingung',
    'deleted_payment_term' => 'Zahlungsbedingung erfolgreich gelöscht',
    'removed_payment_term' => 'Zahlungsbedingung erfolgreich entfernt',
    'restored_payment_term' => 'Zahlungsbedingungen erfolgreich wiederhergestellt',
    'full_width_editor' => 'Editor über die gesamte Breite',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Mit E-Mail anmelden',
    'change' => 'Ändern',
    'change_to_mobile_layout' => 'Möchten Sie zur mobilen Ansicht wechseln?',
    'change_to_desktop_layout' => 'Möchten Sie zur Desktopansicht wechseln?',
    'send_from_gmail' => 'Mit Gmail versenden',
    'reversed' => 'Umgekehrt',
    'cancelled' => 'Storniert',
    'quote_amount' => 'Angebotsbetrag',
    'hosted' => 'Gehostet',
    'selfhosted' => 'Selbstgehostet',
    'hide_menu' => 'Menü ausblenden',
    'show_menu' => 'Menü einblenden',
    'partially_refunded' => 'Teilweise erstattet',
    'search_documents' => 'Suche nach Dokumenten',
    'search_designs' => 'Suche nach Designs',
    'search_invoices' => 'Suche Rechnungen',
    'search_clients' => 'Suche Kunden',
    'search_products' => 'Suche Produkte',
    'search_quotes' => 'Suche Angebote',
    'search_credits' => 'Suche Guthaben',
    'search_vendors' => 'Suche Lieferanten',
    'search_users' => 'Suche Benutzer',
    'search_tax_rates' => 'Suche Steuersatz',
    'search_tasks' => 'Suche Aufgaben',
    'search_settings' => 'Suche Einstellungen',
    'search_projects' => 'Suche nach Projekten',
    'search_expenses' => 'Suche Ausgaben',
    'search_payments' => 'Suche Zahlungen',
    'search_groups' => 'Suche nach Gruppen',
    'search_company' => 'Suche Firma',
    'cancelled_invoice' => 'Rechnung erfolgreich storniert',
    'cancelled_invoices' => 'Rechnungen erfolgreich storniert',
    'reversed_invoice' => 'Rechnung erfolgreich zurückgebucht',
    'reversed_invoices' => 'Rechnungen erfolgreich zurückgebucht',
    'reverse' => 'Rückbuchung',
    'filtered_by_project' => 'Nach Projekt filtern',
    'google_sign_in' => 'Anmeldung mit Google',
    'activity_58' => ':user buchte Rechnung :invoice zurück',
    'activity_59' => ':user brach Rechnung :invoice ab',
    'payment_reconciliation_failure' => 'Fehler bei Kontenabstimmung',
    'payment_reconciliation_success' => 'Kontenabstimmung erfolgreich',
    'gateway_success' => 'Zahlungsanbieter erfolgreich',
    'gateway_failure' => 'Zahlungsanbieter Fehler',
    'gateway_error' => 'Zahlungsanbieter Fehler',
    'email_send' => 'E-Mail gesendet',
    'email_retry_queue' => 'E-Mail Wiederholungswarteschlange',
    'failure' => 'Fehler',
    'quota_exceeded' => 'Quota erreicht',
    'upstream_failure' => 'Upstream Fehler',
    'system_logs' => 'System-Log',
    'copy_link' => 'Link kopieren',
    'welcome_to_invoice_ninja' => 'Willkommen bei Invoice Ninja',
    'optin' => 'Anmelden',
    'optout' => 'Abmelden',
    'auto_convert' => 'Automatisch konvertieren',
    'reminder1_sent' => 'Erste Erinnerung verschickt',
    'reminder2_sent' => 'Zweite Erinnerung verschickt',
    'reminder3_sent' => 'Dritte Erinnerung verschickt',
    'reminder_last_sent' => 'Letzte Erinnerung verschickt',
    'pdf_page_info' => 'Seite :current von :total',
    'emailed_credits' => 'Guthaben erfolgreich per E-Mail versendet',
    'view_in_stripe' => 'In Stripe anzeigen',
    'rows_per_page' => 'Einträge pro Seite',
    'apply_payment' => 'Zahlungen anwenden',
    'unapplied' => 'unangewendet',
    'custom_labels' => 'Eigene Beschriftungen',
    'record_type' => 'Eintragstyp',
    'record_name' => 'Eintragsname',
    'file_type' => 'Dateityp',
    'height' => 'Höhe',
    'width' => 'Breite',
    'health_check' => 'Systemprüfung',
    'last_login_at' => 'Letzter Login',
    'company_key' => 'Firmen Schlüssel',
    'storefront' => 'Storefront',
    'storefront_help' => 'Drittanbieter Applikationen erlauben Rechnungen zu erstellen',
    'count_records_selected' => ':count Datensätze ausgewählt',
    'count_record_selected' => ':count Datensätze ausgewählt',
    'client_created' => 'Kunde wurde erstellt',
    'online_payment_email' => 'Online-Zahlung E-Mail Adresse',
    'manual_payment_email' => 'manuelle Zahlung E-Mail Adresse',
    'completed' => 'Abgeschlossen',
    'gross' => 'Gesamtbetrag',
    'net_amount' => 'Netto Betrag',
    'net_balance' => 'Netto Betrag',
    'client_settings' => 'Kundeneinstellungen',
    'selected_invoices' => 'Ausgewählte Rechnungen',
    'selected_payments' => 'Ausgewählte Zahlungen',
    'selected_quotes' => 'Ausgewählte Angebote',
    'selected_tasks' => 'Ausgewählte Aufgaben',
    'selected_expenses' => 'Ausgewählte Ausgaben',
    'past_due_invoices' => 'Überfällige Rechnungen',
    'create_payment' => 'Zahlung erstellen',
    'update_quote' => 'Angebot aktualisieren',
    'update_invoice' => 'Rechnung aktualisieren',
    'update_client' => 'Kunde aktualisieren',
    'update_vendor' => 'Lieferant aktualisieren',
    'create_expense' => 'Ausgabe erstellen',
    'update_expense' => 'Ausgabe aktualisieren',
    'update_task' => 'Aufgabe aktualisieren',
    'approve_quote' => 'Angebot annehmen',
    'when_paid' => 'Bei Zahlung',
    'expires_on' => 'Gültig bis',
    'show_sidebar' => 'Zeige Seitenmenü',
    'hide_sidebar' => 'Verstecke Seitenmenu',
    'event_type' => 'Ereignistyp',
    'copy' => 'kopieren',
    'must_be_online' => 'Bitte starten Sie die App sobald Sie mit dem Internet verbunden sind',
    'crons_not_enabled' => 'Die Crons müssen aktiviert werden',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Suche :count Webhooks',
    'search_webhook' => 'Suche 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Neuer Webhook',
    'edit_webhook' => 'Webhook bearbeiten',
    'created_webhook' => 'Webhook erfolgreich erstellt',
    'updated_webhook' => 'Webhook erfolgreich aktualisiert',
    'archived_webhook' => 'Webhook erfolgreich archiviert',
    'deleted_webhook' => 'Webhook erfolgreich gelöscht',
    'removed_webhook' => 'Webhook erfolgreich entfernt',
    'restored_webhook' => 'Webhook erfolgreich wiederhergestellt',
    'search_tokens' => 'Suche :count Token',
    'search_token' => 'Suche 1 Token',
    'new_token' => 'Neues Token',
    'removed_token' => 'Token erfolgreich entfernt',
    'restored_token' => 'Token erfolgreich wiederhergestellt',
    'client_registration' => 'Kunden Registration',
    'client_registration_help' => 'Den Kunden ermöglichen, sich selbst im Portal zu registrieren.',
    'customize_and_preview' => 'Anpassung und Vorschau',
    'search_document' => 'Suche 1 Dokument',
    'search_design' => 'Suche 1 Design',
    'search_invoice' => 'Suche 1 Angebot',
    'search_client' => 'Suche 1 Kunden',
    'search_product' => 'Suche 1 Produkt',
    'search_quote' => 'Suche 1 Angebot',
    'search_credit' => 'Suche 1 Guthaben',
    'search_vendor' => 'Suche 1 Hersteller',
    'search_user' => 'Suche 1 Benutzer',
    'search_tax_rate' => 'Suche 1 Steuersatz',
    'search_task' => 'Suche 1 Aufgabe',
    'search_project' => 'Suche 1 Projekt',
    'search_expense' => 'Suche 1 Ausgabe',
    'search_payment' => 'Suche 1 Zahlung',
    'search_group' => 'Suche 1 Gruppen',
    'created_on' => 'Erstellt am',
    'payment_status_-1' => 'nicht angewendet',
    'lock_invoices' => 'Rechnung sperren',
    'show_table' => 'Zeige Tabelle',
    'show_list' => 'Zeige Liste',
    'view_changes' => 'Änderungen anzeigen',
    'force_update' => 'Aktualisierungen erzwingen',
    'force_update_help' => 'Du benutzt die aktuellste Version, aber es stehen noch ausstehende Fehlerbehebungen zur Verfügung',
    'mark_paid_help' => 'Verfolge ob Ausgabe bezahlt wurde',
    'mark_invoiceable_help' => 'Ermögliche diese Ausgabe in Rechnung zu stellen',
    'add_documents_to_invoice_help' => 'Dokumente sichtbar machen',
    'convert_currency_help' => 'Wechselkurs setzen',
    'expense_settings' => 'Ausgaben Einstellungen',
    'clone_to_recurring' => 'Duplizieren zu Widerkehrend',
    'crypto' => 'Verschlüsselung',
    'user_field' => 'Benutzer Feld',
    'variables' => 'Variablen',
    'show_password' => 'Zeige Passwort',
    'hide_password' => 'Verstecke Passwort',
    'copy_error' => 'Kopier Fehler',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Automatische Rechnungsstellung aktivieren',
    'total_taxes' => 'Gesamt Steuern',
    'line_taxes' => 'Belegposition Steuer',
    'total_fields' => 'Gesamt Felder',
    'stopped_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich gestoppt',
    'started_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich gestartet',
    'resumed_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich fortgesetzt',
    'gateway_refund' => 'Zahlungsanbieter Rückerstattung',
    'gateway_refund_help' => 'Bearbeite die Rückerstattung über den Zahlungsanbieter',
    'due_date_days' => 'Fälligkeitsdatum',
    'paused' => 'Pausiert',
    'day_count' => 'Tag :count',
    'first_day_of_the_month' => 'Erster Tag des Monats',
    'last_day_of_the_month' => 'Letzter Tag des Monats',
    'use_payment_terms' => 'Benutze Zahlungsbedingung',
    'endless' => 'Endlos',
    'next_send_date' => 'Nächstes Versanddatum',
    'remaining_cycles' => 'Verbleibende Durchgänge',
    'created_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich erstellt',
    'updated_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich aktualisiert',
    'removed_recurring_invoice' => 'Wiederkehrende Rechnung erfolgreich entfernt',
    'search_recurring_invoice' => 'Suche 1 wiederkehrende Rechnung',
    'search_recurring_invoices' => 'Suche :count Wiederkehrende Rechnungen',
    'send_date' => 'Versanddatum',
    'auto_bill_on' => 'Automatische Rechnungsstellung zum',
    'minimum_under_payment_amount' => 'Minimaler Unterzahlungsbetrag',
    'allow_over_payment' => 'Überzahlung zulassen',
    'allow_over_payment_help' => 'Überzahlungen zulassen, beispielsweise Trinkgelder',
    'allow_under_payment' => 'Unterzahlung zulassen',
    'allow_under_payment_help' => 'Teilzahlungen zulassen',
    'test_mode' => 'Test Modus',
    'calculated_rate' => 'Berechneter Satz',
    'default_task_rate' => 'Standard-Steuersatz',
    'clear_cache' => 'Zwischenspeicher leeren',
    'sort_order' => 'Sortierreihenfolge',
    'task_status' => 'Status',
    'task_statuses' => 'Aufgaben Status',
    'new_task_status' => 'Neuer Aufgaben Status',
    'edit_task_status' => 'Aufgaben Status bearbeiten',
    'created_task_status' => 'Aufgaben Status erfolgreich erstellt',
    'archived_task_status' => 'Aufgaben Status erfolgreich archiviert',
    'deleted_task_status' => 'Aufgaben Status erfolgreich gelöscht',
    'removed_task_status' => 'Aufgaben Status erfolgreich entfernt',
    'restored_task_status' => 'Aufgaben Status erfolgreich wiederhergestellt',
    'search_task_status' => 'Suche 1 Aufgaben Status',
    'search_task_statuses' => 'Suche :count Aufgaben Status',
    'show_tasks_table' => 'Zeige Aufgaben Tabelle',
    'show_tasks_table_help' => 'Beim Erstellen von Rechnungen immer die Aufgabenauswahl anzeigen',
    'invoice_task_timelog' => 'Aufgaben Zeiterfassung in Rechnung stellen',
    'invoice_task_timelog_help' => 'Zeitdetails in der Rechnungsposition ausweisen',
    'auto_start_tasks_help' => 'Beginne Aufgabe vor dem Speichern',
    'configure_statuses' => 'Stati bearbeiten',
    'task_settings' => 'Aufgaben Einstellungen',
    'configure_categories' => 'Kategorien bearbeiten',
    'edit_expense_category' => 'Ausgaben Kategorie bearbeiten',
    'removed_expense_category' => 'Ausgaben Kategorie erfolgreich entfernt',
    'search_expense_category' => 'Suche 1 Ausgabenkategorie',
    'search_expense_categories' => 'Suche :count Ausgabenkategorie',
    'use_available_credits' => 'Verfügbares Guthaben verwenden',
    'show_option' => 'Zeige Option',
    'negative_payment_error' => 'Der Guthabenbetrag darf den Zahlungsbetrag nicht übersteigen',
    'should_be_invoiced_help' => 'Ermögliche diese Ausgabe in Rechnung zu stellen',
    'configure_gateways' => 'Zahlungsanbieter bearbeiten',
    'payment_partial' => 'Teilzahlung',
    'is_running' => 'Läuft derzeit',
    'invoice_currency_id' => 'Rechnungs-Währungs-ID',
    'tax_name1' => 'Steuersatz Name 1',
    'tax_name2' => 'Steuersatz Name 2',
    'transaction_id' => 'Transaktions ID',
    'invoice_late' => 'Rechnung in Verzug',
    'quote_expired' => 'Angebot abgelaufen',
    'recurring_invoice_total' => 'Gesamtbetrag',
    'actions' => 'Aktionen',
    'expense_number' => 'Ausgabennummer',
    'task_number' => 'Aufgabennummer',
    'project_number' => 'Projektnummer',
    'view_settings' => 'Einstellungen anzeigen',
    'company_disabled_warning' => 'Warnung: diese Firma wurde noch nicht aktiviert',
    'late_invoice' => 'Rechnung in Verzug',
    'expired_quote' => 'Abgelaufenes Angebot',
    'remind_invoice' => 'Rechnungserinnerung',
    'client_phone' => 'Kunden Telefon',
    'required_fields' => 'Benötigte Felder',
    'enabled_modules' => 'Module aktivieren',
    'activity_60' => ':contact schaute Angebot :quote an',
    'activity_61' => ':user hat Kunde :client aktualisiert',
    'activity_62' => ':user hat Lieferant :vendor aktualisiert',
    'activity_63' => ':user mailte erste Erinnerung für Rechnung :invoice an :contact ',
    'activity_64' => ':user mailte zweite Erinnerung für Rechnung :invoice an :contact ',
    'activity_65' => ':user mailte dritte Erinnerung für Rechnung :invoice an :contact ',
    'activity_66' => ':user mailte endlose Erinnerung für Rechnung :invoice an :contact',
    'expense_category_id' => 'Ausgabenkategorie ID',
    'view_licenses' => 'Lizenzen anzeigen',
    'fullscreen_editor' => 'Vollbild Editor',
    'sidebar_editor' => 'Seitenmenü Editor',
    'please_type_to_confirm' => 'Bitte geben Sie ":value" zur Bestätigung ein',
    'purge' => 'Bereinigen',
    'clone_to' => 'Duplizieren zu',
    'clone_to_other' => 'Duplizieren zu anderem',
    'labels' => 'Beschriftung',
    'add_custom' => 'Beschriftung hinzufügen',
    'payment_tax' => 'Steuer-Zahlung',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Versendete Rechnungen sind gesperrt',
    'paid_invoices_are_locked' => 'Bezahlte Rechnungen sind gesperrt',
    'source_code' => 'Quellcode',
    'app_platforms' => 'Applikations Platform',
    'archived_task_statuses' => ' :value Aufgaben Stati erfolgreich archiviert',
    'deleted_task_statuses' => ' :value Aufgaben Stati erfolgreich gelöscht',
    'restored_task_statuses' => ' :value Aufgaben Stati erfolgreich wiederhergestellt',
    'deleted_expense_categories' => ' :value Ausgabenkategorien erfolgreich gelöscht',
    'restored_expense_categories' => ':value Ausgabenkategorien erfolgreich wiederhergestellt',
    'archived_recurring_invoices' => ':value Wiederkehrende Rechnung erfolgreich archiviert',
    'deleted_recurring_invoices' => ':value Wiederkehrende Rechnungen erfolgreich gelöscht',
    'restored_recurring_invoices' => ':value Wiederkehrende Rechnungen erfolgreich wiederhergestellt',
    'archived_webhooks' => ':value Webhooks erfolgreich archiviert',
    'deleted_webhooks' => ':value Webhooks erfolgreich gelöscht',
    'removed_webhooks' => ':value Webhooks erfolgreich entfernt',
    'restored_webhooks' => ':value Webhooks erfolgreich wiederhergestellt',
    'api_docs' => 'API Doku',
    'archived_tokens' => ':count Token erfolgreich archiviert',
    'deleted_tokens' => ':count Token erfolgreich gelöscht',
    'restored_tokens' => ':value Token erfolgreich wiederhergestellt',
    'archived_payment_terms' => ':value Zahlungsbedingungen erfolgreich archiviert',
    'deleted_payment_terms' => ':value Zahlungsbedingungen erfolgreich gelöscht',
    'restored_payment_terms' => ':value Zahlungsbedingungen erfolgreich wiederhergestellt',
    'archived_designs' => ':value Designs erfolgreich archiviert',
    'deleted_designs' => ':value Designs erfolgreich gelöscht',
    'restored_designs' => ':value Designs erfolgreich wiederhergestellt',
    'restored_credits' => ':value Guthaben erfolgreich archiviert',
    'archived_users' => ':value Benutzer erfolgreich archiviert',
    'deleted_users' => ':value Benutzer erfolgreich gelöscht',
    'removed_users' => ':value Benutzer erfolgreich entfernt',
    'restored_users' => ':value Benutzer erfolgreich wiederhergestellt',
    'archived_tax_rates' => ':value Steuersätze erfolgreich archiviert',
    'deleted_tax_rates' => ':value Steuersätze erfolgreich gelöscht',
    'restored_tax_rates' => ':value Steuersätze erfolgreich wiederhergestellt',
    'archived_company_gateways' => ':value Zahlungsanbieter erfolgreich archiviert',
    'deleted_company_gateways' => ':value Zahlungsanbieter erfolgreich gelöscht',
    'restored_company_gateways' => ':value Zahlungsanbieter erfolgreich wiederhergestellt',
    'archived_groups' => ':value Gruppen erfolgreich archiviert',
    'deleted_groups' => ':value Gruppen erfolgreich gelöscht',
    'restored_groups' => ':value Gruppen erfolgreich wiederhergestellt',
    'archived_documents' => ':value Dokumente erfolgreich archiviert',
    'deleted_documents' => ':value Dokumente erfolgreich gelöscht',
    'restored_documents' => ':value Dokumente erfolgreich wiederhergestellt',
    'restored_vendors' => ':value Lieferanten erfolgreich wiederhergestellt',
    'restored_expenses' => ':value Ausgaben erfolgreich wiederhergestellt',
    'restored_tasks' => ':value Aufgaben erfolgreich wiederhergestellt',
    'restored_projects' => ':value Projekte erfolgreich wiederhergestellt',
    'restored_products' => ':value Produkte erfolgreich wiederhergestellt',
    'restored_clients' => ':value Kunden erfolgreich wiederhergestellt',
    'restored_invoices' => ':value Rechnungen erfolgreich wiederhergestellt',
    'restored_payments' => ':value Zahlungen erfolgreich wiederhergestellt',
    'restored_quotes' => ':value Angebote erfolgreich wiederhergestellt',
    'update_app' => 'App aktualisieren',
    'started_import' => 'Import erfolgreich gestartet',
    'duplicate_column_mapping' => 'Dupliziere Spaltenzuordnung',
    'uses_inclusive_taxes' => 'Benutzt Inklusive Steuern',
    'is_amount_discount' => 'Ist Betrag ermäßigt',
    'map_to' => 'Zuordnen',
    'first_row_as_column_names' => 'Benutze erste Zeile als Spaltenüberschrift',
    'no_file_selected' => 'Keine Datei ausgewählt',
    'import_type' => 'Import Typ',
    'draft_mode' => 'Entwurfsmodus',
    'draft_mode_help' => 'Vorschau schneller aber weniger genau darstellen',
    'show_product_discount' => 'Produktermäßigung anzeigen',
    'show_product_discount_help' => 'Zeige Rabattfeld in Belegposition',
    'tax_name3' => 'Steuersatz Name 3',
    'debug_mode_is_enabled' => 'Der Entwicklungsmodus ist aktiviert',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Laufende Aufgaben',
    'recent_tasks' => 'Kürzliche Aufgaben',
    'recent_expenses' => 'Kürzliche Ausgaben',
    'upcoming_expenses' => 'Zukünftige Ausgaben',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Speichern und Vorschau anzeigen',
    'save_and_email' => 'Speichern und verschicken',
    'converted_balance' => 'Guthabenstand',
    'is_sent' => 'Gesendet',
    'document_upload' => 'Dokument hochladen',
    'document_upload_help' => 'Erlaube Kunden Dokumente hochzuladen',
    'expense_total' => 'Ausgabensumme',
    'enter_taxes' => 'Steuersätze eingeben',
    'by_rate' => 'Nach Satz',
    'by_amount' => 'Nach Betrag',
    'enter_amount' => 'Betrag eingeben',
    'before_taxes' => 'Vor Steuern',
    'after_taxes' => 'Nach Steuern',
    'color' => 'Farbe',
    'show' => 'anzeigen',
    'empty_columns' => 'Leere Spalten',
    'project_name' => 'Projektname',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'Dieses Quartal',
    'to_update_run' => 'Zum Änderungslauf',
    'registration_url' => 'Registrierungs-URL',
    'show_product_cost' => 'Produktkosten anzeigen',
    'complete' => 'Fertigstellen',
     'next' => 'Weiter',
     'next_step' => 'Nächster Schritt',
     'notification_credit_sent_subject' => 'Rechnung :invoice wurde an Kunde gesendet.',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Bitte geben Sie ihre E-Mail-Adresse an, um das Passwort zurücksetzen zu können.',
     'password_reset' => 'Passwort zurücksetzten',
     'account_login_text' => 'Willkommen! Schön Sie wieder zu sehen.',
     'request_cancellation' => 'Storno beantragen',
     'delete_payment_method' => 'Zahlungsmethode löschen',
     'about_to_delete_payment_method' => 'Diese Zahlungsmethode wird gelöscht.',
     'action_cant_be_reversed' => 'Diese Aktion kann nicht widerrufen werden',
     'profile_updated_successfully' => 'Das Profil wurde erfolgreich aktualisiert.',
     'currency_ethiopian_birr' => 'Äthiopischer Birr',
     'client_information_text' => 'Bitte nutzen Sie eine postfähige Anschrift.',
     'status_id' => 'Rechnungsstatus',
     'email_already_register' => 'Diese E-Mail wird bereits von einem anderen Account verwendet',
     'locations' => 'Standorte',
     'freq_indefinitely' => 'Unendlich',
     'cycles_remaining' => 'Verbleibende Zyklen',
     'i_understand_delete' => 'Ich bin mir der Risiken bewusst, löschen',
     'download_files' => 'Dateien herunterladen',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'Neue Registrierung',
     'new_signup_text' => 'Ein neuer Benutzer wurde von :user - :email von der IP: :ip erstellt',
     'notification_payment_paid_subject' => 'Neue Zahlung von :Kunde',
     'notification_partial_payment_paid_subject' => 'Neue Anzahlung von :Kunde',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Benachrichtigungs-Bot',
     'invoice_number_placeholder' => 'Rechnung # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Log anzeigen',
     'send_fail_logs_to_our_server' => 'Fehler in Echtzeit melden',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Schnellüberblick & Statistiken',
     'update_your_personal_info' => 'Aktualisieren Sie Ihre Profil',
     'name_website_logo' => 'Name, Webseite & Logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Private Adresse',
     'enter_your_personal_address' => 'Bitte geben Sie Ihre Rechnungsadresse an',
     'enter_your_shipping_address' => 'Bitte geben Sie Ihr Lieferadresse an',
     'list_of_invoices' => 'Liste der Rechnungen',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'Diese Rechnung wurde noch nicht beglichen. Klicken um zu vervollständigen.',
     'list_of_recurring_invoices' => 'Liste der wiederkehrende Rechnungen',
     'details_of_recurring_invoice' => 'Details über wiederkehrende Rechnung',
     'cancellation' => 'Storno',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'Liste der Zahlungen',
     'payment_details' => 'Details zu der Rechnung',
     'list_of_payment_invoices' => 'Liste der Rechnungen die von dieser Zahlung betroffenen sind',
     'list_of_payment_methods' => 'Liste der Zahlungsmethoden',
     'payment_method_details' => 'Details zu der Zahlungsmethode',
     'permanently_remove_payment_method' => 'Zahlungsmethode endgültig entfernen.',
     'warning_action_cannot_be_reversed' => 'Achtung! Diese Aktion kann nicht widerrufen werden!',
     'confirmation' => 'Bestätigung',
     'list_of_quotes' => 'Angebote',
     'waiting_for_approval' => 'Annahme ausstehend',
     'quote_still_not_approved' => 'Dieses Angebot wurde noch nicht angenommen.',
     'list_of_credits' => 'Guthaben',
     'required_extensions' => 'Benötigte PHP-Erweiterungen',
     'php_version' => 'PHP Version',
     'writable_env_file' => 'Beschreibbare .env-Datei',
     'env_not_writable' => 'die .env-Datei ist vom aktuellen Benutzer nicht beschreibbar',
     'minumum_php_version' => 'Minimale PHP-Version',
     'satisfy_requirements' => 'Prüfen Sie, ob alle Anforderungen erfüllt sind.',
     'oops_issues' => 'Entschuldigung, das ist wohl etwas schiefgelaufen!',
     'open_in_new_tab' => 'In neuem Fenster öffnen',
     'complete_your_payment' => 'Zahlung abschließen',
     'authorize_for_future_use' => 'Zahlungsmethode für zukünftige Verwendung freigeben',
     'page' => 'Seite',
     'per_page' => 'pro Seite',
     'of' => 'von',
     'view_credit' => 'Guthaben anzeigen',
     'to_view_entity_password' => 'Um :entity anzusehen, geben Sie bitte Ihr Passwort ein.',
     'showing_x_of' => 'Zeige :first bis :last von :total Ergebnissen',
     'no_results' => 'Kein Ergebnis gefunden.',
     'payment_failed_subject' => 'Zahlung für Kunde :client fehlgeschlagen',
     'payment_failed_body' => 'Eine Zahlung von :client schlug fehl: :message',
     'register' => 'Registrieren',
     'register_label' => 'Benutzerkonto in wenigen Sekunden erstellen',
     'password_confirmation' => 'Passwort bestätigen',
     'verification' => 'Bestätigung',
     'complete_your_bank_account_verification' => 'Ein Bankkonto muss verifiziert werden, bevor es genutzt werden kann.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Die angegebene Kreditkartennummer ist ungültig.',
     'month_invalid' => 'Der angegebene Monat ist ungültig',
     'year_invalid' => 'Das angegebene Jahr ist ungültig',
     'https_required' => 'HTTPS ist Pflicht, das Formular wird nicht funktionieren',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'Nach dem Update des Passworts wird Ihr Account bestätigt.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Nur in Entwicklungsumgebung aktivieren',
     'test_pdf' => 'PDF testen',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node-Status',
     'npm_status' => 'NPM-Status',
     'node_status_not_found' => 'Node konnte nicht gefunden werden - ist es installiert?',
     'npm_status_not_found' => 'NPM konnte nicht gefunden werden - ist es installiert?',
     'locked_invoice' => 'Diese Rechnung ist gesperrt und kann nicht bearbeitet werden.',
     'downloads' => 'Downloads',
     'resource' => 'Resourcen',
     'document_details' => 'Details zu dem Dokument',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Erlaubte Dateitypen:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Ausgewählte herunterladen',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'Zahlungsart hinzufügen',
     'no_items_selected' => 'Keine Objekte ausgewählt.',
     'payment_due' => 'Zahlung überfallig',
     'account_balance' => 'Kontostand',
     'thanks' => 'Danke',
     'minimum_required_payment' => 'Mindestbetrag für die Zahlung ist :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Gespeichert um :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Kryptowährung',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Für zukünftige Zahlung speichern',
     'pay_with_credit' => 'Mit Kreditkarte zahlen',
     'payment_method_saving_failed' => 'Die Zahlungsart konnte nicht für zukünftige Zahlungen gespeichert werden.',
     'pay_with' => 'zahlen mit',
     'n/a' => 'n. z.',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Nicht angegeben',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Zahlen',
     'instructions' => 'Anleitung',
     'notification_invoice_reminder1_sent_subject' => 'Die erste Erinnerung für Rechnung :invoice wurde an Kunde :client gesendet',
     'notification_invoice_reminder2_sent_subject' => 'Die 2. Erinnerung für Rechnung :invoice wurde an Kunde :client gesendet',
     'notification_invoice_reminder3_sent_subject' => 'Die 3. Erinnerung für Rechnung :invoice wurde an Kunde :client gesendet',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Zugewiesener Benutzer',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Mindestbetrag',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'Keine unbezahlten Rechnungen ausgewählt. Stellen Sie sicher, dass Sie nicht versuchen, einen Rechnungsentwurf oder eine Rechnung mit Nullsaldo zu bezahlen.',
     'required_payment_information' => 'Benötigte Zahlungsinformationen',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Angaben zur Zahlungsart speichern',
     'new_card' => 'Neue Kreditkarte',
     'new_bank_account' => 'Bankverbindung hinzufügen',
     'company_limit_reached' => 'Maximal 10 Firmen pro Account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Gutschriftsnummer bereits vergeben.',
     'credit_not_found' => 'Gutschrift nicht gefunden',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Kundennummer wird benötigt.',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Diese Rechnungsnummer wurde bereits verwendet.',
     'payment_id_required' => 'Zahlungs-ID notwendig.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Angebotsnummer bereits in Verwendung',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Rechnung :number kann nicht erstattet werden',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Umstellung abgeschlossen',
     'migration_completed_description' => 'Die Umstellung wurde erfolgreich abgeschlossen. Bitte prüfen Sie trotzdem Ihre Daten nach dem Login.',
     'api_404' => '404 | Hier gibt es nichts zu sehen!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'Kein Guthaben gefunden.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'Keine Dokumente gefunden.',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Rechnung kann nicht als "bezahlt" gekennzeichnet werden.',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Angebot/e nicht gefunden',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Integrierter Updater auf diesem System nicht verfügbar.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Webhook konnte nicht erstellt werden',
     'payment_message_extended' => 'Vielen Dank für deine Zahlung von :amount für die Rechnung :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Zeige Aktionen',
     'start_multiselect' => 'Mehrfachauswahl',
     'email_sent_to_confirm_email' => 'Eine E-Mail wurde versandt um Ihre E-Mail-Adresse zu bestätigen.',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Name der Antwortadresse',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Farbthema',
     'start_migration' => 'Beginne mit der Migration.',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hallo',
     'group_documents' => 'Gruppendokumente',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Wählen Sie die zu migrierenden Firmen aus',
     'force_migration' => 'Migration erzwingen',
     'require_password_with_social_login' => 'Password mit Verknüpfung zu Sozialmedia notwendig',
     'stay_logged_in' => 'Eingeloggt bleiben',
     'session_about_to_expire' => 'Warnung: Ihre Sitzung läuft bald ab',
     'count_hours' => ':count Stunden',
     'count_day' => '1 Tag',
     'count_days' => ':count Tage',
     'web_session_timeout' => 'Web-Sitzungs-Timeout',
     'security_settings' => 'Sicherheitseinstellungen',
     'resend_email' => 'Bestätigungsemail erneut versenden ',
     'confirm_your_email_address' => 'Bitte bestätigen Sie Ihre E-Mail-Adresse',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Buchhaltung',
     'required_files_missing' => 'Bitte geben Sie alle CSV-Dateien an.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API-Secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'Ein Fehler ist aufgetreten, bitte versuchen Sie es erneut.',
     'please_first_set_a_password' => 'Bitte vergeben Sie zuerst ein Passwort.',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Hilf mit beim Übersetzen',
     'please_select_a_country' => 'Bitte wählen Sie ein Land',
     'disabled_two_factor' => '2FA erfolgreich deaktiviert',
     'connected_google' => 'Konto erfolgreich verbunden.',
     'disconnected_google' => 'Konto erfolgreich getrennt.',
     'delivered' => 'zugestellt',
     'spam' => 'Spam',
     'view_docs' => 'Dokumentation ansehen.',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'SMS senden',
     'sms_code' => 'SMS-Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Zwei-Faktor-Authentifizierung deaktivieren',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Gutscheincode',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Abonnement',
     'new_subscription' => 'Neues Abonnement',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Mit Gmail verbinden',
     'disconnect_gmail' => 'von Gmail trennen',
     'connected_gmail' => 'Mit Gmail erfolgreich verbunden',
     'disconnected_gmail' => 'Von Gmail erfolgreich getrennt',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Kundennummer',
     'count_minutes' => ':count Minuten',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user hat Abonnement :subscription erstellt',
    'activity_81' => ':user hat Abonnement :subscription geändert',
    'activity_82' => ':user hat Abonnement :subscription archiviert',
    'activity_83' => ':user hat Abonnement :subscription gelöscht',
    'activity_84' => ':user hat Abonnement :subscription wiederhergestellt',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
